library(metafor)

setwd("")

rcmcdat <- read.csv("MCRC_MetaAnalysis_Data.csv", header = T)

# GOLDEN THREAD / DISTINCT CONSTRUCTS HYPOTHESES
### create r to z transformed correlation effect size estimate for RC and MC correlations
goldenthread <- escalc("ZCOR", ri = rcmcdat$CorrRCMC, ni = rcmcdat$SampleSize, append = T, data = rcmcdat)
goldenmeta <- rma(yi, vi, data = goldenthread, method = "ML")
goldenmeta

### set font to normal
tiff("Fig1new.tiff", width = 10, height = 11, unit = 'in', res = 300)
par(font=1)
### forest plot of correlations between RC and MC to test golden thread / distinct constructs hypotheses
forest(goldenmeta, transf = transf.ztor, slab = NA, order = "obs",
       ilab = cbind(goldenthread$StudyNumber, as.character(goldenthread$AttitudeObject), goldenthread$SampleSize),
       ilab.xpos = c(-.65, -.64, -.05), ilab.pos = c(2, 4, 2),
       xlim = c(-.75, 1.1), cex = .9, mlab = "", xlab = "Correlation")
### add RE Model Stats to plot
text(-.75, -1, pos=4, cex=0.9, bquote(paste("RE Model (Q = ",
                                            .(formatC(goldenmeta$QE, digits=2, format="f")), ", df = ", .(goldenmeta$k - goldenmeta$p),
                                            ", p = ", .(formatC(goldenmeta$QEp, digits=2, format="f")), "; ", I^2, " = ",
                                            .(formatC(goldenmeta$I2, digits=1, format="f")), "%)")))
### switch to bold font
par(font=2)
### add column headings to the plot
text(-.75, 45, "Study",  pos = 4, cex = .9)
text(-.45, 45, "Issue", pos = 4, cex = .9)
text(-.07, 45, expression(bolditalic(N)), pos = 2, cex = .9)
text(.93, 45, expression(bolditalic(r)), pos = 2, cex = .9)
text(.9, 45, "[95% CI]", pos = 4, cex = .9)
title("Golden Thread/Distinct Constructs Hypotheses:\nCorrelation between RC and MC")
par(font=1)
dev.off()


# SECULARIZATION HYPOTHESIS
### create semi-partial correlation effect size estimate for secularization hypothesis (currently omnibus interaction in regression model 2)
secular <- escalc("SPCOR", ti = rcmcdat$SecularTi, ni = rcmcdat$SampleSize, mi = rcmcdat$X2wayPredictors, r2i = rcmcdat$X2wayR2i,
                  append = T, data = rcmcdat)
secularmeta <- rma(yi, vi, data = secular, method = "ML")
secularmeta

### set font to normal
tiff("Fig3new.tiff", width = 10, height = 11, unit = 'in', res = 300)
par(font=1)
### forest plot of semi-partial correlations of effect of interaction between RC and Religiosity predicting MC to test secularization hypothesis
forest(secularmeta, slab = NA, order = "obs",
       ilab = cbind(secular$StudyNumber, as.character(secular$AttitudeObject), secular$SampleSize),
       ilab.xpos = c(-.9, -.89, -.25), ilab.pos = c(2, 4, 2),
       xlim = c(-1, 1), cex = .9, mlab = "", xlab = "Semi-Partial Correlation")
### add RE Model Stats to plot
text(-1, -1, pos=4, cex=0.9, bquote(paste("RE Model (Q = ",
                                            .(formatC(secularmeta$QE, digits=2, format="f")), ", df = ", .(secularmeta$k - secularmeta$p),
                                            ", p = ", .(formatC(secularmeta$QEp, digits=2, format="f")), "; ", I^2, " = ",
                                            .(formatC(secularmeta$I2, digits=1, format="f")), "%)")))
### switch to bold font
par(font=2)
### add column headings to the plot
text(-1, 27, "Study",  pos = 4, cex = .9)
text(-.7, 27, "Issue", pos = 4, cex = .9)
text(-.27, 27, expression(bolditalic(N)), pos = 2, cex = .9)
text(.83, 27, expression(bolditalic(r)[sp]), pos = 2, cex = .9)
text(.8, 27, "[95% CI]", pos = 4, cex = .9)
title("Secularization Hypothesis:\nSemi-Partial Correlation between RC/Religiosity Interaction and MC")
par(font=1)
dev.off()


# BROAD CULTURE WAR HYPOTHESIS
### create semi-partial correlation effect size estimate for broad culture war hypothesis (currently omnibus interaction in regression model 2)
broad <- escalc("SPCOR", ti = rcmcdat$BroadTi, ni = rcmcdat$SampleSize, mi = rcmcdat$X2wayPredictors, r2i = rcmcdat$X2wayR2i,
                  append = T, data = rcmcdat)
broadmeta <- rma(yi, vi, data = broad, method = "ML")
broadmeta

### set font to normal
tiff("Fig2new.tiff", width = 10, height = 11, unit = 'in', res = 300)
par(font=1)
### forest plot of semi-partial correlations of effect of interaction between RC and PO predicting MC to test broad culture war hypothesis
forest(broadmeta, slab = NA, order = "obs",
       ilab = cbind(broad$StudyNumber, as.character(broad$AttitudeObject), broad$SampleSize),
       ilab.xpos = c(-1.13, -1.12, -.40), ilab.pos = c(2, 4, 2),
       xlim = c(-1.25, 1), cex = .9, mlab = "", xlab = "Semi-Partial Correlation")
### add RE Model Stats to plot
text(-1.25, -1, pos=4, cex=0.9, bquote(paste("RE Model (Q = ",
                                          .(formatC(broadmeta$QE, digits=2, format="f")), ", df = ", .(broadmeta$k - broadmeta$p),
                                          ", p = ", .(formatC(broadmeta$QEp, digits=2, format="f")), "; ", I^2, " = ",
                                          .(formatC(broadmeta$I2, digits=1, format="f")), "%)")))
### switch to bold font
par(font=2)
### add column headings to the plot
text(-1.25, 45, "Study",  pos=4, cex = .9)
text(-.9, 45, "Issue", pos = 4, cex = .9)
text(-.42, 45, expression(bolditalic(N)), pos = 2, cex = .9)
text(.8, 45, expression(bolditalic(r)[sp]), pos = 2, cex = .9)
text(.77, 45, "[95% CI]", pos = 4, cex = .9)
title("Broad Culture War Hypothesis:\nSemi-Partial Correlation between RC/PO Interaction and MC")
par(font=1)
dev.off()


# NARROW CULTURE WAR HYPOTHESIS
### create semi-partial correlation effect size estimate for broad culture war hypothesis (currently omnibus interaction in regression model 3)
narrow <- escalc("SPCOR", ti = rcmcdat$NarrowTi, ni = rcmcdat$SampleSize, mi = rcmcdat$X3wayPredictors, r2i = rcmcdat$X3wayR2i,
                append = T, data = rcmcdat)
narrowmeta <- rma(yi, vi, data = narrow, method = "ML")
narrowmeta

### set font to normal
tiff("Fig4new.tiff", width = 10, height = 11, unit = 'in', res = 300)
par(font=1)
### forest plot of semi-partial correlations of effect of interaction between RC, PO, and Religiosity predicting MC to test narrow culture hypothesis
forest(narrowmeta, slab = NA, order = "obs",
       ilab = cbind(narrow$StudyNumber, as.character(narrow$AttitudeObject), narrow$SampleSize),
       ilab.xpos = c(-1.15, -1.14, -.5), ilab.pos = c(2, 4, 2),
       xlim = c(-1.25, .75), cex = .9, mlab = "", xlab = "Semi-Partial Correlation")
### add RE Model Stats to plot
text(-1.25, -1, pos=4, cex=0.9, bquote(paste("RE Model (Q = ",
                                             .(formatC(narrowmeta$QE, digits=2, format="f")), ", df = ", .(narrowmeta$k - narrowmeta$p),
                                             ", p = ", .(formatC(narrowmeta$QEp, digits=2, format="f")), "; ", I^2, " = ",
                                             .(formatC(narrowmeta$I2, digits=1, format="f")), "%)")))
### switch to bold font
par(font=2)
### add column headings to the plot
text(-1.25, 27, "Study",  pos=4, cex = .9)
text(-.95, 27, "Issue", pos = 4, cex = .9)
text(-.52, 27, expression(bolditalic(N)), pos = 2, cex = .9)
text(.57, 27, expression(bolditalic(r)[sp]), pos = 2, cex = .9)
text(.54, 27, "[95% CI]", pos = 4, cex = .9)
title("Narrow Culture War Hypothesis:\nSemi-Partial Correlation between RC/PO/Religiosity Interaction and MC")
par(font=1)
dev.off()
