####################################################################
####################################################################
#######  Reigious Convcition Perdicting Moral Conviction   #########

library(rockchalk) #Graphing simple slopes; moderation
library(stargazer) #Handy regression tables
library(foreign)  # Read in SPSS
library(gvlma)   #helper on diagnostics
library(effects) #helper on visualizing interactions - Uses lattice
library(sjPlot)  #helper on visualizing interactions - uses ggplot
library(ggplot2) #All the graphs
library(psych) #handy for descriptives, etc
library(dplyr) 

#set working directory
setwd("C:/Users/Brittany/Box Sync/RC Project/Data sets/Study 10 (Supreme Court SSM Study BH)")

##########################################################################################
##########################################################################################
#### Supreme Court SSM Wave 1 . 

##########################################################################################
#SC Same-Sex Marriage analysis.

#Data for Same-Sex Marriage analysis. 
SCSSM<-read.spss("MCRC_Study10_SameSexMarriage_Data.sav", use.value.labels = FALSE, to.data.frame = TRUE,
                 max.value.labels = Inf, trim.factor.names = FALSE,
                 trim_values = TRUE, reencode = NA, use.missings = to.data.frame)

describe(SCSSM$PO)
describe(SCSSM$Relig)
describe(SCSSM$SSM_mc)
describe(SCSSM$SSM_rc)

#Center Religiosity.
SCSSM$Religc <- scale(SCSSM$Relig, center = T, scale = F)
describe(SCSSM$Religc)
class(SCSSM$Religc)
SCSSM$Religc <- as.vector(SCSSM$Religc)

#Center Religious Conviction.
SCSSM$SSM_RCc <- scale(SCSSM$SSM_rc, center = T, scale = F)
describe(SCSSM$SSM_RCc)
class(SCSSM$SSM_RCc)
SCSSM$SSM_RCc <- as.vector(SCSSM$SSM_RCc)

#Mean replace Centered Religiosity.
SCSSM$Religcmr <- ifelse(is.na(SCSSM$Religc),
                         mean(SCSSM$Religc,na.rm=TRUE), SCSSM$Religc)
class(SCSSM$Religcmr)

#Mean replace Centered Religious Conviction.
SCSSM$SSM_RCcmr <- ifelse(is.na(SCSSM$SSM_RCc),
                          mean(SCSSM$SSM_RCc,na.rm=TRUE), SCSSM$SSM_RCc)
class(SCSSM$SSM_RCcmr)

#Mean replace Political Orientation.
SCSSM$POmr <- ifelse(is.na(SCSSM$PO),
                     mean(SCSSM$PO,na.rm=TRUE), SCSSM$PO)

#Mean replace Moral Conviction
SCSSM$SSM_MCmr <- ifelse(is.na(SCSSM$SSM_mc),
                         mean(SCSSM$SSM_mc,na.rm=TRUE), SCSSM$SSM_mc)

describe(SCSSM$POmr)
describe(SCSSM$Religcmr)
describe(SCSSM$SSM_RCcmr)
describe(SCSSM$SSM_MCmr)

##############  Analyses  ################

##Descriptives and Bi-variate correlations.
describe(SCSSM$PO)
describe(SCSSM$Relig)
describe(SCSSM$SSM_rc)
describe(SCSSM$SSM_mc)

cor.test(SCSSM$PO,SCSSM$Relig)
cor.test(SCSSM$PO,SCSSM$SSM_rc)
cor.test(SCSSM$PO,SCSSM$SSM_mc)
cor.test(SCSSM$Relig, SCSSM$SSM_rc)
cor.test(SCSSM$Relig, SCSSM$SSM_mc)
cor.test(SCSSM$SSM_rc, SCSSM$SSM_mc)

#Main effects political orientation, religiosity, same-sex marriage religious conviction 
SC_SSM.main <- lm(SSM_MCmr ~ POmr
                  + Religcmr
                  + SSM_RCcmr,
                  data = SCSSM) 
summary(SC_SSM.main)

#Main effects & 2-way Interactions

SC_SSM.2way <- lm(SSM_MCmr ~ POmr
                  + Religcmr
                  + SSM_RCcmr
                  + Religcmr*SSM_RCcmr
                  + POmr*Religcmr
                  + POmr*SSM_RCcmr,
                  data = SCSSM) 
summary(SC_SSM.2way)
anova(SC_SSM.main,SC_SSM.2way)

#Main effects & 2-way Interactions & 3-way interaction

SC_SSM.3way <- lm(SSM_MCmr ~ POmr
                  + Religcmr
                  + SSM_RCcmr
                  + Religcmr*SSM_RCcmr
                  + POmr*Religcmr
                  + POmr*SSM_RCcmr
                  + POmr*SSM_RCcmr*Religcmr,
                  data = SCSSM) 
summary(SC_SSM.3way)
anova(SC_SSM.2way,SC_SSM.3way)

##Table of all the steps
stargazer(SC_SSM.main,SC_SSM.2way,SC_SSM.3way,type="text",
          column.labels = c("Main Effects", "2-way Interactions", "3-way Interaction"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

#Create High and Low Political Orientation, (Liberal, Conservative, Moderate)
describe(SCSSM$POmr)

SCSSM$POmrHi <- (SCSSM$POmr - sd(SCSSM$POmr))
SCSSM$POmrLo <- (SCSSM$POmr + sd(SCSSM$POmr))

describe(SCSSM$POmrHi)
describe(SCSSM$POmrLo)

#Simple Interaction of Religiosity and Religious Conviction for Hi Political Orientation (Conservatives).
SC_SSM.3way.HiPO <- lm(SSM_MCmr ~ POmrHi
                       + Religcmr
                       + SSM_RCcmr
                       + Religcmr*SSM_RCcmr
                       + POmrHi*Religcmr
                       + POmrHi*SSM_RCcmr
                       + POmrHi*SSM_RCcmr*Religcmr,
                       data = SCSSM) 
summary(SC_SSM.3way.HiPO)

#Simple Interaction of Religiosity and Religious Conviction for Lo Political Orientation (Liberals).
SC_SSM.3way.LoPO <- lm(SSM_MCmr ~ POmrLo
                       + Religcmr
                       + SSM_RCcmr
                       + Religcmr*SSM_RCcmr
                       + POmrLo*Religcmr
                       + POmrLo*SSM_RCcmr
                       + POmrLo*SSM_RCcmr*Religcmr,
                       data = SCSSM) 
summary(SC_SSM.3way.LoPO)

#Three simple interactions for Liberals, Moderates, and Conservatives. 
stargazer(SC_SSM.3way.LoPO,SC_SSM.3way,SC_SSM.3way.HiPO,type="text",
          column.labels = c("Liberals", "Moderates", "Conservatives"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

#Plotting the Religious Conviction by Religiosity by Political Orientation interaction predicting moral conviction
#The effect of Religious Conviction  at mean religiosity, one standard deviation above the mean (high religiosity) and one standard deviation below the mean (low religiosity) 
#FOR Liberals (- 1SD), Moderates (Midpoint), and Conservatives (+1SD)
summary(SC_SSM.3way)
describe(SCSSM$POmr)
describe(SCSSM$Religcmr)
describe(SCSSM$SSM_RCcmr)

SC_SSM.RCatReligatPO.fitted<-effect('POmr:Religcmr:SSM_RCcmr', SC_SSM.3way,
                                    xlevels=list(POmr=c(-2.42, 0 , 2.42),
                                                 Religcmr=c(-1.54, 0 , 1.54),
                                                 SSM_RCcmr = seq(from = -1.62, to = 2.38, by =1)), 
                                    se=TRUE,confidence.level=.95)

SC_SSM.RCatReligatPO.Eff<-as.data.frame(SC_SSM.RCatReligatPO.fitted)

SC_SSM.RCatReligatPO.Eff$ReligMod<-factor(SC_SSM.RCatReligatPO.Eff$Religcmr,
                                          levels=c(-1.54,0,1.54),
                                          labels=c("Low Religiosity","Mean Religiosity","Hi Religiosity"))

SC_SSM.RCatReligatPO.Eff$POMod<-factor(SC_SSM.RCatReligatPO.Eff$POmr,
                                       levels=c(-2.42,0,2.42),
                                       labels=c("Liberals","Moderates","Conservatives"))

SC_SSM.RCatReligatPO.Plot <-ggplot(data = SC_SSM.RCatReligatPO.Eff, aes(x = SSM_RCcmr, y =fit, group=ReligMod))+
  facet_grid(~POMod)+
  coord_cartesian(xlim=c(-1.62, 2.38),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -1.62, to = 2.38, by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=ReligMod, linetype = ReligMod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=ReligMod),alpha=.2)+
  xlab("Same-Sex Marriage Religious Conviction")+
  ylab("Same-Sex Marriage Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .18))
SC_SSM.RCatReligatPO.Plot

#Testing the Simple Slopes of Religious Conviction at High Religiosity (+1 sd), Mean Religiosity, and Low Religiosity (-1 sd) For Liberals (-1 sd). 
summary(SC_SSM.3way.LoPO)
describe(SCSSM$SSM_RCcmr)
describe(SCSSM$Religcmr)

SC_SSM.RCAtRelig.Lib <- plotSlopes(SC_SSM.3way.LoPO, plotx="SSM_RCcmr", modx="Religcmr", 
                                   xlab = "Religious Conviction", ylab = "Moral Conviction", 
                                   modxVals = c(- 1.54, 0 ,  1.54), xlim = c (-1.62,  2.38), plotPoints = FALSE, 
                                   legendTitle = "Religiosity")

SC_SSM.RCAtRelig.Lib.test <- testSlopes(SC_SSM.RCAtRelig.Lib)
SC_SSM.RCAtRelig.Lib.test$hypotests

#Testing the Simple Slopes of Religious Conviction at High Religiosity (+1 sd), Mean Religiosity, and Low Religiosity (-1 sd) For Moderates (midpoint)
SC_SSM.RCAtRelig.Mod <- plotSlopes(SC_SSM.3way, plotx="SSM_RCcmr", modx="Religcmr", 
                                   xlab = "Religious Conviction", ylab = "Moral Conviction", 
                                   modxVals = c(- 1.54, 0 ,  1.54), xlim = c (-1.62,  2.38), plotPoints = FALSE, 
                                   legendTitle = "Religiosity")

SC_SSM.RCAtRelig.Mod.test <- testSlopes(SC_SSM.RCAtRelig.Mod)
SC_SSM.RCAtRelig.Mod.test$hypotests

#Testing the Simple Slopes of Religious Conviction at High Religiosity (+1 sd), Mean Religiosity, and Low Religiosity (-1 sd) For Conservatives (+1 sd)
SC_SSM.RCAtRelig.Con <- plotSlopes(SC_SSM.3way.HiPO, plotx="SSM_RCcmr", modx="Religcmr", 
                                   xlab = "Religious Conviction", ylab = "Moral Conviction", 
                                   modxVals = c(- 1.54, 0 ,  1.54), xlim = c (-1.62,  2.38), plotPoints = FALSE, 
                                   legendTitle = "Religiosity")

SC_SSM.RCAtRelig.Con.test <- testSlopes(SC_SSM.RCAtRelig.Con)
SC_SSM.RCAtRelig.Con.test$hypotests

##########################################################################################
#SC Same-Sex Couple Adoption analysis.

#Data for allowing same-sex couples to adopt children analysis. 
SCAdopt<-read.spss("MCRC_Study10_SameSexAdoption_Data.sav", use.value.labels = FALSE, to.data.frame = TRUE,
                   max.value.labels = Inf, trim.factor.names = FALSE,
                   trim_values = TRUE, reencode = NA, use.missings = to.data.frame)

describe(SCAdopt$PO)
describe(SCAdopt$Relig)
describe(SCAdopt$Adopt_mc)
describe(SCAdopt$Adopt_rc)

#Center Religiosity.
SCAdopt$Religc <- scale(SCAdopt$Relig, center = T, scale = F)
describe(SCAdopt$Religc)
class(SCAdopt$Religc)
SCAdopt$Religc <- as.vector(SCAdopt$Religc)

#Center Religious Conviction
SCAdopt$Adopt_RCc <- scale(SCAdopt$Adopt_rc, center = T, scale = F)
describe(SCAdopt$Adopt_RCc)
class(SCAdopt$Adopt_RCc)
SCAdopt$Adopt_RCc <- as.vector(SCAdopt$Adopt_RCc)

#Mean replace Centered Religiosity.
SCAdopt$Religcmr <- ifelse(is.na(SCAdopt$Religc),
                           mean(SCAdopt$Religc,na.rm=TRUE), SCAdopt$Religc)
class(SCAdopt$Religcmr)

#Mean replace Centered Religious Conviction.
SCAdopt$Adopt_RCcmr <- ifelse(is.na(SCAdopt$Adopt_RCc),
                              mean(SCAdopt$Adopt_RCc,na.rm=TRUE), SCAdopt$Adopt_RCc)
class(SCAdopt$Adopt_RCcmr)

#Mean replace Political Orientation.
SCAdopt$POmr <- ifelse(is.na(SCAdopt$PO),
                       mean(SCAdopt$PO,na.rm=TRUE), SCAdopt$PO)

#Mean replace Moral Conviction.
SCAdopt$Adopt_MCmr <- ifelse(is.na(SCAdopt$Adopt_mc),
                             mean(SCAdopt$Adopt_mc,na.rm=TRUE), SCAdopt$Adopt_mc)

describe(SCAdopt$POmr)
describe(SCAdopt$Religcmr)
describe(SCAdopt$Adopt_RCcmr)
describe(SCAdopt$Adopt_MCmr)


##############  Analyses  ################

##Descriptives and Bi-variate correlations.
describe(SCAdopt$PO)
describe(SCAdopt$Relig)
describe(SCAdopt$Adopt_rc)
describe(SCAdopt$Adopt_mc)

cor.test(SCAdopt$PO,SCAdopt$Relig)
cor.test(SCAdopt$PO,SCAdopt$Adopt_rc)
cor.test(SCAdopt$PO,SCAdopt$Adopt_mc)
cor.test(SCAdopt$Relig, SCAdopt$Adopt_rc)
cor.test(SCAdopt$Relig, SCAdopt$Adopt_mc)
cor.test(SCAdopt$Adopt_rc, SCAdopt$Adopt_mc)

#Main effects political orientation, religiosity,religious conviction 
SC_Adopt.main <- lm(Adopt_MCmr ~ POmr
                    + Religcmr
                    + Adopt_RCcmr,
                    data = SCAdopt) 
summary(SC_Adopt.main)

#Main effects & 2-way Interactions
SC_Adopt.2way <- lm(Adopt_MCmr ~ POmr
                    + Religcmr
                    + Adopt_RCcmr
                    + Religcmr*Adopt_RCcmr
                    + POmr*Religcmr
                    + POmr*Adopt_RCcmr,
                    data = SCAdopt) 
summary(SC_Adopt.2way)
anova(SC_Adopt.main,SC_Adopt.2way)

#Main effects & 2-way Interactions & 3-way interaction
SC_Adopt.3way <- lm(Adopt_MCmr ~ POmr
                    + Religcmr
                    + Adopt_RCcmr
                    + Religcmr*Adopt_RCcmr
                    + POmr*Religcmr
                    + POmr*Adopt_RCcmr
                    + POmr*Adopt_RCcmr*Religcmr,
                    data = SCAdopt) 
summary(SC_Adopt.3way)
anova(SC_Adopt.2way,SC_Adopt.3way)

##Table of all the steps
stargazer(SC_Adopt.main,SC_Adopt.2way,SC_Adopt.3way,type="text",
          column.labels = c("Main Effects", "2-way Interactions", "3-way Interaction"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

#Plotting the Religious Conviction by Religiosity interaction predicting moral conviction.
#The effect of Religious Conviction at mean religiosity, one standard deviation above (high religiosity), and one standard deviation below (low religiosity).
summary(SC_Adopt.2way)
describe(SCAdopt$Religcmr)
describe(SCAdopt$Adopt_RCcmr)

SC_Adopt.RCatRelig.fitted<-effect('Religcmr:Adopt_RCcmr', SC_Adopt.2way,
                                  xlevels=list(Religcmr=c(-1.61, 0 , 1.61), 
                                               Adopt_RCcmr = seq(from = -1.38, to = 2.62, by =1)), 
                                  se=TRUE,confidence.level=.95)

SC_Adopt.RCatRelig.Eff<-as.data.frame(SC_Adopt.RCatRelig.fitted)

SC_Adopt.RCatRelig.Eff$ReligMod<-factor(SC_Adopt.RCatRelig.Eff$Religcmr,
                                        levels=c(-1.61,0,1.61),
                                        labels=c("Low Religiosity","Mean Religiosity","Hi Religiosity"))

SC_Adopt.RCatRelig.Plot <-ggplot(data = SC_Adopt.RCatRelig.Eff, aes(x = Adopt_RCcmr, y =fit, group=ReligMod))+
  coord_cartesian(xlim=c(-1.38, 2.62),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -1.38, to = 2.62, by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=ReligMod, linetype = ReligMod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=ReligMod),alpha=.2)+
  xlab("Same-Sex Adoption Religious Conviction")+
  ylab("Same-Sex Adoption Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .18))
SC_Adopt.RCatRelig.Plot

#Test simple slopes
SC_Adopt.RCatRelig <- plotSlopes(SC_Adopt.2way, plotx="Adopt_RCcmr", modx="Religcmr", 
                                 xlab = "Same-Sex Adoption Religious Conviction", ylab = "Same-Sex Adoption Moral Conviction", 
                                 modxVals = c(-1.61, 0, 1.61), xlim = c (-1.38, 2.62), plotPoints = FALSE, 
                                 legendTitle = "Religiosity")

SC_Adopt.RCatRelig.test <- testSlopes(SC_Adopt.RCatRelig)
SC_Adopt.RCatRelig.test$hypotests

#Plotting the Political orientation by Religiosity interaction predicting moral conviction.
#The effect of Religiosity at moderates (midpoint) and one standard deviation above (Conservatives) and standard deviation below (Liberals) 
summary(SC_Adopt.2way)
describe(SCAdopt$Religcmr)
describe(SCAdopt$POmr)

SC_Adopt.RelgAtPO.fitted<-effect('POmr:Religcmr', SC_Adopt.2way,
                                 xlevels=list(POmr=c(-2.52, 0 , 2.52), 
                                              Religcmr = seq(from = -1.87, to = 2.13, by =1)), 
                                 se=TRUE,confidence.level=.95)

SC_Adopt.RelgAtPO.Eff<-as.data.frame(SC_Adopt.RelgAtPO.fitted)

SC_Adopt.RelgAtPO.Eff$POmod<-factor(SC_Adopt.RelgAtPO.Eff$POmr,
                                    levels=c(-2.52,0,2.52),
                                    labels=c("Liberal","Moderate","Conservative"))

SC_Adopt.RelgAtPO.Plot <-ggplot(data = SC_Adopt.RelgAtPO.Eff, aes(x = Religcmr, y =fit, group=POmod))+
  coord_cartesian(xlim=c(-1.87, 2.13),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -1.87, to = 2.13, by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=POmod, linetype = POmod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=POmod),alpha=.2)+
  xlab("Religiosity")+
  ylab("Same-sex Adoption Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .18))
SC_Adopt.RelgAtPO.Plot


#Test simple slopes.
SC_Adopt.RelgAtPO <- plotSlopes(SC_Adopt.2way, plotx="Religcmr", modx="POmr", 
                                xlab = "Religiosity", ylab = "Same-sex Adoption Moral Conviction", 
                                modxVals = c(-2.52, 0, 2.52), xlim = c (-1.87, 2.13), plotPoints = F, 
                                legendTitle = "Political Orientation")

SC_Adopt.RelgAtPO.test <- testSlopes(SC_Adopt.RelgAtPO)
SC_Adopt.RelgAtPO.test$hypotests


#Plotting the Political orientation by religious conviction interaction predicting moral conviction.
#The effect of RC at moderates (midpoint) and one standard deviation above (Conservatives) and standard deviation below (Liberals) 
summary(SC_Adopt.2way)
describe(SCAdopt$Adopt_RCcmr)
describe(SCAdopt$POmr)

SC_Adopt.RCatPO.fitted<-effect('POmr:Adopt_RCcmr', SC_Adopt.2way,
                               xlevels=list(POmr=c(-2.52, 0 , 2.52), 
                                            Adopt_RCcmr = seq(from = -1.38, to = 2.62, by =1)), 
                               se=TRUE,confidence.level=.95)

SC_Adopt.RCatPO.Eff<-as.data.frame(SC_Adopt.RCatPO.fitted)

SC_Adopt.RCatPO.Eff$POmod<-factor(SC_Adopt.RCatPO.Eff$POmr,
                                  levels=c(-2.52,0,2.52),
                                  labels=c("Liberal","Moderate","Conservative"))

SC_Adopt.RCatPO.Plot <-ggplot(data = SC_Adopt.RCatPO.Eff, aes(x = Adopt_RCcmr, y =fit, group=POmod))+
  coord_cartesian(xlim=c(-1.38, 2.62),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -1.38, to = 2.62, by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=POmod, linetype = POmod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=POmod),alpha=.2)+
  xlab("Same-sex Adoption Religious Conviction")+
  ylab("Same-sex Adoption Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .18))
SC_Adopt.RCatPO.Plot

#Testing Simple Slopes. 

SC_Adopt.RCatPO <- plotSlopes(SC_Adopt.2way, plotx="Adopt_RCcmr", modx="POmr", 
                              xlab = "Same-sex Adoption Religious Conviction", 
                              ylab = "Same-sex Adoption Moral Conviction", 
                              modxVals = c(-2.52, 0 , 2.52), xlim = c (-1.38, 2.62), plotPoints = FALSE, 
                              legendTitle = "Political Orientation")

SC_Adopt.RCatPO.test <- testSlopes(SC_Adopt.RCatPO)
SC_Adopt.RCatPO.test$hypotests

##########################################################################################
#Prohibit openly gay adults from serving as Boy Scout leaders analysis.

#Data for "Boy Scouts of America continuing to prohibit openly gay adults from serving as Boy Scout leaders" analysis. 
SCBoy<-read.spss("MCRC_Study10_BoyScout_Data.sav", use.value.labels = FALSE, to.data.frame = TRUE,
                 max.value.labels = Inf, trim.factor.names = FALSE,
                 trim_values = TRUE, reencode = NA, use.missings = to.data.frame)

describe(SCBoy$PO)
describe(SCBoy$Relig)
describe(SCBoy$Boy_mc)
describe(SCBoy$Boy_rc)

#Center Religiosity.
SCBoy$Religc <- scale(SCBoy$Relig, center = T, scale = F)
describe(SCBoy$Religc)
class(SCBoy$Religc)
SCBoy$Religc <- as.vector(SCBoy$Religc)

#Center Religious Conviction.
SCBoy$Boy_RCc <- scale(SCBoy$Boy_rc, center = T, scale = F)
describe(SCBoy$Boy_RCc)
class(SCBoy$Boy_RCc)
SCBoy$Boy_RCc <- as.vector(SCBoy$Boy_RCc)

#Mean replace Centered Religiosity.
SCBoy$Religcmr <- ifelse(is.na(SCBoy$Religc),
                         mean(SCBoy$Religc,na.rm=TRUE), SCBoy$Religc)
class(SCBoy$Religcmr)

#Mean replace Centered Religious Conviction.
SCBoy$Boy_RCcmr <- ifelse(is.na(SCBoy$Boy_RCc),
                          mean(SCBoy$Boy_RCc,na.rm=TRUE), SCBoy$Boy_RCc)
class(SCBoy$Boy_RCcmr)

#Mean replace Political Orientation.
SCBoy$POmr <- ifelse(is.na(SCBoy$PO),
                     mean(SCBoy$PO,na.rm=TRUE), SCBoy$PO)

#Mean replace Moral Conviction
SCBoy$Boy_MCmr <- ifelse(is.na(SCBoy$Boy_mc),
                         mean(SCBoy$Boy_mc,na.rm=TRUE), SCBoy$Boy_mc)

describe(SCBoy$POmr)
describe(SCBoy$Religcmr)
describe(SCBoy$Boy_RCcmr)
describe(SCBoy$Boy_MCmr)


##############  Analyses  ################

##Descriptives and Bi-variate correlations.
describe(SCBoy$PO)
describe(SCBoy$Relig)
describe(SCBoy$Boy_rc)
describe(SCBoy$Boy_mc)

cor.test(SCBoy$PO,SCBoy$Relig)
cor.test(SCBoy$PO,SCBoy$Boy_rc)
cor.test(SCBoy$PO,SCBoy$Boy_mc)
cor.test(SCBoy$Relig, SCBoy$Boy_rc)
cor.test(SCBoy$Relig, SCBoy$Boy_mc)
cor.test(SCBoy$Boy_rc, SCBoy$Boy_mc)

#Main effects political orientation, religiosity, religious conviction 

SC_Boy.main <- lm(Boy_MCmr ~ POmr
                  + Religcmr
                  + Boy_RCcmr,
                  data = SCBoy) 
summary(SC_Boy.main)

#Main effects & 2-way Interactions

SC_Boy.2way <- lm(Boy_MCmr ~ POmr
                  + Religcmr
                  + Boy_RCcmr
                  + Religcmr*Boy_RCcmr
                  + POmr*Religcmr
                  + POmr*Boy_RCcmr,
                  data = SCBoy) 
summary(SC_Boy.2way)
anova(SC_Boy.main,SC_Boy.2way)

#Main effects & 2-way Interactions & 3-way interaction

SC_Boy.3way <- lm(Boy_MCmr ~ POmr
                  + Religcmr
                  + Boy_RCcmr
                  + Religcmr*Boy_RCcmr
                  + POmr*Religcmr
                  + POmr*Boy_RCcmr
                  + POmr*Boy_RCcmr*Religcmr,
                  data = SCBoy) 
summary(SC_Boy.3way)
anova(SC_Boy.2way,SC_Boy.3way)

##Table of all the steps
stargazer(SC_Boy.main,SC_Boy.2way,SC_Boy.3way,type="text",
          column.labels = c("Main Effects", "2-way Interactions", "3-way Interaction"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)


#Plotting the Religious Conviction by Religiosity interaction predicting moral conviction.
#The effect of Religious Conviction at mean religiosity and one standard deviation above (high religiosity) and below the mean (low religiosity).
summary(SC_Boy.2way)
describe(SCBoy$Religcmr)
describe(SCBoy$Boy_RCcmr)

SC_Boy.RCatRelig.fitted<-effect('Religcmr:Boy_RCcmr', SC_Boy.2way,
                                xlevels=list(Religcmr=c(-1.61, 0 , 1.61), 
                                             Boy_RCcmr = seq(from = -1.32, to = 2.68, by =1)), 
                                se=TRUE,confidence.level=.95)

SC_Boy.RCatRelig.Eff<-as.data.frame(SC_Boy.RCatRelig.fitted)

SC_Boy.RCatRelig.Eff$ReligMod<-factor(SC_Boy.RCatRelig.Eff$Religcmr,
                                      levels=c(-1.61,0,1.61),
                                      labels=c("Low Religiosity","Mean Religiosity","Hi Religiosity"))

SC_Boy.RCatRelig.Plot <-ggplot(data = SC_Boy.RCatRelig.Eff, aes(x = Boy_RCcmr, y =fit, group=ReligMod))+
  coord_cartesian(xlim=c(-1.32, 2.68),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -1.32, to = 2.68, by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=ReligMod, linetype = ReligMod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=ReligMod),alpha=.2)+
  xlab("Gay Boy Scout Leaders Religious Conviction")+
  ylab("Gay Boy Scout Leaders Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .18))
SC_Boy.RCatRelig.Plot

#Test simple slopes
SC_Boy.RCatRelig <- plotSlopes(SC_Boy.2way, plotx="Boy_RCcmr", modx="Religcmr", 
                               xlab = "Gay Boy Scout Leaders Religious Conviction", 
                               ylab = "Gay Boy Scout Leaders Moral Conviction", 
                               modxVals = c(-1.61, 0, 1.61), xlim = c (-1.32, 2.68), plotPoints = FALSE, 
                               legendTitle = "Religiosity")

SC_Boy.RCatRelig.test <- testSlopes(SC_Boy.RCatRelig)
SC_Boy.RCatRelig.test$hypotests

#Plotting the Political orientation by Religiosity interaction predicting moral conviction.
#The effect of Religiosity at moderates (midpoint) and one standard deviation above (Conservatives) and standard deviation below (Liberals) 
summary(SC_Boy.2way)
describe(SCBoy$Religcmr)
describe(SCBoy$POmr)

SC_Boy.RelgAtPO.fitted<-effect('POmr:Religcmr', SC_Boy.2way,
                               xlevels=list(POmr=c(-2.52, 0 , 2.52), 
                                            Religcmr = seq(from = -1.87, to = 2.13, by =1)), 
                               se=TRUE,confidence.level=.95)

SC_Boy.RelgAtPO.Eff<-as.data.frame(SC_Boy.RelgAtPO.fitted)

SC_Boy.RelgAtPO.Eff$POmod<-factor(SC_Boy.RelgAtPO.Eff$POmr,
                                  levels=c(-2.52,0,2.52),
                                  labels=c("Liberal","Moderate","Conservative"))

SC_Boy.RelgAtPO.Plot <-ggplot(data = SC_Boy.RelgAtPO.Eff, aes(x = Religcmr, y =fit, group=POmod))+
  coord_cartesian(xlim=c(-1.87, 2.13),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -1.87, to = 2.13, by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=POmod, linetype = POmod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=POmod),alpha=.2)+
  xlab("Religiosity")+
  ylab("Gay Boy Scout Leaders Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .18))
SC_Boy.RelgAtPO.Plot


#Test simple slopes.
SC_Boy.RelgAtPO <- plotSlopes(SC_Boy.2way, plotx="Religcmr", modx="POmr", 
                              xlab = "Religiosity", ylab = "Gay Boy Scout Leaders Moral Conviction", 
                              modxVals = c(-2.52, 0, 2.52), xlim = c (-1.87, 2.13), plotPoints = F, 
                              legendTitle = "Political Orientation")

SC_Boy.RelgAtPO.test <- testSlopes(SC_Boy.RelgAtPO)
SC_Boy.RelgAtPO.test$hypotests


#Plotting the Political orientation by religious conviction interaction predicting moral conviction.
#The effect of RC at moderates (midpoint) and one standard deviation above (Conservatives) and standard deviation below (Liberals) 
summary(SC_Boy.2way)
describe(SCBoy$Boy_RCcmr)
describe(SCBoy$POmr)

SC_Boy.RCatPO.fitted<-effect('POmr:Boy_RCcmr', SC_Boy.2way,
                             xlevels=list(POmr=c(-2.52, 0 , 2.52), 
                                          Boy_RCcmr = seq(from = -1.32, to = 2.68, by =1)), 
                             se=TRUE,confidence.level=.95)

SC_Boy.RCatPO.Eff<-as.data.frame(SC_Boy.RCatPO.fitted)

SC_Boy.RCatPO.Eff$POmod<-factor(SC_Boy.RCatPO.Eff$POmr,
                                levels=c(-2.52,0,2.52),
                                labels=c("Liberal","Moderate","Conservative"))

SC_Boy.RCatPO.Plot <-ggplot(data = SC_Boy.RCatPO.Eff, aes(x = Boy_RCcmr, y =fit, group=POmod))+
  coord_cartesian(xlim=c(-1.32, 2.68),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -1.32, to = 2.68, by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=POmod, linetype = POmod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=POmod),alpha=.2)+
  xlab("Gay Boy Scout Leaders Religious Conviction")+
  ylab("Gay Boy Scout Leaders Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .18))
SC_Boy.RCatPO.Plot

#Testing Simple Slopes. 

SC_Boy.RCatPO <- plotSlopes(SC_Boy.2way, plotx="Boy_RCcmr", modx="POmr", 
                            xlab = "Gay Boy Scout Leaders Religious Conviction", 
                            ylab = "Gay Boy Scout Leaders Moral Conviction", 
                            modxVals = c(-2.52, 0 , 2.52), xlim = c (-1.32, 2.68), plotPoints = FALSE, 
                            legendTitle = "Political Orientation")

SC_Boy.RCatPO.test <- testSlopes(SC_Boy.RCatPO)
SC_Boy.RCatPO.test$hypotests

##########################################################################################
#SC LGBT Job Law analysis.

#Data for Laws to protect against job discrimination for LGBT individuals analysis. 
SCJoblaw<-read.spss("MCRC_Study10_LGBTJobLaw_Data.sav", use.value.labels = FALSE, to.data.frame = TRUE,
                    max.value.labels = Inf, trim.factor.names = FALSE,
                    trim_values = TRUE, reencode = NA, use.missings = to.data.frame)


describe(SCJoblaw$PO)
describe(SCJoblaw$Relig)
describe(SCJoblaw$Joblaw_mc)
describe(SCJoblaw$Joblaw_rc)

#Center Religiosity.
SCJoblaw$Religc <- scale(SCJoblaw$Relig, center = T, scale = F)
describe(SCJoblaw$Religc)
class(SCJoblaw$Religc)
SCJoblaw$Religc <- as.vector(SCJoblaw$Religc)

#Center Religious Conviction.
SCJoblaw$Joblaw_RCc <- scale(SCJoblaw$Joblaw_rc, center = T, scale = F)
describe(SCJoblaw$Joblaw_RCc)
class(SCJoblaw$Joblaw_RCc)
SCJoblaw$Joblaw_RCc <- as.vector(SCJoblaw$Joblaw_RCc)

#Mean replace Centered Religiosity.
SCJoblaw$Religcmr <- ifelse(is.na(SCJoblaw$Religc),
                            mean(SCJoblaw$Religc,na.rm=TRUE), SCJoblaw$Religc)
class(SCJoblaw$Religcmr)

#Mean replace Centered Religious Conviction.
SCJoblaw$Joblaw_RCcmr <- ifelse(is.na(SCJoblaw$Joblaw_RCc),
                                mean(SCJoblaw$Joblaw_RCc,na.rm=TRUE), SCJoblaw$Joblaw_RCc)
class(SCJoblaw$Joblaw_RCcmr)

#Mean replace Political Orientation.
SCJoblaw$POmr <- ifelse(is.na(SCJoblaw$PO),
                        mean(SCJoblaw$PO,na.rm=TRUE), SCJoblaw$PO)

#Mean replace Moral Conviction
SCJoblaw$Joblaw_MCmr <- ifelse(is.na(SCJoblaw$Joblaw_mc),
                               mean(SCJoblaw$Joblaw_mc,na.rm=TRUE), SCJoblaw$Joblaw_mc)

describe(SCJoblaw$POmr)
describe(SCJoblaw$Religcmr)
describe(SCJoblaw$Joblaw_RCcmr)
describe(SCJoblaw$Joblaw_MCmr)

##############  Analyses  ################

##Descriptives and Bi-variate correlations.
describe(SCJoblaw$PO)
describe(SCJoblaw$Relig)
describe(SCJoblaw$Joblaw_rc)
describe(SCJoblaw$Joblaw_mc)

cor.test(SCJoblaw$PO,SCJoblaw$Relig)
cor.test(SCJoblaw$PO,SCJoblaw$Joblaw_rc)
cor.test(SCJoblaw$PO,SCJoblaw$Joblaw_mc)
cor.test(SCJoblaw$Relig, SCJoblaw$Joblaw_rc)
cor.test(SCJoblaw$Relig, SCJoblaw$Joblaw_mc)
cor.test(SCJoblaw$Joblaw_rc, SCJoblaw$Joblaw_mc)

#Main effects political orientation, religiosity, religious conviction 

SC_Job.main <- lm(Joblaw_MCmr ~ POmr
                  + Religcmr
                  + Joblaw_RCcmr,
                  data = SCJoblaw) 
summary(SC_Job.main)

#Main effects & 2-way Interactions

SC_Job.2way <- lm(Joblaw_MCmr ~ POmr
                  + Religcmr
                  + Joblaw_RCcmr
                  + Religcmr*Joblaw_RCcmr
                  + POmr*Religcmr
                  + POmr*Joblaw_RCcmr,
                  data = SCJoblaw) 
summary(SC_Job.2way)
anova(SC_Job.main,SC_Job.2way)

#Main effects & 2-way Interactions & 3-way interaction

SC_Job.3way <- lm(Joblaw_MCmr ~ POmr
                  + Religcmr
                  + Joblaw_RCcmr
                  + Religcmr*Joblaw_RCcmr
                  + POmr*Religcmr
                  + POmr*Joblaw_RCcmr
                  + POmr*Joblaw_RCcmr*Religcmr,
                  data = SCJoblaw) 
summary(SC_Job.3way)
anova(SC_Job.2way,SC_Job.3way)

##Table of all the steps
stargazer(SC_Job.main,SC_Job.2way,SC_Job.3way,type="text",
          column.labels = c("Main Effects", "2-way Interactions", "3-way Interaction"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

#Plotting the Religious Conviction by Religiosity interaction predicting moral conviction.
#The effect of Religious Conviction at mean religiosity, one standard deviation above (high religiosity), and one standard deviation below (low religiosity).
summary(SC_Job.2way)
describe(SCJoblaw$Religcmr)
describe(SCJoblaw$Joblaw_RCcmr)

SC_Job.RCatRelig.fitted<-effect('Religcmr:Joblaw_RCcmr', SC_Job.2way,
                                xlevels=list(Religcmr=c(-1.61, 0 , 1.61), 
                                             Joblaw_RCcmr = seq(from = -1.14, to = 2.86, by =1)), 
                                se=TRUE,confidence.level=.95)

SC_Job.RCatRelig.Eff<-as.data.frame(SC_Job.RCatRelig.fitted)

SC_Job.RCatRelig.Eff$ReligMod<-factor(SC_Job.RCatRelig.Eff$Religcmr,
                                      levels=c(-1.61,0,1.61),
                                      labels=c("Low Religiosity","Mean Religiosity","Hi Religiosity"))

SC_Job.RCatRelig.Plot <-ggplot(data = SC_Job.RCatRelig.Eff, aes(x = Joblaw_RCcmr, y =fit, group=ReligMod))+
  coord_cartesian(xlim=c(-1.14, 2.86),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -1.14, to = 2.86, by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=ReligMod, linetype = ReligMod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=ReligMod),alpha=.2)+
  xlab("LGBT Job Protection Religious Conviction")+
  ylab("LGBT Job Protection Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .18))
SC_Job.RCatRelig.Plot

#Test simple slopes
SC_Job.RCatRelig <- plotSlopes(SC_Job.2way, plotx="Joblaw_RCcmr", modx="Religcmr", 
                               xlab = "LGBT Job Protection Religious Conviction", 
                               ylab = "LGBT Job Protection Moral Conviction", 
                               modxVals = c(-1.61, 0, 1.61), xlim = c (-1.14, 2.86), plotPoints = FALSE, 
                               legendTitle = "Religiosity")

SC_Job.RCatRelig.test <- testSlopes(SC_Job.RCatRelig)
SC_Job.RCatRelig.test$hypotests

#Plotting the Political orientation by Religiosity interaction predicting moral conviction.
#The effect of Religiosity at moderates (midpoint) and one standard deviation above (Conservatives) and standard deviation below (Liberals)
summary(SC_Job.2way)
describe(SCJoblaw$Religcmr)
describe(SCJoblaw$POmr)

SC_Job.RelgAtPO.fitted<-effect('POmr:Religcmr', SC_Job.2way,
                               xlevels=list(POmr=c(-2.52, 0 , 2.52), 
                                            Religcmr = seq(from = -1.87, to = 2.13, by =1)), 
                               se=TRUE,confidence.level=.95)

SC_Job.RelgAtPO.Eff<-as.data.frame(SC_Job.RelgAtPO.fitted)

SC_Job.RelgAtPO.Eff$POmod<-factor(SC_Job.RelgAtPO.Eff$POmr,
                                  levels=c(-2.52,0,2.52),
                                  labels=c("Liberal","Moderate","Conservative"))

SC_Job.RelgAtPO.Plot <-ggplot(data = SC_Job.RelgAtPO.Eff, aes(x = Religcmr, y =fit, group=POmod))+
  coord_cartesian(xlim=c(-1.87, 2.13),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -1.87, to = 2.13, by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=POmod, linetype = POmod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=POmod),alpha=.2)+
  xlab("Religiosity")+
  ylab("LGBT Job Protection Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .18))
SC_Job.RelgAtPO.Plot


#Test simple slopes.
SC_Job.RelgAtPO <- plotSlopes(SC_Job.2way, plotx="Religcmr", modx="POmr", 
                              xlab = "Religiosity", ylab = "LGBT Job Protection Moral Conviction", 
                              modxVals = c(-2.52, 0, 2.52), xlim = c (-1.87, 2.13), plotPoints = F, 
                              legendTitle = "Political Orientation")

SC_Job.RelgAtPO.test <- testSlopes(SC_Job.RelgAtPO)
SC_Job.RelgAtPO.test$hypotests


#Plotting the Political orientation by religious conviction interaction predicting moral conviction.
#The effect of RC at moderates (midpoint) and one standard deviation above (Conservatives) and standard deviation below (Liberals)
summary(SC_Job.2way)
describe(SCJoblaw$Joblaw_RCcmr)
describe(SCJoblaw$POmr)

SC_Job.RCatPO.fitted<-effect('POmr:Joblaw_RCcmr', SC_Job.2way,
                             xlevels=list(POmr=c(-2.52, 0 , 2.52), 
                                          Joblaw_RCcmr = seq(from = -1.14, to = 2.86, by =1)), 
                             se=TRUE,confidence.level=.95)

SC_Job.RCatPO.Eff<-as.data.frame(SC_Job.RCatPO.fitted)

SC_Job.RCatPO.Eff$POmod<-factor(SC_Job.RCatPO.Eff$POmr,
                                levels=c(-2.52,0,2.52),
                                labels=c("Liberal","Moderate","Conservative"))

SC_Job.RCatPO.Plot <-ggplot(data = SC_Job.RCatPO.Eff, aes(x = Joblaw_RCcmr, y =fit, group=POmod))+
  coord_cartesian(xlim=c(-1.14, 2.86),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -1.14, to = 2.86, by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=POmod, linetype = POmod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=POmod),alpha=.2)+
  xlab("LGBT Job Protection Religious Conviction")+
  ylab("LGBT Job Protection Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .18))
SC_Job.RCatPO.Plot

#Testing Simple Slopes. 

SC_Job.RCatPO <- plotSlopes(SC_Job.2way, plotx="Joblaw_RCcmr", modx="POmr", 
                            xlab = "LGBT Job Protection Religious Conviction", 
                            ylab = "LGBT Job Protection Moral Conviction", 
                            modxVals = c(-2.52, 0 , 2.52), xlim = c (-1.14, 2.86), plotPoints = FALSE, 
                            legendTitle = "Political Orientation")

SC_Job.RCatPO.test <- testSlopes(SC_Job.RCatPO)
SC_Job.RCatPO.test$hypotests


##########################################################################################
#SC Affirmative Action analysis.

#Data for Affirmative Action analysis. 
SCAAct<-read.spss("MCRC_Study10_AffirmativeAction_Data.sav", use.value.labels = FALSE, to.data.frame = TRUE,
                  max.value.labels = Inf, trim.factor.names = FALSE,
                  trim_values = TRUE, reencode = NA, use.missings = to.data.frame)

describe(SCAAct$PO)
describe(SCAAct$Relig)
describe(SCAAct$AAct_mc)
describe(SCAAct$AAct_rc)

#Center Religiosity.
SCAAct$Religc <- scale(SCAAct$Relig, center = T, scale = F)
describe(SCAAct$Religc)
class(SCAAct$Religc)
SCAAct$Religc <- as.vector(SCAAct$Religc)

#Center Religious Conviction.
SCAAct$AAct_RCc <- scale(SCAAct$AAct_rc, center = T, scale = F)
describe(SCAAct$AAct_RCc)
class(SCAAct$AAct_RCc)
SCAAct$AAct_RCc <- as.vector(SCAAct$AAct_RCc)

#Mean replace Centered Religiosity.
SCAAct$Religcmr <- ifelse(is.na(SCAAct$Religc),
                          mean(SCAAct$Religc,na.rm=TRUE), SCAAct$Religc)
class(SCAAct$Religcmr)

#Mean replace Centered Religious Conviction.
SCAAct$AAct_RCcmr <- ifelse(is.na(SCAAct$AAct_RCc),
                            mean(SCAAct$AAct_RCc,na.rm=TRUE), SCAAct$AAct_RCc)
class(SCAAct$AAct_RCcmr)

#Mean replace Political Orientation.
SCAAct$POmr <- ifelse(is.na(SCAAct$PO),
                      mean(SCAAct$PO,na.rm=TRUE), SCAAct$PO)

#Mean replace Moral Conviction
SCAAct$AAct_MCmr <- ifelse(is.na(SCAAct$AAct_mc),
                           mean(SCAAct$AAct_mc,na.rm=TRUE), SCAAct$AAct_mc)

describe(SCAAct$POmr)
describe(SCAAct$Religcmr)
describe(SCAAct$AAct_RCcmr)
describe(SCAAct$AAct_MCmr)

##############  Analyses  ################

##Descriptives and Bi-variate correlations.
describe(SCAAct$PO)
describe(SCAAct$Relig)
describe(SCAAct$AAct_rc)
describe(SCAAct$AAct_mc)

cor.test(SCAAct$PO,SCAAct$Relig)
cor.test(SCAAct$PO,SCAAct$AAct_rc)
cor.test(SCAAct$PO,SCAAct$AAct_mc)
cor.test(SCAAct$Relig, SCAAct$AAct_rc)
cor.test(SCAAct$Relig, SCAAct$AAct_mc)
cor.test(SCAAct$AAct_rc, SCAAct$AAct_mc)

#Main effects political orientation, religiosity,religious conviction 

SC_AAct.main <- lm(AAct_MCmr ~ POmr
                   + Religcmr
                   + AAct_RCcmr,
                   data = SCAAct) 
summary(SC_AAct.main)

#Main effects & 2-way Interactions
SC_AAct.2way <- lm(AAct_MCmr ~ POmr
                   + Religcmr
                   + AAct_RCcmr
                   + Religcmr*AAct_RCcmr
                   + POmr*Religcmr
                   + POmr*AAct_RCcmr,
                   data = SCAAct) 
summary(SC_AAct.2way)
anova(SC_AAct.main,SC_AAct.2way)

#Main effects & 2-way Interactions & 3-way interaction
SC_AAct.3way <- lm(AAct_MCmr ~ POmr
                   + Religcmr
                   + AAct_RCcmr
                   + Religcmr*AAct_RCcmr
                   + POmr*Religcmr
                   + POmr*AAct_RCcmr
                   + POmr*AAct_RCcmr*Religcmr,
                   data = SCAAct) 
summary(SC_AAct.3way)
anova(SC_AAct.2way,SC_AAct.3way)

##Table of all the steps
stargazer(SC_AAct.main,SC_AAct.2way,SC_AAct.3way,type="text",
          column.labels = c("Main Effects", "2-way Interactions", "3-way Interaction"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

#Main effects & Significant 2-way Interactions
SC_AAct.2way.sig <- lm(AAct_MCmr ~ POmr
                       + Religcmr
                       + AAct_RCcmr
                       + Religcmr*AAct_RCcmr,
                       data = SCAAct) 
summary(SC_AAct.2way.sig)

#Plotting the Religious Conviction by Religiosity interaction predicting moral conviction.
#The effect of Religious Conviction at mean religiosity, one standard deviation above (high religiosity), and one standard deviation below (low religiosity).
summary(SC_AAct.2way.sig)
describe(SCAAct$Religcmr)
describe(SCAAct$AAct_RCcmr)

SC_AAct.RCatRelig.fitted<-effect('Religcmr:AAct_RCcmr', SC_AAct.2way.sig,
                                 xlevels=list(Religcmr=c(-1.61, 0 , 1.61), 
                                              AAct_RCcmr = seq(from = -0.88, to = 3.12, by =1)), 
                                 se=TRUE,confidence.level=.95)

SC_AAct.RCatRelig.Eff<-as.data.frame(SC_AAct.RCatRelig.fitted)

SC_AAct.RCatRelig.Eff$ReligMod<-factor(SC_AAct.RCatRelig.Eff$Religcmr,
                                       levels=c(-1.61,0,1.61),
                                       labels=c("Low Religiosity","Mean Religiosity","Hi Religiosity"))

SC_AAct.RCatRelig.Plot <-ggplot(data = SC_AAct.RCatRelig.Eff, aes(x = AAct_RCcmr, y =fit, group=ReligMod))+
  coord_cartesian(xlim=c(-0.88, 3.12),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -0.88, to = 3.12, by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=ReligMod, linetype = ReligMod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=ReligMod),alpha=.2)+
  xlab("Affirmative Action Religious Conviction")+
  ylab("Affirmative Action Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .18))
SC_AAct.RCatRelig.Plot

#Test simple slopes
SC_AAct.RCatRelig <- plotSlopes(SC_AAct.2way.sig, plotx="AAct_RCcmr", modx="Religcmr", 
                                xlab = "Affirmative Action Religious Conviction", 
                                ylab = "Affirmative Action Moral Conviction", 
                                modxVals = c(-1.61, 0, 1.61), xlim = c (-0.88, 3.12), plotPoints = FALSE, 
                                legendTitle = "Religiosity")

SC_AAct.RCatRelig.test <- testSlopes(SC_AAct.RCatRelig)
SC_AAct.RCatRelig.test$hypotests