####################################################################
####################################################################
#######  Reigious Convcition Perdicting Moral Conviction   #########

library(rockchalk) #Graphing simple slopes; moderation
library(stargazer) #Handy regression tables
library(foreign)  # Read in SPSS
library(gvlma)   #helper on diagnostics
library(effects) #helper on visualizing interactions - Uses lattice
library(sjPlot)  #helper on visualizing interactions - uses ggplot
library(ggplot2) #All the graphs
library(psych) #handy for descriptives, etc
library(dplyr) 

#set working directory
setwd("C:/Users/Brittany/Box Sync/RC Project/Data sets/Study 11 (USAMP BH)")

##########################################################################################
##########################################################################################
#USAMP data. 

#Read in data. 
USAMP <-read.spss("MCRC_Study11_Data.sav", use.value.labels = FALSE, to.data.frame = TRUE,
                  max.value.labels = Inf, trim.factor.names = FALSE,
                  trim_values = TRUE, reencode = NA, use.missings = to.data.frame)

describe(USAMP$PO)
describe(USAMP$RC)
describe(USAMP$MC)


#Center Religious Conviction.
USAMP$RCc <- scale(USAMP$RC, center = T, scale = F)
describe(USAMP$RCc)
class(USAMP$RCc)
USAMP$RCc <- as.vector(USAMP$RCc)

#Mean replace Centered Religious Conviction.
USAMP$RCcmr <- ifelse(is.na(USAMP$RCc),
                      mean(USAMP$RCc,na.rm=TRUE), USAMP$RCc)
class(USAMP$RCcmr)

#Mean replace Political Orientation.
USAMP$POmr <- ifelse(is.na(USAMP$PO),
                     mean(USAMP$PO,na.rm=TRUE), USAMP$PO)

#Mean replace Moral Conviction
USAMP$MCmr <- ifelse(is.na(USAMP$MC),
                     mean(USAMP$MC,na.rm=TRUE), USAMP$MC)

describe(USAMP$POmr)
describe(USAMP$RCcmr)
describe(USAMP$MCmr)

##############  Analyses  ################

##Descriptives and Bi-variate correlations.
describe(USAMP$PO)
describe(USAMP$RC)
describe(USAMP$MC)

cor.test(USAMP$PO,USAMP$RC)
cor.test(USAMP$PO,USAMP$MC)
cor.test(USAMP$RC, USAMP$MC)

#Main effects political orientation and religious conviction 

USAMP.main <- lm(MCmr ~ POmr
                 + RCcmr,
                 data = USAMP) 
summary(USAMP.main)

#Main effects & 2-way Interactions

USAMP.2way <- lm(MCmr ~ POmr
                 + RCcmr
                 + POmr*RCcmr,
                 data = USAMP) 
summary(USAMP.2way)
anova(USAMP.main,USAMP.2way)


##Table of all the steps
stargazer(USAMP.main,USAMP.2way,type="text",
          column.labels = c("Main Effects", "2-way Interactions"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)


#Plotting the Political orientation by religious conviction interaction predicting moral conviction.
#The effect of RC at moderates (midpoint) and one standard deviation above (Conservatives) and standard deviation below (Liberals)

describe(USAMP$RCcmr)
describe(USAMP$POmr)

USAMP.2way.fitted<-effect('POmr:RCcmr', USAMP.2way,
                          xlevels=list(POmr=c(-1.73, 0 , 1.73), 
                                       RCcmr = seq(from = -1.85, to = 2.15, by =1)), 
                          se=TRUE,confidence.level=.95)

USAMP.2way.Eff<-as.data.frame(USAMP.2way.fitted)

USAMP.2way.Eff$POmod<-factor(USAMP.2way.Eff$POmr,
                             levels=c(-1.73,0,1.73),
                             labels=c("Liberal","Moderate","Conservative"))

USAMP.2way.Plot.RCAtPO <-ggplot(data = USAMP.2way.Eff, aes(x = RCcmr, y =fit, group=POmod))+
  coord_cartesian(xlim=c(-1.85, 2.15),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -1.85, to = 2.15, by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=POmod, linetype = POmod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=POmod),alpha=.2)+
  xlab("Same-Sex Marriage Religious Conviction")+
  ylab("Same-Sex Marriage Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .18))
USAMP.2way.Plot.RCAtPO


#Testing Simple Slopes. 
describe(MCmanipRegFit$RCcmr)
describe(MCmanipRegFit$POmr)

USAMP.RCAtPO <- plotSlopes(USAMP.2way, plotx="RCcmr", modx="POmr", 
                           xlab = "Same-Sex Marriage Religious Conviction", ylab = "Same-Sex Marriage Moral Conviction", 
                           modxVals = c(-1.73, 0 , 1.73), xlim = c (-1.85, 2.15), plotPoints = FALSE, 
                           legendTitle = "Political Orientation")

USAMP.RCAtPO.test <- testSlopes(USAMP.RCAtPO)
USAMP.RCAtPO.test$hypotests