####################################################################
####################################################################
#######  Reigious Convcition Perdicting Moral Conviction   #########

library(rockchalk) #Graphing simple slopes; moderation
library(stargazer) #Handy regression tables
library(foreign)  # Read in SPSS
library(gvlma)   #helper on diagnostics
library(effects) #helper on visualizing interactions - Uses lattice
library(sjPlot)  #helper on visualizing interactions - uses ggplot
library(ggplot2) #All the graphs
library(psych) #handy for descriptives, etc
library(dplyr) 

#set working directory
setwd("C:/Users/Brittany/Box Sync/RC Project/Data sets/Study 12 (MUMPE BH)")

##########################################################################################
##########################################################################################
#MUMPE data. 

#Read in data. 
MUMPE <-read.spss("MCRC_Study12_Data.sav", use.value.labels = FALSE, to.data.frame = TRUE,
                  max.value.labels = Inf, trim.factor.names = FALSE,
                  trim_values = TRUE, reencode = NA, use.missings = to.data.frame)

describe(MUMPE$PO)
describe(MUMPE$CC_rc)
describe(MUMPE$CC_mc)


#Center Religious Conviction.
MUMPE$RCc <- scale(MUMPE$CC_rc, center = T, scale = F)
describe(MUMPE$RCc)
class(MUMPE$RCc)
MUMPE$RCc <- as.vector(MUMPE$RCc)

#Mean replace Centered Religious Conviction.
MUMPE$RCcmr <- ifelse(is.na(MUMPE$RCc),
                      mean(MUMPE$RCc,na.rm=TRUE), MUMPE$RCc)
class(MUMPE$RCcmr)

#Mean replace Political Orientation.
MUMPE$POmr <- ifelse(is.na(MUMPE$PO),
                     mean(MUMPE$PO,na.rm=TRUE), MUMPE$PO)

#Mean replace Moral Conviction
MUMPE$MCmr <- ifelse(is.na(MUMPE$CC_mc),
                     mean(MUMPE$CC_mc,na.rm=TRUE), MUMPE$CC_mc)

describe(MUMPE$POmr)
describe(MUMPE$RCcmr)
describe(MUMPE$MCmr)

##############  Analyses  ################

##Descriptives and Bi-variate correlations.
describe(MUMPE$PO)
describe(MUMPE$CC_rc)
describe(MUMPE$CC_mc)

cor.test(MUMPE$PO,MUMPE$CC_rc)
cor.test(MUMPE$PO,MUMPE$CC_mc)
cor.test(MUMPE$CC_rc, MUMPE$CC_mc)

#Main effects political orientation and religious conviction 
MUMPE.main <- lm(MCmr ~ POmr
                 + RCcmr,
                 data = MUMPE) 
summary(MUMPE.main)

#Main effects & 2-way Interactions
MUMPE.2way <- lm(MCmr ~ POmr
                 + RCcmr
                 + POmr*RCcmr,
                 data = MUMPE) 
summary(MUMPE.2way)
anova(MUMPE.main,MUMPE.2way)


##Table of all the steps
stargazer(MUMPE.main,MUMPE.2way,type="text",
          column.labels = c("Main Effects", "2-way Interactions"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)