####################################################################
####################################################################
#######  Reigious Convcition Perdicting Moral Conviction   #########

library(rockchalk) #Graphing simple slopes; moderation
library(stargazer) #Handy regression tables
library(foreign)  # Read in SPSS
library(gvlma)   #helper on diagnostics
library(effects) #helper on visualizing interactions - Uses lattice
library(sjPlot)  #helper on visualizing interactions - uses ggplot
library(ggplot2) #All the graphs
library(psych) #handy for descriptives, etc
library(dplyr) 

#set working directory
setwd("C:/Users/Brittany/Box Sync/RC Project/Data sets/Study 14 (Zaal S3 BH)")

##########################################################################################
##########################################################################################
#Zaal Series Study 3 RegFit SSM data. 

#Read in data. 
RegFitSSM <-read.spss("MCRC_Study14_Data.sav", use.value.labels = FALSE, to.data.frame = TRUE,
                      max.value.labels = Inf, trim.factor.names = FALSE,
                      trim_values = TRUE, reencode = NA, use.missings = to.data.frame)

describe(RegFitSSM$PO)
describe(RegFitSSM$RC)
describe(RegFitSSM$MC)


#Center Religious Conviction.
RegFitSSM$RCc <- scale(RegFitSSM$RC, center = T, scale = F)
describe(RegFitSSM$RCc)
class(RegFitSSM$RCc)
RegFitSSM$RCc <- as.vector(RegFitSSM$RCc)

#Mean replace Centered Religious Conviction.
RegFitSSM$RCcmr <- ifelse(is.na(RegFitSSM$RCc),
                          mean(RegFitSSM$RCc,na.rm=TRUE), RegFitSSM$RCc)
class(RegFitSSM$RCcmr)

#Mean replace Political Orientation.
RegFitSSM$POmr <- ifelse(is.na(RegFitSSM$PO),
                         mean(RegFitSSM$PO,na.rm=TRUE), RegFitSSM$PO)

#Mean replace Moral Conviction
RegFitSSM$MCmr <- ifelse(is.na(RegFitSSM$MC),
                         mean(RegFitSSM$MC,na.rm=TRUE), RegFitSSM$MC)

describe(RegFitSSM$POmr)
describe(RegFitSSM$RCcmr)
describe(RegFitSSM$MCmr)

##############  Analyses  ################

##Descriptives and Bi-variate correlations.
describe(RegFitSSM$PO)
describe(RegFitSSM$RC)
describe(RegFitSSM$MC)

cor.test(RegFitSSM$PO,RegFitSSM$RC)
cor.test(RegFitSSM$PO,RegFitSSM$MC)
cor.test(RegFitSSM$RC, RegFitSSM$MC)

#Main effects political orientation and religious conviction 

RegFitSSM.main <- lm(MCmr ~ POmr
                     + RCcmr,
                     data = RegFitSSM) 
summary(RegFitSSM.main)

#Main effects & 2-way Interactions

RegFitSSM.2way <- lm(MCmr ~ POmr
                     + RCcmr
                     + POmr*RCcmr,
                     data = RegFitSSM) 
summary(RegFitSSM.2way)
anova(RegFitSSM.main,RegFitSSM.2way)


##Table of all the steps
stargazer(RegFitSSM.main,RegFitSSM.2way,type="text",
          column.labels = c("Main Effects", "2-way Interactions"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

#Plotting the Political orientation by religious conviction interaction predicting moral conviction.
#The effect of RC at moderates (midpoint) and one standard deviation above (Conservatives) and standard deviation below (Liberals)

describe(RegFitSSM$RCcmr)
describe(RegFitSSM$POmr)

RegFitSSM.2way.fitted<-effect('POmr:RCcmr', RegFitSSM.2way,
                              xlevels=list(POmr=c(-2.22, 0 , 2.22), 
                                           RCcmr = seq(from = -1.36, to = 2.64, by =1)), 
                              se=TRUE,confidence.level=.95)

RegFitSSM.2way.Eff<-as.data.frame(RegFitSSM.2way.fitted)

RegFitSSM.2way.Eff$POmod<-factor(RegFitSSM.2way.Eff$POmr,
                                 levels=c(-2.22,0,2.22),
                                 labels=c("Liberal","Moderate","Conservative"))

RegFitSSM.2way.Plot.RCAtPO <-ggplot(data = RegFitSSM.2way.Eff, aes(x = RCcmr, y =fit, group=POmod))+
  coord_cartesian(xlim=c(-1.36, 2.64),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -1.36, to = 2.64, by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=POmod, linetype = POmod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=POmod),alpha=.2)+
  xlab("Same-Sex Marriage Religious Conviction")+
  ylab("Same-Sex Marriage Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .18))
RegFitSSM.2way.Plot.RCAtPO


#Testing Simple Slopes. 
describe(RegFitSSM$RCcmr)
describe(RegFitSSM$POmr)

RegFitSSM.RCAtPO <- plotSlopes(RegFitSSM.2way, plotx="RCcmr", modx="POmr", 
                               xlab = "Same-Sex Marriage Religious Conviction", ylab = "Same-Sex Marriage Moral Conviction", 
                               modxVals = c(-2.22, 0 , 2.22), xlim = c (-1.36, 2.64), plotPoints = FALSE, 
                               legendTitle = "Political Orientation")

RegFitSSM.RCAtPO.test <- testSlopes(RegFitSSM.RCAtPO)
RegFitSSM.RCAtPO.test$hypotests
