####################################################################
####################################################################
#######  Reigious Convcition Perdicting Moral Conviction   #########

library(rockchalk) #Graphing simple slopes; moderation
library(stargazer) #Handy regression tables
library(foreign)  # Read in SPSS
library(gvlma)   #helper on diagnostics
library(effects) #helper on visualizing interactions - Uses lattice
library(sjPlot)  #helper on visualizing interactions - uses ggplot
library(ggplot2) #All the graphs
library(psych) #handy for descriptives, etc
library(dplyr) 

#set working directory
setwd("C:/Users/Brittany/Box Sync/RC Project/Data sets/Study 15 (MA Forcasting BH)")

##########################################################################################
##########################################################################################
#### MA forcasting Data. 

##########################################################################################
#MA forcasting Abortion analysis.

#Data. 
MAF.Abort<-read.spss("MCRC_Study15_Abortion_Data.sav", use.value.labels = FALSE, to.data.frame = TRUE,
                     max.value.labels = Inf, trim.factor.names = FALSE,
                     trim_values = TRUE, reencode = NA, use.missings = to.data.frame)


describe(MAF.Abort$PO)
describe(MAF.Abort$Relig)
describe(MAF.Abort$Abort_MC)
describe(MAF.Abort$Abort_RC)

#Center Religiosity.
MAF.Abort$Religc <- scale(MAF.Abort$Relig, center = T, scale = F)
describe(MAF.Abort$Religc)
class(MAF.Abort$Religc)
MAF.Abort$Religc <- as.vector(MAF.Abort$Religc)

#Center Religious Conviction.
MAF.Abort$Abort_RCc <- scale(MAF.Abort$Abort_RC, center = T, scale = F)
describe(MAF.Abort$Abort_RCc)
class(MAF.Abort$Abort_RCc)
MAF.Abort$Abort_RCc <- as.vector(MAF.Abort$Abort_RCc)

#Mean replace Centered Religiosity.
MAF.Abort$Religcmr <- ifelse(is.na(MAF.Abort$Religc),
                             mean(MAF.Abort$Religc,na.rm=TRUE), MAF.Abort$Religc)
class(MAF.Abort$Religcmr)

#Mean replace Centered Religious Conviction.
MAF.Abort$Abort_RCcmr <- ifelse(is.na(MAF.Abort$Abort_RCc),
                                mean(MAF.Abort$Abort_RCc,na.rm=TRUE), MAF.Abort$Abort_RCc)
class(MAF.Abort$Abort_RCcmr)

#Mean replace Political Orientation.
MAF.Abort$POmr <- ifelse(is.na(MAF.Abort$PO),
                         mean(MAF.Abort$PO,na.rm=TRUE), MAF.Abort$PO)

#Mean replace Moral Conviction
MAF.Abort$Abort_MCmr <- ifelse(is.na(MAF.Abort$Abort_MC),
                               mean(MAF.Abort$Abort_MC,na.rm=TRUE), MAF.Abort$Abort_MC)

describe(MAF.Abort$POmr)
describe(MAF.Abort$Religcmr)
describe(MAF.Abort$Abort_RCcmr)
describe(MAF.Abort$Abort_MCmr)

##############  Analyses  ################

##Descriptives and Bi-variate correlations.
describe(MAF.Abort$PO)
describe(MAF.Abort$Relig)
describe(MAF.Abort$Abort_RC)
describe(MAF.Abort$Abort_MC)

cor.test(MAF.Abort$PO,MAF.Abort$Relig)
cor.test(MAF.Abort$PO,MAF.Abort$Abort_RC)
cor.test(MAF.Abort$PO,MAF.Abort$Abort_MC)
cor.test(MAF.Abort$Relig, MAF.Abort$Abort_RC)
cor.test(MAF.Abort$Relig, MAF.Abort$Abort_MC)
cor.test(MAF.Abort$Abort_RC, MAF.Abort$Abort_MC)

#Main effects political orientation, religiosity, religious conviction 

MAF.Abort.main <- lm(Abort_MCmr ~ POmr
                     + Religcmr
                     + Abort_RCcmr,
                     data = MAF.Abort) 
summary(MAF.Abort.main)

#Main effects & 2-way Interactions
MAF.Abort.2way <- lm(Abort_MCmr ~ POmr
                     + Religcmr
                     + Abort_RCcmr
                     + Religcmr*Abort_RCcmr
                     + POmr*Religcmr
                     + POmr*Abort_RCcmr,
                     data = MAF.Abort) 
summary(MAF.Abort.2way)
anova(MAF.Abort.main,MAF.Abort.2way)

#Main effects & 2-way Interactions & 3-way interaction
MAF.Abort.3way <- lm(Abort_MCmr ~ POmr
                     + Religcmr
                     + Abort_RCcmr
                     + Religcmr*Abort_RCcmr
                     + POmr*Religcmr
                     + POmr*Abort_RCcmr
                     + POmr*Abort_RCcmr*Religcmr,
                     data = MAF.Abort) 
summary(MAF.Abort.3way)
anova(MAF.Abort.2way,MAF.Abort.3way)

##Table of all the steps
stargazer(MAF.Abort.main,MAF.Abort.2way,MAF.Abort.3way,type="text",
          column.labels = c("Main Effects", "2-way Interactions", "3-way Interaction"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

#Create High and Low PO, (Liberal, Conservative, Moderate)
describe(MAF.Abort$POmr)

MAF.Abort$POmrHi <- (MAF.Abort$POmr - sd(MAF.Abort$POmr))
MAF.Abort$POmrLo <- (MAF.Abort$POmr + sd(MAF.Abort$POmr))

describe(MAF.Abort$POmrHi)
describe(MAF.Abort$POmrLo)

#Simple Interaction of Religiosity and Religious Conviction for Hi PO (Conservatives).
MAF.Abort.3way.HiPO <- lm(Abort_MCmr ~ POmrHi
                          + Religcmr
                          + Abort_RCcmr
                          + Religcmr*Abort_RCcmr
                          + POmrHi*Religcmr
                          + POmrHi*Abort_RCcmr
                          + POmrHi*Abort_RCcmr*Religcmr,
                          data = MAF.Abort) 
summary(MAF.Abort.3way.HiPO)

#Simple Interaction of Religiosity and Religious Conviction for Lo PO (Liberals).
MAF.Abort.3way.LoPO <- lm(Abort_MCmr ~ POmrLo
                          + Religcmr
                          + Abort_RCcmr
                          + Religcmr*Abort_RCcmr
                          + POmrLo*Religcmr
                          + POmrLo*Abort_RCcmr
                          + POmrLo*Abort_RCcmr*Religcmr,
                          data = MAF.Abort) 
summary(MAF.Abort.3way.LoPO)

#Three simple interactions for Liberals, Moderates, and Conservatives. 
stargazer(MAF.Abort.3way.LoPO, MAF.Abort.3way, MAF.Abort.3way.HiPO, type="text",
          column.labels = c("Liberals", "Moderates", "Conservatives"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

#Plotting the Religious Conviction by Religiosity by Political Orientation interaction predicting moral conviction
#The effect of Religious Conviction at mean religiosity, one standard deviation above (high religiosity), and one standard deviation below (low religiosity).
#FOR Liberals (- 1SD), Moderates (Midpoint), and Conservatives (+1SD)
summary(MAF.Abort.3way)
describe(MAF.Abort$POmr)
describe(MAF.Abort$Religcmr)
describe(MAF.Abort$Abort_RCcmr)

MAF.Abort.RCatReligatPO.fitted<-effect('POmr:Religcmr:Abort_RCcmr', MAF.Abort.3way,
                                       xlevels=list(POmr=c(-2.28, 0 , 2.28),
                                                    Religcmr=c(-1.38, 0 , 1.38),
                                                    Abort_RCcmr = seq(from = -1.19, to = 2.81, by =1)), 
                                       se=TRUE,confidence.level=.95)

MAF.Abort.RCatReligatPO.Eff<-as.data.frame(MAF.Abort.RCatReligatPO.fitted)

MAF.Abort.RCatReligatPO.Eff$ReligMod<-factor(MAF.Abort.RCatReligatPO.Eff$Religcmr,
                                             levels=c(-1.38,0,1.38),
                                             labels=c("Low Religiosity","Mean Religiosity","Hi Religiosity"))

MAF.Abort.RCatReligatPO.Eff$POMod<-factor(MAF.Abort.RCatReligatPO.Eff$POmr,
                                          levels=c(-2.28,0,2.28),
                                          labels=c("Liberals","Moderates","Conservatives"))

MAF.Abort.RCatReligatPO.Plot <-ggplot(data = MAF.Abort.RCatReligatPO.Eff, aes(x = Abort_RCcmr, y =fit, group=ReligMod))+
  facet_grid(~POMod)+
  coord_cartesian(xlim=c(-1.19, 2.81),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -1.19, to = 2.81, by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=ReligMod, linetype = ReligMod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=ReligMod),alpha=.2)+
  xlab("Abortion Religious Conviction")+
  ylab("Abortion Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .18))
MAF.Abort.RCatReligatPO.Plot

#Testing the Simple Slopes of the Simple Interaction Religious Conviction by Religiosity.
summary(MAF.Abort.3way.LoPO)
describe(MAF.Abort$Abort_RCcmr)
describe(MAF.Abort$Religcmr)

#Liberals
MAF.Abort.RCAtRelig.Lib <- plotSlopes(MAF.Abort.3way.LoPO, plotx="Abort_RCcmr", modx="Religcmr", 
                                      xlab = "Religious Conviction", ylab = "Moral Conviction", 
                                      modxVals = c(- 1.38, 0 ,  1.38), xlim = c (-1.19,  2.81), plotPoints = FALSE, 
                                      legendTitle = "Religiosity")

MAF.Abort.RCAtRelig.Lib.test <- testSlopes(MAF.Abort.RCAtRelig.Lib)
MAF.Abort.RCAtRelig.Lib.test$hypotests

#Moderates
MAF.Abort.RCAtRelig.Mod <- plotSlopes(MAF.Abort.3way, plotx="Abort_RCcmr", modx="Religcmr", 
                                      xlab = "Religious Conviction", ylab = "Moral Conviction", 
                                      modxVals = c(- 1.38, 0 ,  1.38), xlim = c (-1.19,  2.81), plotPoints = FALSE, 
                                      legendTitle = "Religiosity")

MAF.Abort.RCAtRelig.Mod.test <- testSlopes(MAF.Abort.RCAtRelig.Mod)
MAF.Abort.RCAtRelig.Mod.test$hypotests

#Conservatives
MAF.Abort.RCAtRelig.Con <- plotSlopes(MAF.Abort.3way.HiPO, plotx="Abort_RCcmr", modx="Religcmr", 
                                      xlab = "Religious Conviction", ylab = "Moral Conviction", 
                                      modxVals = c(- 1.38, 0 ,  1.38), xlim = c (-1.19,  2.81), plotPoints = FALSE, 
                                      legendTitle = "Religiosity")

MAF.Abort.RCAtRelig.Con.test <- testSlopes(MAF.Abort.RCAtRelig.Con)
MAF.Abort.RCAtRelig.Con.test$hypotests

##########################################################################################
#MA forcasting Capital Punishment analysis.

#Data. 
MAF.CP<-read.spss("MCRC_Study15_CapitalPunishment_Data.sav", use.value.labels = FALSE, to.data.frame = TRUE,
                  max.value.labels = Inf, trim.factor.names = FALSE,
                  trim_values = TRUE, reencode = NA, use.missings = to.data.frame)


describe(MAF.CP$PO)
describe(MAF.CP$Relig)
describe(MAF.CP$CP_MC)
describe(MAF.CP$CP_RC)

#Center Religiosity.
MAF.CP$Religc <- scale(MAF.CP$Relig, center = T, scale = F)
describe(MAF.CP$Religc)
class(MAF.CP$Religc)
MAF.CP$Religc <- as.vector(MAF.CP$Religc)

#Center Religious Conviction.
MAF.CP$CP_RCc <- scale(MAF.CP$CP_RC, center = T, scale = F)
describe(MAF.CP$CP_RCc)
class(MAF.CP$CP_RCc)
MAF.CP$CP_RCc <- as.vector(MAF.CP$CP_RCc)

#Mean replace Centered Religiosity.
MAF.CP$Religcmr <- ifelse(is.na(MAF.CP$Religc),
                          mean(MAF.CP$Religc,na.rm=TRUE), MAF.CP$Religc)
class(MAF.CP$Religcmr)

#Mean replace Centered Religious Conviction.
MAF.CP$CP_RCcmr <- ifelse(is.na(MAF.CP$CP_RCc),
                          mean(MAF.CP$CP_RCc,na.rm=TRUE), MAF.CP$CP_RCc)
class(MAF.CP$CP_RCcmr)

#Mean replace Political Orientation.
MAF.CP$POmr <- ifelse(is.na(MAF.CP$PO),
                      mean(MAF.CP$PO,na.rm=TRUE), MAF.CP$PO)

#Mean replace Moral Conviction
MAF.CP$CP_MCmr <- ifelse(is.na(MAF.CP$CP_MC),
                         mean(MAF.CP$CP_MC,na.rm=TRUE), MAF.CP$CP_MC)

describe(MAF.CP$POmr)
describe(MAF.CP$Religcmr)
describe(MAF.CP$CP_RCcmr)
describe(MAF.CP$CP_MCmr)

##############  Analyses  ################

##Descriptives and Bi-variate correlations.
describe(MAF.CP$PO)
describe(MAF.CP$Relig)
describe(MAF.CP$CP_RC)
describe(MAF.CP$CP_MC)

cor.test(MAF.CP$PO,MAF.CP$Relig)
cor.test(MAF.CP$PO,MAF.CP$CP_RC)
cor.test(MAF.CP$PO,MAF.CP$CP_MC)
cor.test(MAF.CP$Relig, MAF.CP$CP_RC)
cor.test(MAF.CP$Relig, MAF.CP$CP_MC)
cor.test(MAF.CP$CP_RC, MAF.CP$CP_MC)

#Main effects political orientation, religiosity, religious conviction 

MAF.CP.main <- lm(CP_MCmr ~ POmr
                  + Religcmr
                  + CP_RCcmr,
                  data = MAF.CP) 
summary(MAF.CP.main)

#Main effects & 2-way Interactions

MAF.CP.2way <- lm(CP_MCmr ~ POmr
                  + Religcmr
                  + CP_RCcmr
                  + Religcmr*CP_RCcmr
                  + POmr*Religcmr
                  + POmr*CP_RCcmr,
                  data = MAF.CP) 
summary(MAF.CP.2way)
anova(MAF.CP.main,MAF.CP.2way)

#Main effects & 2-way Interactions & 3-way interaction

MAF.CP.3way <- lm(CP_MCmr ~ POmr
                  + Religcmr
                  + CP_RCcmr
                  + Religcmr*CP_RCcmr
                  + POmr*Religcmr
                  + POmr*CP_RCcmr
                  + POmr*CP_RCcmr*Religcmr,
                  data = MAF.CP) 
summary(MAF.CP.3way)
anova(MAF.CP.2way,MAF.CP.3way)

##Table of all the steps
stargazer(MAF.CP.main,MAF.CP.2way,MAF.CP.3way,type="text",
          column.labels = c("Main Effects", "2-way Interactions", "3-way Interaction"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)


#Main effects & Significant 2-way Interactions
MAF.CP.2way.sig <- lm(CP_MCmr ~ POmr
                      + Religcmr
                      + CP_RCcmr
                      + Religcmr*CP_RCcmr,
                      data = MAF.CP) 
summary(MAF.CP.2way.sig)
anova(MAF.CP.main,MAF.CP.2way.sig)

#Plotting the Religious Conviction by Religiosity interaction predicting moral conviction.
#The effect of Religious Conviction at mean religiosity, one standard deviation above (high religiosity), and one standard deviation below (low religiosity).
summary(MAF.CP.2way.sig)
describe(MAF.CP$Religcmr)
describe(MAF.CP$CP_RCcmr)

MAF.CP.RCatRelig.fitted<-effect('Religcmr:CP_RCcmr', MAF.CP.2way.sig,
                                xlevels=list(Religcmr=c(-1.16, 0 , 1.16), 
                                             CP_RCcmr = seq(from = -1.05, to = 2.95, by =1)), 
                                se=TRUE,confidence.level=.95)

MAF.CP.RCatRelig.Eff<-as.data.frame(MAF.CP.RCatRelig.fitted)

MAF.CP.RCatRelig.Eff$ReligMod<-factor(MAF.CP.RCatRelig.Eff$Religcmr,
                                      levels=c(-1.16,0,1.16),
                                      labels=c("Low Religiosity","Mean Religiosity","Hi Religiosity"))

MAF.CP.RCatRelig.Plot <-ggplot(data = MAF.CP.RCatRelig.Eff, aes(x = CP_RCcmr, y =fit, group=ReligMod))+
  coord_cartesian(xlim=c(-1.05, 2.95),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -1.05, to = 2.95, by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=ReligMod, linetype = ReligMod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=ReligMod),alpha=.2)+
  xlab("Capital Punishment Religious Conviction")+
  ylab("Capital Punishment Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .18))
MAF.CP.RCatRelig.Plot

#Test simple slopes
MAF.CP.RCatRelig <- plotSlopes(MAF.CP.2way.sig, plotx="CP_RCcmr", modx="Religcmr", 
                               xlab = "Capital Punishment Religious Conviction", 
                               ylab = "Capital Punishment Moral Conviction", 
                               modxVals = c(-1.16, 0, 1.16), xlim = c (-1.05, 2.95), plotPoints = FALSE, 
                               legendTitle = "Religiosity")

MAF.CP.RCatRelig.test <- testSlopes(MAF.CP.RCatRelig)
MAF.CP.RCatRelig.test$hypotests

##########################################################################################
#MA forcasting Nuclear Power analysis.

#Data. 
MAF.NP<-read.spss("MCRC_Study15_NuclearPower_Data.sav", use.value.labels = FALSE, to.data.frame = TRUE,
                  max.value.labels = Inf, trim.factor.names = FALSE,
                  trim_values = TRUE, reencode = NA, use.missings = to.data.frame)


describe(MAF.NP$PO)
describe(MAF.NP$Relig)
describe(MAF.NP$NP_MC)
describe(MAF.NP$NP_RC)

#Center Religiosity.
MAF.NP$Religc <- scale(MAF.NP$Relig, center = T, scale = F)
describe(MAF.NP$Religc)
class(MAF.NP$Religc)
MAF.NP$Religc <- as.vector(MAF.NP$Religc)

#Center Religious Conviction.
MAF.NP$NP_RCc <- scale(MAF.NP$NP_RC, center = T, scale = F)
describe(MAF.NP$NP_RCc)
class(MAF.NP$NP_RCc)
MAF.NP$NP_RCc <- as.vector(MAF.NP$NP_RCc)

#Mean replace Centered Religiosity.
MAF.NP$Religcmr <- ifelse(is.na(MAF.NP$Religc),
                          mean(MAF.NP$Religc,na.rm=TRUE), MAF.NP$Religc)
class(MAF.NP$Religcmr)

#Mean replace Centered Religious Conviction.
MAF.NP$NP_RCcmr <- ifelse(is.na(MAF.NP$NP_RCc),
                          mean(MAF.NP$NP_RCc,na.rm=TRUE), MAF.NP$NP_RCc)
class(MAF.NP$NP_RCcmr)

#Mean replace Political Orientation.
MAF.NP$POmr <- ifelse(is.na(MAF.NP$PO),
                      mean(MAF.NP$PO,na.rm=TRUE), MAF.NP$PO)

#Mean replace Moral Conviction
MAF.NP$NP_MCmr <- ifelse(is.na(MAF.NP$NP_MC),
                         mean(MAF.NP$NP_MC,na.rm=TRUE), MAF.NP$NP_MC)

describe(MAF.NP$POmr)
describe(MAF.NP$Religcmr)
describe(MAF.NP$NP_RCcmr)
describe(MAF.NP$NP_MCmr)

##############  Analyses  ################

##Descriptives and Bi-variate correlations.
describe(MAF.NP$PO)
describe(MAF.NP$Relig)
describe(MAF.NP$NP_RC)
describe(MAF.NP$NP_MC)

cor.test(MAF.NP$PO,MAF.NP$Relig)
cor.test(MAF.NP$PO,MAF.NP$NP_RC)
cor.test(MAF.NP$PO,MAF.NP$NP_MC)
cor.test(MAF.NP$Relig, MAF.NP$NP_RC)
cor.test(MAF.NP$Relig, MAF.NP$NP_MC)
cor.test(MAF.NP$NP_RC, MAF.NP$NP_MC)

#Main effects political orientation, religiosity, religious conviction 
MAF.NP.main <- lm(NP_MCmr ~ POmr
                  + Religcmr
                  + NP_RCcmr,
                  data = MAF.NP) 
summary(MAF.NP.main)

#Main effects & 2-way Interactions
MAF.NP.2way <- lm(NP_MCmr ~ POmr
                  + Religcmr
                  + NP_RCcmr
                  + Religcmr*NP_RCcmr
                  + POmr*Religcmr
                  + POmr*NP_RCcmr,
                  data = MAF.NP) 
summary(MAF.NP.2way)
anova(MAF.NP.main,MAF.NP.2way)

#Main effects & 2-way Interactions & 3-way interaction
MAF.NP.3way <- lm(NP_MCmr ~ POmr
                  + Religcmr
                  + NP_RCcmr
                  + Religcmr*NP_RCcmr
                  + POmr*Religcmr
                  + POmr*NP_RCcmr
                  + POmr*NP_RCcmr*Religcmr,
                  data = MAF.NP) 
summary(MAF.NP.3way)
anova(MAF.NP.2way,MAF.NP.3way)

##Table of all the steps
stargazer(MAF.NP.main,MAF.NP.2way,MAF.NP.3way,type="text",
          column.labels = c("Main Effects", "2-way Interactions", "3-way Interaction"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

#Main effects & Significant 2-way Interactions
MAF.NP.2way.sig <- lm(NP_MCmr ~ POmr
                      + Religcmr
                      + NP_RCcmr
                      + Religcmr*NP_RCcmr,
                      data = MAF.NP) 
summary(MAF.NP.2way.sig)

#Plotting the Religious Conviction by Religiosity interaction predicting moral conviction.
#The effect of Religious Conviction at mean religiosity, one standard deviation above (high religiosity), and one standard deviation below (low religiosity).
summary(MAF.NP.2way.sig)
describe(MAF.NP$Religcmr)
describe(MAF.NP$NP_RCcmr)

MAF.NP.RCatRelig.fitted<-effect('Religcmr:NP_RCcmr', MAF.NP.2way.sig,
                                xlevels=list(Religcmr=c(-1.3, 0 , 1.3), 
                                             NP_RCcmr = seq(from = -0.53, to = 3.47, by =1)), 
                                se=TRUE,confidence.level=.95)

MAF.NP.RCatRelig.Eff<-as.data.frame(MAF.NP.RCatRelig.fitted)

MAF.NP.RCatRelig.Eff$ReligMod<-factor(MAF.NP.RCatRelig.Eff$Religcmr,
                                      levels=c(-1.3,0,1.3),
                                      labels=c("Low Religiosity","Mean Religiosity","Hi Religiosity"))

MAF.NP.RCatRelig.Plot <-ggplot(data = MAF.NP.RCatRelig.Eff, aes(x = NP_RCcmr, y =fit, group=ReligMod))+
  coord_cartesian(xlim=c(-0.53, 3.47),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -0.53, to = 3.47, by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=ReligMod, linetype = ReligMod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=ReligMod),alpha=.2)+
  xlab("Nuclear Power Religious Conviction")+
  ylab("Nuclear Power Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .85))
MAF.NP.RCatRelig.Plot

#Test simple slopes
MAF.NP.RCatRelig <- plotSlopes(MAF.NP.2way.sig, plotx="NP_RCcmr", modx="Religcmr", 
                               xlab = "Nuclear Power Religious Conviction", 
                               ylab = "Nuclear Power Moral Conviction", 
                               modxVals = c(-1.3, 0, 1.3), xlim = c (-0.53, 3.47), plotPoints = FALSE, 
                               legendTitle = "Religiosity")

MAF.NP.RCatRelig.test <- testSlopes(MAF.NP.RCatRelig)
MAF.NP.RCatRelig.test$hypotests

##########################################################################################
#MA forcasting Gun Control analysis.

#Data. 
MAF.GC<-read.spss("MCRC_Study15_GunControl_Data.sav", use.value.labels = FALSE, to.data.frame = TRUE,
                  max.value.labels = Inf, trim.factor.names = FALSE,
                  trim_values = TRUE, reencode = NA, use.missings = to.data.frame)


describe(MAF.GC$PO)
describe(MAF.GC$Relig)
describe(MAF.GC$GC_MC)
describe(MAF.GC$GC_RC)

#Center Religiosity.
MAF.GC$Religc <- scale(MAF.GC$Relig, center = T, scale = F)
describe(MAF.GC$Religc)
class(MAF.GC$Religc)
MAF.GC$Religc <- as.vector(MAF.GC$Religc)

#Center Religious Conviction.
MAF.GC$GC_RCc <- scale(MAF.GC$GC_RC, center = T, scale = F)
describe(MAF.GC$GC_RCc)
class(MAF.GC$GC_RCc)
MAF.GC$GC_RCc <- as.vector(MAF.GC$GC_RCc)

#Mean replace Centered Religiosity.
MAF.GC$Religcmr <- ifelse(is.na(MAF.GC$Religc),
                          mean(MAF.GC$Religc,na.rm=TRUE), MAF.GC$Religc)
class(MAF.GC$Religcmr)

#Mean replace Centered Religious Conviction.
MAF.GC$GC_RCcmr <- ifelse(is.na(MAF.GC$GC_RCc),
                          mean(MAF.GC$GC_RCc,na.rm=TRUE), MAF.GC$GC_RCc)
class(MAF.GC$GC_RCcmr)

#Mean replace Political Orientation.
MAF.GC$POmr <- ifelse(is.na(MAF.GC$PO),
                      mean(MAF.GC$PO,na.rm=TRUE), MAF.GC$PO)

#Mean replace Moral Conviction
MAF.GC$GC_MCmr <- ifelse(is.na(MAF.GC$GC_MC),
                         mean(MAF.GC$GC_MC,na.rm=TRUE), MAF.GC$GC_MC)

describe(MAF.GC$POmr)
describe(MAF.GC$Religcmr)
describe(MAF.GC$GC_RCcmr)
describe(MAF.GC$GC_MCmr)

##############  Analyses  ################

##Descriptives and Bi-variate correlations.
describe(MAF.GC$PO)
describe(MAF.GC$Relig)
describe(MAF.GC$GC_RC)
describe(MAF.GC$GC_MC)

cor.test(MAF.GC$PO,MAF.GC$Relig)
cor.test(MAF.GC$PO,MAF.GC$GC_RC)
cor.test(MAF.GC$PO,MAF.GC$GC_MC)
cor.test(MAF.GC$Relig, MAF.GC$GC_RC)
cor.test(MAF.GC$Relig, MAF.GC$GC_MC)
cor.test(MAF.GC$GC_RC, MAF.GC$GC_MC)

#Main effects political orientation, religiosity, religious conviction 

MAF.GC.main <- lm(GC_MCmr ~ POmr
                  + Religcmr
                  + GC_RCcmr,
                  data = MAF.GC) 
summary(MAF.GC.main)

#Main effects & 2-way Interactions

MAF.GC.2way <- lm(GC_MCmr ~ POmr
                  + Religcmr
                  + GC_RCcmr
                  + Religcmr*GC_RCcmr
                  + POmr*Religcmr
                  + POmr*GC_RCcmr,
                  data = MAF.GC) 
summary(MAF.GC.2way)
anova(MAF.GC.main,MAF.GC.2way)

#Main effects & 2-way Interactions & 3-way interaction

MAF.GC.3way <- lm(GC_MCmr ~ POmr
                  + Religcmr
                  + GC_RCcmr
                  + Religcmr*GC_RCcmr
                  + POmr*Religcmr
                  + POmr*GC_RCcmr
                  + POmr*GC_RCcmr*Religcmr,
                  data = MAF.GC) 
summary(MAF.GC.3way)
anova(MAF.GC.2way,MAF.GC.3way)

##Table of all the steps
stargazer(MAF.GC.main,MAF.GC.2way,MAF.GC.3way,type="text",
          column.labels = c("Main Effects", "2-way Interactions", "3-way Interaction"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)