###################################
########### Interaction follow-ups 
###### RC and MC distint



library(rockchalk) #Graphing simple slopes; moderation
library(stargazer) #Handy regression tables
library(foreign)  # Read in SPSS
library(gvlma)   #helper on diagnostics
library(effects) #helper on visualizing interactions - Uses lattice
library(sjPlot)  #helper on visualizing interactions - uses ggplot
library(ggplot2) #All the graphs
library(psych) #handy for descriptives, etc
library(dplyr) 

#set working directory
setwd("")

IsraelData<-read.spss("MCRC_Study16_Data.sav", use.value.labels = FALSE, to.data.frame = TRUE,
                    max.value.labels = Inf, trim.factor.names = FALSE,
                    trim_values = TRUE, reencode = NA, use.missings = to.data.frame)

head(IsraelData)
str(IsraelData)

length(IsraelData$iprc)
length(IsraelData$ipmc)
length(IsraelData$polorient)

describe(IsraelData$iprc)
describe(IsraelData$ipmc)
describe(IsraelData$polorient)

#center continuous predictors (not PO, which is centered at the midpoint) 

IsraelData$iprc_c <- scale(IsraelData$iprc, scale=FALSE)
describe(IsraelData$iprc_c, na.rm = TRUE)


### Creating mean replacement variables to take care of missingness.
#If else statement: if value of the variable is missing, replace with the mean of the variable, else use the original value.

#Mean centered religious conviction. Replace missing values with mean (0 since it's mean centered). 
IsraelData$iprc_c_mr <- ifelse(is.na(IsraelData$iprc_c),
                             mean(IsraelData$iprc_c,na.rm=TRUE), IsraelData$iprc_c)

describe(IsraelData$iprc_c_mr)
describe(IsraelData$iprc_c)
round(IsraelData$iprc_c_mr, 3)

#Moral conviction. Replace missing values with mean
IsraelData$ipmc_mr <- ifelse(is.na(IsraelData$ipmc),
                           mean(IsraelData$ipmc,na.rm=TRUE), IsraelData$ipmc)

describe(IsraelData$ipmc_mr)
describe(IsraelData$ipmc)
round(IsraelData$ipmc_mr, 3)


#PO. Replace missing values with mean . 
IsraelData$polorient_mr <- ifelse(is.na(IsraelData$polorient),
                        mean(IsraelData$polorient,na.rm=TRUE), IsraelData$polorient)

describe(IsraelData$polorient_mr)
describe(IsraelData$polorient)
round(IsraelData$polorient_mr, 3)


##################################################
####Moral conviction for IP conflict

IsraelData$iprc_c_mrV <- as.vector(IsraelData$iprc_c_mr)
IsraelData$ipmc_mrV <- as.vector(IsraelData$ipmc_mr)
IsraelData$polorient_mrV <- as.vector(IsraelData$polorient_mr)


#Main effects T1 political orientation, T1 religious conviction for PAS, T1 religiosity 

mcIsrael.mainV <- lm(ipmc_mrV ~ iprc_c_mrV
                  + polorient_mrV,
                  data = IsraelData) 
summary(mcIsrael.mainV)

cor(IsraelData$ipmc_mrV,IsraelData$iprc_c_mrV)

cor.test(IsraelData$ipmc_mrV,IsraelData$iprc_c_mrV)

cor.test(IsraelData$ipmc_mrV,IsraelData$polorient_mrV)

cor.test(IsraelData$iprc_c_mrV,IsraelData$polorient_mrV)





#Mmain effects & 2-way Interaction

mcIsrael.2wayV <- lm(ipmc_mrV ~ iprc_c_mrV
                  + polorient_mrV
                  + iprc_c_mrV*polorient_mrV,
                  data = IsraelData) 
summary(mcIsrael.2wayV)
anova(mcIsrael.mainV,mcIsrael.2wayV)

##Nice table of all the steps
stargazer(mcIsrael.mainV,mcIsrael.2wayV, type="text",
          column.labels = c("Main Effects", "2-way Interactions"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE,
          out="mcPAS.2wayfull.txt")

#Plotting
library(rockchalk)
?plotSlopes

describe(IsraelData$iprc_c_mrV)
describe(IsraelData$polorient_mrV)


mcIsrael.RCAtPO <- plotSlopes(mcIsrael.2wayV, plotx="iprc_c_mrV", modx="polorient_mrV", 
                             xlab = "Religious Conviction for I-P Conflict", ylab = "Moral Conviction for I-P Conflict", 
                             modxVals = c(2.76, 4, 5.24), xlim = c (-2.12, 3.88), plotPoints = F, 
                             legendTitle = "Political Orientation")



mcIsrael.RCAtPO.test <- testSlopes(mcIsrael.RCAtPO)

mcIsrael.RCAtPO.test$hypotests

