###################################
########### Interaction follow-ups 
###### RC and MC distint


library(rockchalk) #Graphing simple slopes; moderation
library(stargazer) #Handy regression tables
library(foreign)  # Read in SPSS
library(gvlma)   #helper on diagnostics
library(effects) #helper on visualizing interactions - Uses lattice
library(sjPlot)  #helper on visualizing interactions - uses ggplot
library(ggplot2) #All the graphs
library(psych) #handy for descriptives, etc
library(dplyr) 

#set working directory
setwd("C:/Users/Brittany/Box Sync/RC Project/Data sets/Study 17 (China Data BH)")

##########################################################################################
#China data analysis.

#Data. 
China<-read.spss("MCRC_Study17_Data.sav", use.value.labels = FALSE, to.data.frame = TRUE,
                 max.value.labels = Inf, trim.factor.names = FALSE,
                 trim_values = TRUE, reencode = NA, use.missings = to.data.frame)


describe(China$PO)
describe(China$MC)
describe(China$RC)

#Center Religious Conviction.
China$RCc <- scale(China$RC, center = T, scale = F)
describe(China$RCc)
class(China$RCc)
China$RCc <- as.vector(China$RCc)

#Mean replace Centered Religious Conviction.
China$RCcmr <- ifelse(is.na(China$RCc),
                      mean(China$RCc,na.rm=TRUE), China$RCc)
class(China$RCcmr)

#Mean replace Political Orientation.
China$POmr <- ifelse(is.na(China$PO),
                     mean(China$PO,na.rm=TRUE), China$PO)

#Mean replace Moral Conviction
China$MCmr <- ifelse(is.na(China$MC),
                     mean(China$MC,na.rm=TRUE), China$MC)

describe(China$POmr)
describe(China$RCcmr)
describe(China$MCmr)

##############  Analyses  ################

##Descriptives and Bi-variate correlations.
describe(China$PO)
describe(China$RC)
describe(China$MC)

cor.test(China$PO,China$RC)
cor.test(China$PO,China$MC)
cor.test(China$RC, China$MC)

#Main effects political orientation and religious conviction 

China.main <- lm(MCmr ~ POmr
                 + RCcmr,
                 data = China) 
summary(China.main)

#Main effects & 2-way Interactions

China.2way <- lm(MCmr ~ POmr
                 + RCcmr
                 + POmr*RCcmr,
                 data = China) 
summary(China.2way)
anova(China.main,China.2way)


##Table of all the steps
stargazer(China.main,China.2way,type="text",
          column.labels = c("Main Effects", "2-way Interactions"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)
