###################################
########### Interaction follow-ups 
###### RC and MC distint


library(rockchalk) #Graphing simple slopes; moderation
library(stargazer) #Handy regression tables
library(foreign)  # Read in SPSS
library(gvlma)   #helper on diagnostics
library(effects) #helper on visualizing interactions - Uses lattice
library(sjPlot)  #helper on visualizing interactions - uses ggplot
library(ggplot2) #All the graphs
library(psych) #handy for descriptives, etc
library(dplyr)
library(apaTables)
library(Hmisc)
describe<-psych::describe

#set working directory
setwd("")

##########################################################################################
#ChinaMturk data analysis.

#Data. 
ChinaMturk<-read.spss("MCRC_Study18_Data.sav", use.value.labels = FALSE, to.data.frame = TRUE,
                 max.value.labels = Inf, trim.factor.names = FALSE,
                 trim_values = TRUE, reencode = NA)


describe(ChinaMturk$pol)
describe(ChinaMturk$mc)
describe(ChinaMturk$RC)

#Center Religious Conviction.
ChinaMturk$RCc <- scale(ChinaMturk$RC, center = T, scale = F)[,]
describe(ChinaMturk$RCc)

#Mean replace Centered Religious Conviction.
ChinaMturk$RCcmr <- ifelse(is.na(ChinaMturk$RCc),
                      mean(ChinaMturk$RCc,na.rm=TRUE), ChinaMturk$RCc)
describe(ChinaMturk$RCcmr)

#Midpoint center and mean replace Political Orientation.
ChinaMturk$polc <- ChinaMturk$pol - 4
describe(ChinaMturk$polc)
ChinaMturk$POcmr <- ifelse(is.na(ChinaMturk$polc),
                     mean(ChinaMturk$polc,na.rm=TRUE), ChinaMturk$polc)
describe(ChinaMturk$POcmr)

#Mean replace Moral Convcition
ChinaMturk$MCmr <- ifelse(is.na(ChinaMturk$mc),
                     mean(ChinaMturk$mc,na.rm=TRUE), ChinaMturk$mc)
describe(ChinaMturk$MCmr)

##############  Analyses  ################

##Descriptives and Bi-variate correlations.
describe(ChinaMturk$polc)
describe(ChinaMturk$RC)
describe(ChinaMturk$mc)

cor.test(ChinaMturk$MC1, ChinaMturk$MC2)

ChinaMturkcordata<-subset(ChinaMturk[,c("polc","RC","mc")])
apa.cor.table(ChinaMturkcordata, show.conf.interval = FALSE, landscape = FALSE)
ChinaMturkcordatamatrix<-as.matrix(ChinaMturkcordata)
rcorr(ChinaMturkcordatamatrix, type = "pearson")

#Main effects political orientation and prefered candidate religious conviction 

ChinaMturk.main <- lm(MCmr ~ POcmr
                 + RCcmr,
                 data = ChinaMturk) 
summary(ChinaMturk.main)

#Main effects & 2-way Interactions

ChinaMturk.2way <- lm(MCmr ~ POcmr
                 + RCcmr
                 + POcmr*RCcmr,
                 data = ChinaMturk) 
summary(ChinaMturk.2way)
anova(ChinaMturk.main,ChinaMturk.2way)


##Table of all the steps
stargazer(ChinaMturk.main,ChinaMturk.2way,type="text",
          column.labels = c("Main Effects", "2-way Interactions"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

