library(rockchalk) #Graphing simple slopes; moderation
library(stargazer) #Handy regression tables
library(foreign)  # Read in SPSS
library(gvlma)   #helper on diagnostics
library(effects) #helper on visualizing interactions - Uses lattice
library(sjPlot)  #helper on visualizing interactions - uses ggplot
library(ggplot2) #All the graphs
library(psych) #handy for descriptives, etc
library(dplyr)
library(apaTables)
library(texreg)
library(Hmisc)
describe <- psych::describe

#set working directory
setwd("")

RCMCData<-read.spss("MCRC_Study19_Data.sav", use.value.labels = FALSE, to.data.frame = TRUE,
                     max.value.labels = Inf, trim.factor.names = FALSE,
                     trim_values = TRUE, reencode = NA, use.missings = to.data.frame)

#############################################
##### For abstinence-only sex education #####
#############################################
RCMCData.abs <- subset(RCMCData, imcpass == 1)

# To fill in missing values with non-centered mean to be used in descriptives and correlation tables
RCMCData.abs$absonly.rcfull.mr <- ifelse(is.na(RCMCData.abs$absonly.rcfull),
                                      mean(RCMCData.abs$absonly.rcfull,na.rm=TRUE), RCMCData.abs$absonly.rcfull)
describe(RCMCData.abs$absonly.rcfull.mr)

RCMCData.abs$santaclara.full.mr <- ifelse(is.na(RCMCData.abs$santaclara.full),
                                       mean(RCMCData.abs$santaclara.full,na.rm=TRUE), RCMCData.abs$santaclara.full)

describe(RCMCData.abs$santaclara.full.mr)

#bivariate correlations.
RCMCData.abs$santaclara.full.v <- as.vector(RCMCData.abs$santaclara.full)
RCMCData.abs$absonly.rcfull.v <- as.vector(RCMCData.abs$absonly.rcfull)
RCMCData.abs$absonly.mcfull.v <- as.vector(RCMCData.abs$absonly.mcfull)
RCMCData.abs$po.full.v <- as.vector(RCMCData.abs$po.full)

cor(RCMCData.abs$absonly.rcfull.v, RCMCData.abs$absonly.mcfull.v)


#center continuous predictors 

#religious conviction
RCMCData.abs$absonly.rcfull.c <- scale(RCMCData.abs$absonly.rcfull, scale=FALSE)
describe(RCMCData.abs$absonly.rcfull.c, na.rm = TRUE)

#religiosity
RCMCData.abs$santaclara.full.c <- scale(RCMCData.abs$santaclara.full, scale=FALSE)
describe(RCMCData.abs$santaclara.full.c, na.rm = TRUE)

#leave PO median centered at zero.

### Creating mean replacement variables to take care of missingness.
#If else statement: if value of the variable is missing, replace with the mean of the variable, else use the original value.

#Mean centered religious conviction. Replace missing values with mean (0 since it's mean centered). 
RCMCData.abs$absonly.rcfull.c.mr <- ifelse(is.na(RCMCData.abs$absonly.rcfull.c),
                                        mean(RCMCData.abs$absonly.rcfull.c,na.rm=TRUE), RCMCData.abs$absonly.rcfull.c)

describe(RCMCData.abs$absonly.rcfull.c)
describe(RCMCData.abs$absonly.rcfull.c.mr)
round(RCMCData.abs$absonly.rcfull.c.mr, 3)

#Moral conviction. Replace missing values with mean
RCMCData.abs$absonly.mcfull.mr <- ifelse(is.na(RCMCData.abs$absonly.mcfull),
                                      mean(RCMCData.abs$absonly.mcfull,na.rm=TRUE), RCMCData.abs$absonly.mcfull)

describe(RCMCData.abs$absonly.mcfull.mr)
describe(RCMCData.abs$absonly.mcfull)
round(RCMCData.abs$absonly.mcfull.mr, 3)

#mean centered religiosity. Replace missing values with mean (0 since it's mean centered). 
RCMCData.abs$santaclara.full.c.mr <- ifelse(is.na(RCMCData.abs$santaclara.full.c),
                                         mean(RCMCData.abs$santaclara.full.c,na.rm=TRUE), RCMCData.abs$santaclara.full.c)

describe(RCMCData.abs$santaclara.full.c.mr)
describe(RCMCData.abs$santaclara.full.c)
round(RCMCData.abs$santaclara.full.c.mr, 3)


#Midpoint (moderate) centered political orientation. Replace missing values with mean. 
RCMCData.abs$po.full.mr <- ifelse(is.na(RCMCData.abs$po.full),
                               mean(RCMCData.abs$po.full,na.rm=TRUE), RCMCData.abs$po.full)

describe(RCMCData.abs$po.full.mr)
describe(RCMCData.abs$po.full)
round(RCMCData.abs$po.full.mr, 3)

# Tables for Linda
cordata<-RCMCData.abs[,c("po.full.mr","santaclara.full.mr","absonly.rcfull.mr","absonly.mcfull.mr")]
apa.cor.table(cordata, show.conf.interval = FALSE, landscape = FALSE)
cordatamatrix<-as.matrix(cordata)
rcorr(cordatamatrix, type = "pearson")

##################################################
####T1 Moral conviction for abstince only education. 

RCMCData.abs$absonly.rcfull.c.mr.v <- as.vector(RCMCData.abs$absonly.rcfull.c.mr)
RCMCData.abs$santaclara.full.c.mr.v <- as.vector(RCMCData.abs$santaclara.full.c.mr)
RCMCData.abs$absonly.mcfull.mr.v <- as.vector(RCMCData.abs$absonly.mcfull.mr)
RCMCData.abs$po.full.mr.v <- as.vector(RCMCData.abs$po.full.mr)

cor(RCMCData.abs$absonly.rcfull.c.mr.v,RCMCData.abs$absonly.mcfull.mr.v)
cor(RCMCData.abs$santaclara.full.c.mr.v,RCMCData.abs$absonly.rcfull.c.mr.v)
cor(RCMCData.abs$santaclara.full.c.mr.v,RCMCData.abs$absonly.mcfull.mr.v)
cor(RCMCData.abs$santaclara.full.c.mr.v,RCMCData.abs$po.full.mr)
cor(RCMCData.abs$absonly.rcfull.c.mr.v,RCMCData.abs$po.full.mr)
cor(RCMCData.abs$po.full.mr,RCMCData.abs$absonly.mcfull.mr.v)


#Main effects political orientation, religious conviction for abstince, religiosity 

mcABSONLY.mainV <- lm(absonly.mcfull.mr.v ~ absonly.rcfull.c.mr.v
                      + santaclara.full.c.mr.v
                      + po.full.mr.v,
                      data = RCMCData.abs) 
summary(mcABSONLY.mainV)

cor(RCMCData.abs$absonly.rcfull.c.mr.v,RCMCData.abs$absonly.mcfull.mr.v)


#Mmain effects & 2-way Interactions

mcABSONLY.2wayV <- lm(absonly.mcfull.mr.v ~ absonly.rcfull.c.mr.v
                      + santaclara.full.c.mr.v
                      + po.full.mr.v
                      + absonly.rcfull.c.mr.v*santaclara.full.c.mr.v
                      + po.full.mr.v*absonly.rcfull.c.mr.v
                      + santaclara.full.c.mr.v*po.full.mr.v,
                      data = RCMCData.abs) 
summary(mcABSONLY.2wayV)
anova(mcABSONLY.mainV,mcABSONLY.2wayV)

#main effects, 2 way, and 3 way interaction
mcABSONLY.3wayV <- lm(absonly.mcfull.mr.v ~ absonly.rcfull.c.mr.v
                      + santaclara.full.c.mr.v
                      + po.full.mr.v
                      + absonly.rcfull.c.mr.v*santaclara.full.c.mr.v
                      + po.full.mr.v*absonly.rcfull.c.mr.v
                      + santaclara.full.c.mr.v*po.full.mr.v
                      + absonly.rcfull.c.mr.v*santaclara.full.c.mr.v*po.full.mr.v,
                      data = RCMCData.abs) 
summary(mcABSONLY.3wayV)
anova(mcABSONLY.2wayV,mcABSONLY.3wayV)

stargazer(mcABSONLY.3wayV,type="text", title = "3 way", out="mcABSONLY.3wayV.txt")

##Nice table of all the steps
stargazer(mcABSONLY.mainV,mcABSONLY.2wayV,mcABSONLY.3wayV, type="text",
          column.labels = c("Main Effects", "2-way Interactions", "3-way Interaction"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE,
          out="mcABSONLY.3wayfull.txt")

#Plotting
describe(RCMCData.abs$santaclara.full.c.mr.v)
describe(RCMCData.abs$absonly.rcfull.c.mr.v)

mcABSONLY.RCAtRel <- plotSlopes(mcABSONLY.2wayV, plotx="absonly.rcfull.c.mr.v", modx="santaclara.full.c.mr.v", 
                                xlab = "Religious Conviction for ABSONLY", ylab = "Moral Conviction for ABSONLY", 
                                modxVals = c(-1.51, 0, 1.51), xlim = c(-0.94, 3.06), plotPoints = F, 
                                legendTitle = "Religiosity")

mcABSONLY.RCAtRel.test <- testSlopes(mcABSONLY.RCAtRel)

round(mcABSONLY.RCAtRel.test$hypotests,3)



#Plotting pretty with ggplot
#Plotting the religiosity by religious conviction interaction predicting moral conviction.
#The effect of religious conviction at  one standard deviation above and below (sd = 1.51).
summary(mcABSONLY.2wayV)
describe(RCMCData.abs$santaclara.full.c.mr.v)
describe(RCMCData.abs$absonly.rcfull.c.mr.v)

#Getting the effects for the religiosity by Religious conviction interaction
# at 1 SD below mean,  and 1 SD above, and the mean (-1.51, 0, 1.51).
# Specifying the full range of religious conviction (min = -0.94 max = 3.06, every one unit) 
# The variable is mean centered, so this translates to the original points on the 1-5 scale.
mcABSONLY.RCAtRel.fitted<-effect('absonly.rcfull.c.mr.v:santaclara.full.c.mr.v', mcABSONLY.2wayV,
                                 xlevels=list(santaclara.full.c.mr.v=c(-1.51, 0, 1.51),
                                              absonly.rcfull.c.mr.v = seq(from = -0.94, to = 3.06, by =1)), 
                                 se=TRUE,confidence.level=.95)

#Saving the effects as a data frame. 
mcABSONLY.RCAtRel.Eff<-as.data.frame(mcABSONLY.RCAtRel.fitted)

#Recoding the moderator variable (religiosity) as a factor with the names of the groups. 
mcABSONLY.RCAtRel.Eff$santaclaramod<-factor(mcABSONLY.RCAtRel.Eff$santaclara.full.c.mr.v,
                                            levels=c(-1.51,0,1.51),
                                            labels=c("Low Religiosity","Mean Religiosity", "High Religiosity"))

mcABSONLY.RCAtRel.Plot <-ggplot(data = mcABSONLY.RCAtRel.Eff, aes(x = absonly.rcfull.c.mr.v, y =fit, group=santaclaramod))+
  coord_cartesian(xlim=c(-0.94, 3.06),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -0.94, to = 3.06, by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=santaclaramod, linetype = santaclaramod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=santaclaramod),alpha=.2)+
  xlab("Abstinence-Only Sex Education Religious Conviction")+
  ylab("Abstinence-Only Sex Education Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .87))
mcABSONLY.RCAtRel.Plot


##########################################
##### For physician-assisted suicide #####
##########################################
RCMCData.pas <- subset(RCMCData, imcpass == 1)

# To fill in missing values with non-centered mean to be used in descriptives and correlation tables
RCMCData.pas$pas.rcfull.mr <- ifelse(is.na(RCMCData.pas$pas.rcfull),
                                  mean(RCMCData.pas$pas.rcfull,na.rm=TRUE), RCMCData.pas$pas.rcfull)
describe(RCMCData.pas$pas.rcfull.mr)

RCMCData.pas$santaclara.full.mr <- ifelse(is.na(RCMCData.pas$santaclara.full),
                                       mean(RCMCData.pas$santaclara.full,na.rm=TRUE), RCMCData.pas$santaclara.full)

describe(RCMCData.pas$santaclara.full.mr)

#center continuous predictors 

#religious conviction
RCMCData.pas$pas.rcfull.c <- scale(RCMCData.pas$pas.rcfull, scale=FALSE)
describe(RCMCData.pas$pas.rcfull.c, na.rm = TRUE)

#religiosity
RCMCData.pas$santaclara.full.c <- scale(RCMCData.pas$santaclara.full, scale=FALSE)
describe(RCMCData.pas$santaclara.full.c, na.rm = TRUE)

#leave PO median centered at zero.

### Creating mean replacement variables to take care of missingness.
#If else statement: if value of the variable is missing, replace with the mean of the variable, else use the original value.

#Mean centered religious conviction. Replace missing values with mean (0 since it's mean centered). 
RCMCData.pas$pas.rcfull.c.mr <- ifelse(is.na(RCMCData.pas$pas.rcfull.c),
                                    mean(RCMCData.pas$pas.rcfull.c,na.rm=TRUE), RCMCData.pas$pas.rcfull.c)

describe(RCMCData.pas$pas.rcfull.c)
describe(RCMCData.pas$pas.rcfull.c.mr)
round(RCMCData.pas$pas.rcfull.c.mr, 3)

#Moral conviction. Replace missing values with mean
RCMCData.pas$pas.mcfull.mr <- ifelse(is.na(RCMCData.pas$pas.mcfull),
                                  mean(RCMCData.pas$pas.mcfull,na.rm=TRUE), RCMCData.pas$pas.mcfull)

describe(RCMCData.pas$pas.mcfull.mr)
describe(RCMCData.pas$pas.mcfull)
round(RCMCData.pas$pas.mcfull.mr, 3)

#mean centered religiosity. Replace missing values with mean (0 since it's mean centered). 
RCMCData.pas$santaclara.full.c.mr <- ifelse(is.na(RCMCData.pas$santaclara.full.c),
                                         mean(RCMCData.pas$santaclara.full.c,na.rm=TRUE), RCMCData.pas$santaclara.full.c)

describe(RCMCData.pas$santaclara.full.c.mr)
describe(RCMCData.pas$santaclara.full.c)
round(RCMCData.pas$santaclara.full.c.mr, 3)


#Midpoint (moderate) centered political orientation. Replace missing values with mean. 
RCMCData.pas$po.full.mr <- ifelse(is.na(RCMCData.pas$po.full),
                               mean(RCMCData.pas$po.full,na.rm=TRUE), RCMCData.pas$po.full)

describe(RCMCData.pas$po.full.mr)
describe(RCMCData.pas$po.full)
round(RCMCData.pas$po.full.mr, 3)

# Tables for Linda
cordata<-RCMCData.pas[,c("po.full.mr","santaclara.full.mr","pas.rcfull.mr","pas.mcfull.mr")]
apa.cor.table(cordata, show.conf.interval = FALSE, landscape = FALSE)
cordatamatrix<-as.matrix(cordata)
rcorr(cordatamatrix, type = "pearson")

##################################################
####T1 Moral conviction for abstince only education. 

RCMCData.pas$pas.rcfull.c.mr.v <- as.vector(RCMCData.pas$pas.rcfull.c.mr)
RCMCData.pas$santaclara.full.c.mr.v <- as.vector(RCMCData.pas$santaclara.full.c.mr)
RCMCData.pas$pas.mcfull.mr.v <- as.vector(RCMCData.pas$pas.mcfull.mr)
RCMCData.pas$po.full.mr.v <- as.vector(RCMCData.pas$po.full.mr)

cor(RCMCData.pas$pas.rcfull.c.mr.v,RCMCData.pas$pas.mcfull.mr.v)
cor(RCMCData.pas$santaclara.full.c.mr.v,RCMCData.pas$pas.rcfull.c.mr.v)
cor(RCMCData.pas$santaclara.full.c.mr.v,RCMCData.pas$pas.mcfull.mr.v)
cor(RCMCData.pas$santaclara.full.c.mr.v,RCMCData.pas$po.full.mr)
cor(RCMCData.pas$pas.rcfull.c.mr.v,RCMCData.pas$po.full.mr)
cor(RCMCData.pas$po.full.mr,RCMCData.pas$pas.mcfull.mr.v)


#Main effects political orientation, religious conviction for abstince, religiosity 

mcPAS.mainV <- lm(pas.mcfull.mr.v ~ pas.rcfull.c.mr.v
                  + santaclara.full.c.mr.v
                  + po.full.mr.v,
                  data = RCMCData.pas) 
summary(mcPAS.mainV)

cor(RCMCData.pas$pas.rcfull.c.mr.v,RCMCData.pas$pas.mcfull.mr.v)


#Mmain effects & 2-way Interactions

mcPAS.2wayV <- lm(pas.mcfull.mr.v ~ pas.rcfull.c.mr.v
                  + santaclara.full.c.mr.v
                  + po.full.mr.v
                  + pas.rcfull.c.mr.v*santaclara.full.c.mr.v
                  + po.full.mr.v*pas.rcfull.c.mr.v
                  + santaclara.full.c.mr.v*po.full.mr.v,
                  data = RCMCData.pas) 
summary(mcPAS.2wayV)
anova(mcPAS.mainV,mcPAS.2wayV)

#main effects, 2 way, and 3 way interaction
mcPAS.3wayV <- lm(pas.mcfull.mr.v ~ pas.rcfull.c.mr.v
                  + santaclara.full.c.mr.v
                  + po.full.mr.v
                  + pas.rcfull.c.mr.v*santaclara.full.c.mr.v
                  + po.full.mr.v*pas.rcfull.c.mr.v
                  + santaclara.full.c.mr.v*po.full.mr.v
                  + pas.rcfull.c.mr.v*santaclara.full.c.mr.v*po.full.mr.v,
                  data = RCMCData.pas) 
summary(mcPAS.3wayV)
anova(mcPAS.2wayV,mcPAS.3wayV)

stargazer(mcPAS.3wayV,type="text", title = "3 way", out="mcPAS.3wayV.txt")

##Nice table of all the steps
stargazer(mcPAS.mainV,mcPAS.2wayV,mcPAS.3wayV, type="text",
          column.labels = c("Main Effects", "2-way Interactions", "3-way Interaction"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE,
          out="mcPAS.3wayfull.txt")

#Plotting the RC x Religiosity 2 way interaction.
describe(RCMCData.pas$santaclara.full.c.mr.v)
describe(RCMCData.pas$pas.rcfull.c.mr.v)

mcPAS.RCAtRel <- plotSlopes(mcPAS.2wayV, plotx="pas.rcfull.c.mr.v", modx="santaclara.full.c.mr.v", 
                            xlab = "Religious Conviction for PAS", ylab = "Moral Conviction for PAS", 
                            modxVals = c(-1.51, 0, 1.51), xlim = c(-1.05, 2.95), plotPoints = F, 
                            legendTitle = "Religiosity")

mcPAS.RCAtRel.test <- testSlopes(mcPAS.RCAtRel)

mcPAS.RCAtRel.test$hypotests



#Plotting pretty with ggplot
#Plotting the religiosity by religious conviction interaction predicting moral conviction.
#The effect of religious conviction at  one standard deviation above and below (sd = 1.51).
summary(mcPAS.2wayV)
describe(RCMCData.pas$santaclara.full.c.mr.v)
describe(RCMCData.pas$pas.rcfull.c.mr.v)

#Getting the effects for the religiosity by Religious conviction interaction
# at 1 SD below mean,  and 1 SD above, and the mean (-1.51, 0, 1.51).
# Specifying the full range of religious conviction (min = -1.05 max = 2.95, every one unit) 
# The variable is mean centered, so this translates to the original points on the 1-5 scale.
mcPAS.RCAtRel.fitted<-effect('pas.rcfull.c.mr.v:santaclara.full.c.mr.v', mcPAS.2wayV,
                             xlevels=list(santaclara.full.c.mr.v=c(-1.51, 0, 1.51),
                                          pas.rcfull.c.mr.v = seq(from = -1.05, to = 2.95, by =1)), 
                             se=TRUE,confidence.level=.95)

#Saving the effects as a data frame. 
mcPAS.RCAtRel.Eff<-as.data.frame(mcPAS.RCAtRel.fitted)

#Recoding the moderator variable (religiosity) as a factor with the names of the groups. 
mcPAS.RCAtRel.Eff$santaclaramod<-factor(mcPAS.RCAtRel.Eff$santaclara.full.c.mr.v,
                                        levels=c(-1.51,0,1.51),
                                        labels=c("Low Religiosity","Mean Religiosity", "High Religiosity"))

mcPAS.RCAtRel.Plot <-ggplot(data = mcPAS.RCAtRel.Eff, aes(x = pas.rcfull.c.mr.v, y =fit, group=santaclaramod))+
  coord_cartesian(xlim=c(-1.05, 2.95),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -1.05, to = 2.95, by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=santaclaramod, linetype = santaclaramod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=santaclaramod),alpha=.2)+
  xlab("Physician-Assistied Suicide Religious Conviction")+
  ylab("Physician-Assistied Suicide Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .87))
mcPAS.RCAtRel.Plot

#Plotting the PO x Religiosity 2-way Interaction 

describe(RCMCData.pas$santaclara.full.c.mr.v)
describe(RCMCData.pas$po.full.mr.v)

mcPAS.POAtRel <- plotSlopes(mcPAS.2wayV, plotx="santaclara.full.c.mr.v", modx="po.full.mr.v", 
                            xlab = "Religiosity", ylab = "Moral Conviction for PAS", 
                            modxVals = c(-2.62, 0, 2.62), xlim = c(-1.38, 2.62), plotPoints = F, 
                            legendTitle = "Political Orientation")

mcPAS.POAtRel.test <- testSlopes(mcPAS.POAtRel)

mcPAS.POAtRel.test$hypotests



#Plotting pretty with ggplot
#Plotting the religiosity by PO interaction predicting moral conviction.
#The effect of religiosity at  one standard deviation above and below moderate PO (sd = 2.62).
summary(mcPAS.2wayV)
describe(RCMCData.pas$santaclara.full.c.mr.v)
describe(RCMCData.pas$po.full.mr.v)

#Getting the effects for the religiosity by PO interaction
# at 1 SD below mean,  and 1 SD above, and moderate (-2.62, 0, 2.62).
# Specifying the full range of religiousity (min = -1.38 max = 2.62, every one unit) 
# The variable is mean centered, so this translates to the original points on the 1-5 scale.
mcPAS.POAtRel.fitted<-effect('santaclara.full.c.mr.v:po.full.mr.v', mcPAS.2wayV,
                             xlevels=list(po.full.mr.v=c(-2.62, 0, 2.62),
                                          santaclara.full.c.mr.v = seq(from = -1.38, to = 2.62, by =1)), 
                             se=TRUE,confidence.level=.95)

#Saving the effects as a data frame. 
mcPAS.POAtRel.Eff<-as.data.frame(mcPAS.POAtRel.fitted)

#Recoding the moderator variable (religiosity) as a factor with the names of the groups. 
mcPAS.POAtRel.Eff$POmod<-factor(mcPAS.POAtRel.Eff$po.full.mr.v,
                                levels=c(-2.62,0,2.62),
                                labels=c("Liberals","Moderates", "Conservatives"))

mcPAS.POAtRel.Plot <-ggplot(data = mcPAS.POAtRel.Eff, aes(x = santaclara.full.c.mr.v, y =fit, group=POmod))+
  coord_cartesian(xlim=c(-1.38, 2.62),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -1.38, to = 2.62, by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=POmod, linetype = POmod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=POmod),alpha=.2)+
  xlab("Religiosity")+
  ylab("Physician-Assistied Suicide Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .87))
mcPAS.POAtRel.Plot


########################
##### For abortion #####
########################
RCMCData.abort <- subset(RCMCData, imcpass == 1)

# To fill in missing values with non-centered mean to be used in descriptives and correlation tables
RCMCData.abort$abort.rcfull.mr <- ifelse(is.na(RCMCData.abort$abort.rcfull),
                                    mean(RCMCData.abort$abort.rcfull,na.rm=TRUE), RCMCData.abort$abort.rcfull)
describe(RCMCData.abort$abort.rcfull.mr)

RCMCData.abort$santaclara.full.mr <- ifelse(is.na(RCMCData.abort$santaclara.full),
                                       mean(RCMCData.abort$santaclara.full,na.rm=TRUE), RCMCData.abort$santaclara.full)

describe(RCMCData.abort$santaclara.full.mr)

#center continuous predictors 

#religious conviction
RCMCData.abort$abort.rcfull.c <- scale(RCMCData.abort$abort.rcfull, scale=FALSE)
describe(RCMCData.abort$abort.rcfull.c, na.rm = TRUE)

#religiosity
RCMCData.abort$santaclara.full.c <- scale(RCMCData.abort$santaclara.full, scale=FALSE)
describe(RCMCData.abort$santaclara.full.c, na.rm = TRUE)

#leave PO median centered at zero.

### Creating mean replacement variables to take care of missingness.
#If else statement: if value of the variable is missing, replace with the mean of the variable, else use the original value.

#Mean centered religious conviction. Replace missing values with mean (0 since it's mean centered). 
RCMCData.abort$abort.rcfull.c.mr <- ifelse(is.na(RCMCData.abort$abort.rcfull.c),
                                      mean(RCMCData.abort$abort.rcfull.c,na.rm=TRUE), RCMCData.abort$abort.rcfull.c)

describe(RCMCData.abort$abort.rcfull.c)
describe(RCMCData.abort$abort.rcfull.c.mr)
round(RCMCData.abort$abort.rcfull.c.mr, 3)

#Moral conviction. Replace missing values with mean
RCMCData.abort$abort.mcfull.mr <- ifelse(is.na(RCMCData.abort$abort.mcfull),
                                    mean(RCMCData.abort$abort.mcfull,na.rm=TRUE), RCMCData.abort$abort.mcfull)

describe(RCMCData.abort$abort.mcfull.mr)
describe(RCMCData.abort$abort.mcfull)
round(RCMCData.abort$abort.mcfull.mr, 3)

#mean centered religiosity. Replace missing values with mean (0 since it's mean centered). 
RCMCData.abort$santaclara.full.c.mr <- ifelse(is.na(RCMCData.abort$santaclara.full.c),
                                         mean(RCMCData.abort$santaclara.full.c,na.rm=TRUE), RCMCData.abort$santaclara.full.c)

describe(RCMCData.abort$santaclara.full.c.mr)
describe(RCMCData.abort$santaclara.full.c)
round(RCMCData.abort$santaclara.full.c.mr, 3)


#Midpoint (moderate) centered political orientation. Replace missing values with mean. 
RCMCData.abort$po.full.mr <- ifelse(is.na(RCMCData.abort$po.full),
                               mean(RCMCData.abort$po.full,na.rm=TRUE), RCMCData.abort$po.full)

describe(RCMCData.abort$po.full.mr)
describe(RCMCData.abort$po.full)
round(RCMCData.abort$po.full.mr, 3)

# Tables for Linda
cordata<-RCMCData.abort[,c("po.full.mr","santaclara.full.mr","abort.rcfull.mr","abort.mcfull.mr")]
apa.cor.table(cordata, show.conf.interval = FALSE, landscape = FALSE)
cordatamatrix<-as.matrix(cordata)
rcorr(cordatamatrix, type = "pearson")

##################################################
####T1 Moral conviction for abortion. 

RCMCData.abort$abort.rcfull.c.mr.v <- as.vector(RCMCData.abort$abort.rcfull.c.mr)
RCMCData.abort$santaclara.full.c.mr.v <- as.vector(RCMCData.abort$santaclara.full.c.mr)
RCMCData.abort$abort.mcfull.mr.v <- as.vector(RCMCData.abort$abort.mcfull.mr)
RCMCData.abort$po.full.mr.v <- as.vector(RCMCData.abort$po.full.mr)

cor(RCMCData.abort$abort.rcfull.c.mr.v,RCMCData.abort$abort.mcfull.mr.v)
cor(RCMCData.abort$santaclara.full.c.mr.v,RCMCData.abort$abort.rcfull.c.mr.v)
cor(RCMCData.abort$santaclara.full.c.mr.v,RCMCData.abort$abort.mcfull.mr.v)
cor(RCMCData.abort$santaclara.full.c.mr.v,RCMCData.abort$po.full.mr)
cor(RCMCData.abort$abort.rcfull.c.mr.v,RCMCData.abort$po.full.mr)
cor(RCMCData.abort$po.full.mr,RCMCData.abort$abort.mcfull.mr.v)


#Main effects political orientation, religious conviction for abstince, religiosity 

mcABORT.mainV <- lm(abort.mcfull.mr.v ~ abort.rcfull.c.mr.v
                    + santaclara.full.c.mr.v
                    + po.full.mr.v,
                    data = RCMCData.abort) 
summary(mcABORT.mainV)

cor(RCMCData.abort$abort.rcfull.c.mr.v,RCMCData.abort$abort.mcfull.mr.v)


#Mmain effects & 2-way Interactions

mcABORT.2wayV <- lm(abort.mcfull.mr.v ~ abort.rcfull.c.mr.v
                    + santaclara.full.c.mr.v
                    + po.full.mr.v
                    + abort.rcfull.c.mr.v*santaclara.full.c.mr.v
                    + po.full.mr.v*abort.rcfull.c.mr.v
                    + santaclara.full.c.mr.v*po.full.mr.v,
                    data = RCMCData.abort) 
summary(mcABORT.2wayV)
anova(mcABORT.mainV,mcABORT.2wayV)

#main effects, 2 way, and 3 way interaction
mcABORT.3wayV <- lm(abort.mcfull.mr.v ~ abort.rcfull.c.mr.v
                    + santaclara.full.c.mr.v
                    + po.full.mr.v
                    + abort.rcfull.c.mr.v*santaclara.full.c.mr.v
                    + po.full.mr.v*abort.rcfull.c.mr.v
                    + santaclara.full.c.mr.v*po.full.mr.v
                    + abort.rcfull.c.mr.v*santaclara.full.c.mr.v*po.full.mr.v,
                    data = RCMCData.abort) 
summary(mcABORT.3wayV)
anova(mcABORT.2wayV,mcABORT.3wayV)

stargazer(mcABORT.3wayV,type="text", title = "3 way", out="mcABORT.3wayV.txt")

##Nice table of all the steps
stargazer(mcABORT.mainV,mcABORT.2wayV,mcABORT.3wayV, type="text",
          column.labels = c("Main Effects", "2-way Interactions", "3-way Interaction"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE,
          out="mcABORT.3wayfull.txt")

#Plotting the RC x Religiosity 2 way interaction.
describe(RCMCData.abort$santaclara.full.c.mr.v)
describe(RCMCData.abort$abort.rcfull.c.mr.v)

mcABORT.RCAtRel <- plotSlopes(mcABORT.2wayV, plotx="abort.rcfull.c.mr.v", modx="santaclara.full.c.mr.v", 
                              xlab = "Religious Conviction for Abortion", ylab = "Moral Conviction for Abortion", 
                              modxVals = c(-1.51, 0, 1.51), xlim = c(-1.13, 2.87), plotPoints = F, 
                              legendTitle = "Religiosity")

mcABORT.RCAtRel.test <- testSlopes(mcABORT.RCAtRel)

mcABORT.RCAtRel.test$hypotests



#Plotting pretty with ggplot
#Plotting the religiosity by religious conviction interaction predicting moral conviction.
#The effect of religious conviction at  one standard deviation above and below religiosity (sd = 1.51).
summary(mcABORT.2wayV)
describe(RCMCData.abort$santaclara.full.c.mr.v)
describe(RCMCData.abort$abort.rcfull.c.mr.v)

#Getting the effects for the religiosity by Religious conviction interaction
# at 1 SD below mean,  and 1 SD above, and the mean (-1.51, 0, 1.51).
# Specifying the full range of religious conviction (min = -1.13 max = 2.87, every one unit) 
# The variable is mean centered, so this translates to the original points on the 1-5 scale.
mcABORT.RCAtRel.fitted<-effect('abort.rcfull.c.mr.v:santaclara.full.c.mr.v', mcABORT.2wayV,
                               xlevels=list(santaclara.full.c.mr.v=c(-1.51, 0, 1.51),
                                            abort.rcfull.c.mr.v = seq(from = -1.13, to = 2.87, by =1)), 
                               se=TRUE,confidence.level=.95)

#Saving the effects as a data frame. 
mcABORT.RCAtRel.Eff<-as.data.frame(mcABORT.RCAtRel.fitted)

#Recoding the moderator variable (religiosity) as a factor with the names of the groups. 
mcABORT.RCAtRel.Eff$santaclaramod<-factor(mcABORT.RCAtRel.Eff$santaclara.full.c.mr.v,
                                          levels=c(-1.51,0,1.51),
                                          labels=c("Low Religiosity","Mean Religiosity", "High Religiosity"))

mcABORT.RCAtRel.Plot <-ggplot(data = mcABORT.RCAtRel.Eff, aes(x = abort.rcfull.c.mr.v, y =fit, group=santaclaramod))+
  coord_cartesian(xlim=c(-1.13, 2.87),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -1.13, to = 2.87, by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=santaclaramod, linetype = santaclaramod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=santaclaramod),alpha=.2)+
  xlab("Abortion Religious Conviction")+
  ylab("Abortion Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .87))
mcABORT.RCAtRel.Plot

#Plotting the PO x Religiosity 2-way Interaction 

describe(RCMCData.abort$santaclara.full.c.mr.v)
describe(RCMCData.abort$po.full.mr.v)

mcABORT.POAtRel <- plotSlopes(mcABORT.2wayV, plotx="santaclara.full.c.mr.v", modx="po.full.mr.v", 
                              xlab = "Religiosity", ylab = "Moral Conviction for Abortion", 
                              modxVals = c(-2.62, 0, 2.62), xlim = c(-1.38, 2.62), plotPoints = F, 
                              legendTitle = "Political Orientation")

mcABORT.POAtRel.test <- testSlopes(mcABORT.POAtRel)

mcABORT.POAtRel.test$hypotests



#Plotting pretty with ggplot
#Plotting the religiosity by PO interaction predicting moral conviction.
#The effect of religiosity at  one standard deviation above and below moderate PO (sd = 2.62).
summary(mcABORT.2wayV)
describe(RCMCData.abort$santaclara.full.c.mr.v)
describe(RCMCData.abort$po.full.mr.v)

#Getting the effects for the religiosity by PO interaction
# at 1 SD below mean,  and 1 SD above, and moderate (-2.62, 0, 2.62).
# Specifying the full range of religiousity (min = -1.38 max = 2.62, every one unit) 
# The variable is mean centered, so this translates to the original points on the 1-5 scale.
mcABORT.POAtRel.fitted<-effect('santaclara.full.c.mr.v:po.full.mr.v', mcABORT.2wayV,
                               xlevels=list(po.full.mr.v=c(-2.62, 0, 2.62),
                                            santaclara.full.c.mr.v = seq(from = -1.38, to = 2.62, by =1)), 
                               se=TRUE,confidence.level=.95)

#Saving the effects as a data frame. 
mcABORT.POAtRel.Eff<-as.data.frame(mcABORT.POAtRel.fitted)

#Recoding the moderator variable (religiosity) as a factor with the names of the groups. 
mcABORT.POAtRel.Eff$POmod<-factor(mcABORT.POAtRel.Eff$po.full.mr.v,
                                  levels=c(-2.62,0,2.62),
                                  labels=c("Liberals","Moderates", "Conservatives"))

mcABORT.POAtRel.Plot <-ggplot(data = mcABORT.POAtRel.Eff, aes(x = santaclara.full.c.mr.v, y =fit, group=POmod))+
  coord_cartesian(xlim=c(-1.38, 2.62),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -1.38, to = 2.62, by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=POmod, linetype = POmod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=POmod),alpha=.2)+
  xlab("Religiosity")+
  ylab("Abortion Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .87))
mcABORT.POAtRel.Plot


#################################
##### For prayer in schools #####
#################################
RCMCData.prayer <- subset(RCMCData, imcpass == 1)

# To fill in missing values with non-centered mean to be used in descriptives and correlation tables
RCMCData.prayer$prayer.rcfull.mr <- ifelse(is.na(RCMCData.prayer$prayer.rcfull),
                                     mean(RCMCData.prayer$prayer.rcfull,na.rm=TRUE), RCMCData.prayer$prayer.rcfull)
describe(RCMCData.prayer$prayer.rcfull.mr)

RCMCData.prayer$santaclara.full.mr <- ifelse(is.na(RCMCData.prayer$santaclara.full),
                                       mean(RCMCData.prayer$santaclara.full,na.rm=TRUE), RCMCData.prayer$santaclara.full)

describe(RCMCData.prayer$santaclara.full.mr)

#center continuous predictors 

#religious conviction
RCMCData.prayer$prayer.rcfull.c <- scale(RCMCData.prayer$prayer.rcfull, scale=FALSE)
describe(RCMCData.prayer$prayer.rcfull.c, na.rm = TRUE)

#religiosity
RCMCData.prayer$santaclara.full.c <- scale(RCMCData.prayer$santaclara.full, scale=FALSE)
describe(RCMCData.prayer$santaclara.full.c, na.rm = TRUE)

#leave PO median centered at zero.

### Creating mean replacement variables to take care of missingness.
#If else statement: if value of the variable is missing, replace with the mean of the variable, else use the original value.

#Mean centered religious conviction. Replace missing values with mean (0 since it's mean centered). 
RCMCData.prayer$prayer.rcfull.c.mr <- ifelse(is.na(RCMCData.prayer$prayer.rcfull.c),
                                       mean(RCMCData.prayer$prayer.rcfull.c,na.rm=TRUE), RCMCData.prayer$prayer.rcfull.c)

describe(RCMCData.prayer$prayer.rcfull.c)
describe(RCMCData.prayer$prayer.rcfull.c.mr)
round(RCMCData.prayer$prayer.rcfull.c.mr, 3)

#Moral conviction. Replace missing values with mean
RCMCData.prayer$prayer.mcfull.mr <- ifelse(is.na(RCMCData.prayer$prayer.mcfull),
                                     mean(RCMCData.prayer$prayer.mcfull,na.rm=TRUE), RCMCData.prayer$prayer.mcfull)

describe(RCMCData.prayer$prayer.mcfull.mr)
describe(RCMCData.prayer$prayer.mcfull)
round(RCMCData.prayer$prayer.mcfull.mr, 3)

#mean centered religiosity. Replace missing values with mean (0 since it's mean centered). 
RCMCData.prayer$santaclara.full.c.mr <- ifelse(is.na(RCMCData.prayer$santaclara.full.c),
                                         mean(RCMCData.prayer$santaclara.full.c,na.rm=TRUE), RCMCData.prayer$santaclara.full.c)

describe(RCMCData.prayer$santaclara.full.c.mr)
describe(RCMCData.prayer$santaclara.full.c)
round(RCMCData.prayer$santaclara.full.c.mr, 3)


#Midpoint (moderate) centered political orientation. Replace missing values with mean. 
RCMCData.prayer$po.full.mr <- ifelse(is.na(RCMCData.prayer$po.full),
                               mean(RCMCData.prayer$po.full,na.rm=TRUE), RCMCData.prayer$po.full)

describe(RCMCData.prayer$po.full.mr)
describe(RCMCData.prayer$po.full)
round(RCMCData.prayer$po.full.mr, 3)

# Tables for Linda
cordata<-RCMCData.prayer[,c("po.full.mr","santaclara.full.mr","prayer.rcfull.mr","prayer.mcfull.mr")]
apa.cor.table(cordata, show.conf.interval = FALSE, landscape = FALSE)
cordatamatrix<-as.matrix(cordata)
rcorr(cordatamatrix, type = "pearson")

##################################################
####T1 Moral conviction for abortion. 

RCMCData.prayer$prayer.rcfull.c.mr.v <- as.vector(RCMCData.prayer$prayer.rcfull.c.mr)
RCMCData.prayer$santaclara.full.c.mr.v <- as.vector(RCMCData.prayer$santaclara.full.c.mr)
RCMCData.prayer$prayer.mcfull.mr.v <- as.vector(RCMCData.prayer$prayer.mcfull.mr)
RCMCData.prayer$po.full.mr.v <- as.vector(RCMCData.prayer$po.full.mr)

cor(RCMCData.prayer$prayer.rcfull.c.mr.v,RCMCData.prayer$prayer.mcfull.mr.v)
cor(RCMCData.prayer$santaclara.full.c.mr.v,RCMCData.prayer$prayer.rcfull.c.mr.v)
cor(RCMCData.prayer$santaclara.full.c.mr.v,RCMCData.prayer$prayer.mcfull.mr.v)
cor(RCMCData.prayer$santaclara.full.c.mr.v,RCMCData.prayer$po.full.mr)
cor(RCMCData.prayer$prayer.rcfull.c.mr.v,RCMCData.prayer$po.full.mr)
cor(RCMCData.prayer$po.full.mr,RCMCData.prayer$prayer.mcfull.mr.v)


#Main effects political orientation, religious conviction for abstince, religiosity 

mcPRAY.mainV <- lm(prayer.mcfull.mr.v ~ prayer.rcfull.c.mr.v
                   + santaclara.full.c.mr.v
                   + po.full.mr.v,
                   data = RCMCData.prayer) 
summary(mcPRAY.mainV)

cor(RCMCData.prayer$prayer.rcfull.c.mr.v,RCMCData.prayer$prayer.mcfull.mr.v)


#Mmain effects & 2-way Interactions

mcPRAY.2wayV <- lm(prayer.mcfull.mr.v ~ prayer.rcfull.c.mr.v
                   + santaclara.full.c.mr.v
                   + po.full.mr.v
                   + prayer.rcfull.c.mr.v*santaclara.full.c.mr.v
                   + po.full.mr.v*prayer.rcfull.c.mr.v
                   + santaclara.full.c.mr.v*po.full.mr.v,
                   data = RCMCData.prayer) 
summary(mcPRAY.2wayV)
anova(mcPRAY.mainV,mcPRAY.2wayV)

#main effects, 2 way, and 3 way interaction
mcPRAY.3wayV <- lm(prayer.mcfull.mr.v ~ prayer.rcfull.c.mr.v
                   + santaclara.full.c.mr.v
                   + po.full.mr.v
                   + prayer.rcfull.c.mr.v*santaclara.full.c.mr.v
                   + po.full.mr.v*prayer.rcfull.c.mr.v
                   + santaclara.full.c.mr.v*po.full.mr.v
                   + prayer.rcfull.c.mr.v*santaclara.full.c.mr.v*po.full.mr.v,
                   data = RCMCData.prayer) 
summary(mcPRAY.3wayV)
anova(mcPRAY.2wayV,mcPRAY.3wayV)

stargazer(mcPRAY.3wayV,type="text", title = "3 way", out="mcPRAY.3wayV.txt")

##Nice table of all the steps
stargazer(mcPRAY.mainV,mcPRAY.2wayV,mcPRAY.3wayV, type="text",
          column.labels = c("Main Effects", "2-way Interactions", "3-way Interaction"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE,
          out="mcPRAY.3wayfull.txt")

#Plotting the RC x Religiosity 2 way interaction.
describe(RCMCData.prayer$santaclara.full.c.mr.v)
describe(RCMCData.prayer$prayer.rcfull.c.mr.v)

mcPRAY.RCAtRel <- plotSlopes(mcPRAY.2wayV, plotx="prayer.rcfull.c.mr.v", modx="santaclara.full.c.mr.v", 
                             xlab = "Religious Conviction for Prayer in Public Schools", ylab = "Moral Conviction for Prayer in Public Schools", 
                             modxVals = c(-1.51, 0, 1.51), xlim = c(-1.45, 2.55), plotPoints = F, 
                             legendTitle = "Religiosity")

mcPRAY.RCAtRel.test <- testSlopes(mcPRAY.RCAtRel)

mcPRAY.RCAtRel.test$hypotests



#Plotting pretty with ggplot
#Plotting the religiosity by religious conviction interaction predicting moral conviction.
#The effect of religious conviction at  one standard deviation above and below religiosity (sd = 1.51).
summary(mcPRAY.2wayV)
describe(RCMCData.prayer$santaclara.full.c.mr.v)
describe(RCMCData.prayer$prayer.rcfull.c.mr.v)

#Getting the effects for the religiosity by Religious conviction interaction
# at 1 SD below mean,  and 1 SD above, and the mean (-1.51, 0, 1.51).
# Specifying the full range of religious conviction (min = -1.45 max = 2.55, every one unit) 
# The variable is mean centered, so this translates to the original points on the 1-5 scale.
mcPRAY.RCAtRel.fitted<-effect('prayer.rcfull.c.mr.v:santaclara.full.c.mr.v', mcPRAY.2wayV,
                              xlevels=list(santaclara.full.c.mr.v=c(-1.51, 0, 1.51),
                                           prayer.rcfull.c.mr.v = seq(from = -1.45, to = 2.55, by =1)), 
                              se=TRUE,confidence.level=.95)

#Saving the effects as a data frame. 
mcPRAY.RCAtRel.Eff<-as.data.frame(mcPRAY.RCAtRel.fitted)

#Recoding the moderator variable (religiosity) as a factor with the names of the groups. 
mcPRAY.RCAtRel.Eff$santaclaramod<-factor(mcPRAY.RCAtRel.Eff$santaclara.full.c.mr.v,
                                         levels=c(-1.51,0,1.51),
                                         labels=c("Low Religiosity","Mean Religiosity", "High Religiosity"))

mcPRAY.RCAtRel.Plot <-ggplot(data = mcPRAY.RCAtRel.Eff, aes(x = prayer.rcfull.c.mr.v, y =fit, group=santaclaramod))+
  coord_cartesian(xlim=c(-1.45, 2.55),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -1.45, to = 2.55, by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=santaclaramod, linetype = santaclaramod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=santaclaramod),alpha=.2)+
  xlab("Prayer in Public Schools Religious Conviction")+
  ylab("Prayer in Public Schools Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .87))
mcPRAY.RCAtRel.Plot


#######################################################################################################################
##### For climate change issue: Do you support/oppose the idea that human activity contributes to climate change? #####
#######################################################################################################################
RCMCData.climate <- subset(RCMCData, imcpass == 1)

describe(RCMCData.climate$climate.mcfull)
describe(RCMCData.climate$climate.rcfull)
describe(RCMCData.climate$po.full)
describe(RCMCData.climate$santaclara.full)

RCMCData.climate$climate.rcfull.c <- scale(RCMCData.climate$climate.rcfull, scale = FALSE)[,]
describe(RCMCData.climate$climate.rcfull.c)

RCMCData.climate$santaclara.full.c <- scale(RCMCData.climate$santaclara.full, scale = FALSE)[,]
describe(RCMCData.climate$santaclara.full.c)

### Creating mean replacement variables to take care of missingness.
#If else statement: if value of the variable is missing, replace with the mean of the variable, else use the original value.

#Mean centered religious conviction for climate change. Replace missing values with mean (0 since it's mean centered). 
RCMCData.climate$climate.rcfullMR <- ifelse(is.na(RCMCData.climate$climate.rcfull),
                                                     mean(RCMCData.climate$climate.rcfull,na.rm=TRUE), RCMCData.climate$climate.rcfull)

describe(RCMCData.climate$climate.rcfull)
describe(RCMCData.climate$climate.rcfullMR)

RCMCData.climate$climate.rcfull.cMR <- ifelse(is.na(RCMCData.climate$climate.rcfull.c),
                                     mean(RCMCData.climate$climate.rcfull.c,na.rm=TRUE), RCMCData.climate$climate.rcfull.c)

describe(RCMCData.climate$climate.rcfull.c)
describe(RCMCData.climate$climate.rcfull.cMR)


#Midpoint centered political orientation. Replace missing values with mean. 
RCMCData.climate$po.fullMR <- ifelse(is.na(RCMCData.climate$po.full),
                                          mean(RCMCData.climate$po.full,na.rm=TRUE), RCMCData.climate$po.full)

describe(RCMCData.climate$po.full)
describe(RCMCData.climate$po.fullMR)


#Mean centered religiosity for climate change. Replace missing values with mean (0 since it's mean centered). 
RCMCData.climate$santaclara.fullMR <- ifelse(is.na(RCMCData.climate$santaclara.full),
                                                              mean(RCMCData.climate$santaclara.full,na.rm=TRUE), RCMCData.climate$santaclara.full)

describe(RCMCData.climate$santaclara.full)
describe(RCMCData.climate$santaclara.fullMR)

RCMCData.climate$santaclara.full.cMR <- ifelse(is.na(RCMCData.climate$santaclara.full.c),
                                                     mean(RCMCData.climate$santaclara.full.c,na.rm=TRUE), RCMCData.climate$santaclara.full.c)

describe(RCMCData.climate$santaclara.full.c)
describe(RCMCData.climate$santaclara.full.cMR)


#Moral conviction for climate change. Replace missing values with mean. 
RCMCData.climate$climate.mcfullMR <- ifelse(is.na(RCMCData.climate$climate.mcfull),
                                          mean(RCMCData.climate$climate.mcfull,na.rm=TRUE), RCMCData.climate$climate.mcfull)

describe(RCMCData.climate$climate.mcfull)
describe(RCMCData.climate$climate.mcfullMR)


###############################################
#### Moral conviction about climate change ####

#Main effects political orientation, climate change religious conviction, religiosity
mcclimate.main <- lm(climate.mcfullMR ~ po.fullMR
                  + santaclara.full.cMR
                  + climate.rcfull.cMR,
                  data = RCMCData.climate) 
summary(mcclimate.main)

#Mmain effects & 2-way Interactions
mcclimate.2way <- lm(climate.mcfullMR ~ po.fullMR
                  + santaclara.full.cMR
                  + climate.rcfull.cMR
                  + santaclara.full.cMR*climate.rcfull.cMR
                  + po.fullMR*santaclara.full.cMR
                  + po.fullMR*climate.rcfull.cMR,
                  data = RCMCData.climate) 
summary(mcclimate.2way)

anova(mcclimate.main,mcclimate.2way)

#Mmain effects, 2-way Interactions, and 3-way interaction
mcclimate.3way <- lm(climate.mcfullMR ~ po.fullMR
                  + santaclara.full.cMR
                  + climate.rcfull.cMR
                  + santaclara.full.cMR*climate.rcfull.cMR
                  + po.fullMR*santaclara.full.cMR
                  + po.fullMR*climate.rcfull.cMR
                  + santaclara.full.cMR*climate.rcfull.cMR*po.fullMR,
                  data = RCMCData.climate) 
summary(mcclimate.3way)

anova(mcclimate.main,mcclimate.2way,mcclimate.3way)

##Nice table of all the steps
stargazer(mcclimate.main,mcclimate.2way,mcclimate.3way,type="text",
          column.labels = c("Main Effects", "2-way Interactions", "3-way Interaction"),
          intercept.bottom = FALSE, star.cutoffs = c(.05,.01,.001),
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

# Tables for Linda
climatecordata<-RCMCData.climate[,c("po.fullMR","santaclara.fullMR","climate.rcfull.cMR","climate.mcfullMR")]
apa.cor.table(climatecordata, show.conf.interval = FALSE, landscape = FALSE)
climatecordatamatrix<-as.matrix(climatecordata)
rcorr(climatecordatamatrix, type = "pearson")

#Plotting
# No significant interactions


###################################################################################################
##### For tax on wealthy issue: Do you support/oppose raising taxes on top 1% income earners? #####
###################################################################################################
RCMCData.taxes <- subset(RCMCData, imcpass == 1)

describe(RCMCData.taxes$taxes.mcfull)
describe(RCMCData.taxes$taxes.rcfull)
describe(RCMCData.taxes$po.full)
describe(RCMCData.taxes$santaclara.full)

RCMCData.taxes$taxes.rcfull.c <- scale(RCMCData.taxes$taxes.rcfull, scale = FALSE)[,]
describe(RCMCData.taxes$taxes.rcfull.c)

RCMCData.taxes$santaclara.full.c <- scale(RCMCData.taxes$santaclara.full, scale = FALSE)[,]
describe(RCMCData.taxes$santaclara.full.c)

### Creating mean replacement variables to take care of missingness.
#If else statement: if value of the variable is missing, replace with the mean of the variable, else use the original value.

#Mean centered religious conviction for taxes. Replace missing values with mean (0 since it's mean centered). 
RCMCData.taxes$taxes.rcfullMR <- ifelse(is.na(RCMCData.taxes$taxes.rcfull),
                                                         mean(RCMCData.taxes$taxes.rcfull,na.rm=TRUE), RCMCData.taxes$taxes.rcfull)

describe(RCMCData.taxes$taxes.rcfull)
describe(RCMCData.taxes$taxes.rcfullMR)

RCMCData.taxes$taxes.rcfull.cMR <- ifelse(is.na(RCMCData.taxes$taxes.rcfull.c),
                                                           mean(RCMCData.taxes$taxes.rcfull.c,na.rm=TRUE), RCMCData.taxes$taxes.rcfull.c)

describe(RCMCData.taxes$taxes.rcfull.c)
describe(RCMCData.taxes$taxes.rcfull.cMR)


#Midpoint centered political orientation. Replace missing values with mean. 
RCMCData.taxes$po.fullMR <- ifelse(is.na(RCMCData.taxes$po.full),
                                                  mean(RCMCData.taxes$po.full,na.rm=TRUE), RCMCData.taxes$po.full)

describe(RCMCData.taxes$po.full)
describe(RCMCData.taxes$po.fullMR)


#Mean centered religiosity for taxes. Replace missing values with mean (0 since it's mean centered). 
RCMCData.taxes$santaclara.fullMR <- ifelse(is.na(RCMCData.taxes$santaclara.full),
                                                          mean(RCMCData.taxes$santaclara.full,na.rm=TRUE), RCMCData.taxes$santaclara.full)

describe(RCMCData.taxes$santaclara.full)
describe(RCMCData.taxes$santaclara.fullMR)

RCMCData.taxes$santaclara.full.cMR <- ifelse(is.na(RCMCData.taxes$santaclara.full.c),
                                                            mean(RCMCData.taxes$santaclara.full.c,na.rm=TRUE), RCMCData.taxes$santaclara.full.c)

describe(RCMCData.taxes$santaclara.full.c)
describe(RCMCData.taxes$santaclara.full.cMR)


#Moral conviction for taxes. Replace missing values with mean. 
RCMCData.taxes$taxes.mcfullMR <- ifelse(is.na(RCMCData.taxes$taxes.mcfull),
                                                         mean(RCMCData.taxes$taxes.mcfull,na.rm=TRUE), RCMCData.taxes$taxes.mcfull)

describe(RCMCData.taxes$taxes.mcfull)
describe(RCMCData.taxes$taxes.mcfullMR)


###############################################
#### Moral conviction about taxing wealthy ####

#Main effects political orientation, taxes religious conviction, religiosity
mctaxes.main <- lm(taxes.mcfullMR ~ po.fullMR
                     + santaclara.full.cMR
                     + taxes.rcfull.cMR,
                     data = RCMCData.taxes) 
summary(mctaxes.main)

#Mmain effects & 2-way Interactions
mctaxes.2way <- lm(taxes.mcfullMR ~ po.fullMR
                     + santaclara.full.cMR
                     + taxes.rcfull.cMR
                     + santaclara.full.cMR*taxes.rcfull.cMR
                     + po.fullMR*santaclara.full.cMR
                     + po.fullMR*taxes.rcfull.cMR,
                     data = RCMCData.taxes) 
summary(mctaxes.2way)

anova(mctaxes.main,mctaxes.2way)

#Mmain effects, 2-way Interactions, and 3-way interaction
mctaxes.3way <- lm(taxes.mcfullMR ~ po.fullMR
                     + santaclara.full.cMR
                     + taxes.rcfull.cMR
                     + santaclara.full.cMR*taxes.rcfull.cMR
                     + po.fullMR*santaclara.full.cMR
                     + po.fullMR*taxes.rcfull.cMR
                     + santaclara.full.cMR*taxes.rcfull.cMR*po.fullMR,
                     data = RCMCData.taxes) 
summary(mctaxes.3way)

anova(mctaxes.main,mctaxes.2way,mctaxes.3way)

##Nice table of all the steps
stargazer(mctaxes.main,mctaxes.2way,mctaxes.3way,type="text",
          column.labels = c("Main Effects", "2-way Interactions", "3-way Interaction"),
          intercept.bottom = FALSE, star.cutoffs = c(.05,.01,.001),
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

# Tables for Linda
taxescordata<-RCMCData.taxes[,c("po.fullMR","santaclara.fullMR","taxes.rcfull.cMR","taxes.mcfullMR")]
apa.cor.table(taxescordata, show.conf.interval = FALSE, landscape = FALSE)
taxescordatamatrix<-as.matrix(taxescordata)
rcorr(taxescordatamatrix, type = "pearson")

#Plotting
describe(RCMCData.taxes$po.fullMR)
describe(RCMCData.taxes$santaclara.full.cMR)
describe(RCMCData.taxes$santaclara.fullMR)

mctaxes.SCAtPO <- plotSlopes(mctaxes.2way, plotx="santaclara.full.cMR", modx="po.fullMR", 
                            xlab = "Religiosity", xlim = c(-1.38,2.62), ylab = "Taxing Wealthy Moral Conviction", 
                            modxVals = c(-2.62,0,2.62), plotPoints = FALSE,
                            legendTitle = "Political Orientation")

mctaxes.SCAtPO.test <- testSlopes(mctaxes.SCAtPO)
round(mctaxes.SCAtPO.test$hypotests,3)


#Plotting pretty with ggplot

#Plotting the Political orientation by religiosity interaction predicting moral conviction.
#The effect of religiosity at PO moderates and one standard deviation above and below moderate (2.62).
summary(mctaxes.2way)
describe(RCMCData.taxes$santaclara.full.cMR)

#Getting the effects for the PO by Religious conviction interaction
# at 1 SD below moderate, moderate, and 1 SD above moderate (-2.62, 0, 2.62).
# Specifying the full range of religiosity (min = -1.38 max = 2.62, every one unit) 
# The variable is mean centered, so this translates to the original points on the 1-5 scale.
mctaxes.SCAtPO.fitted<-effect('po.fullMR:santaclara.full.cMR', mctaxes.2way,
                              xlevels=list(po.fullMR=c(-2.62, 0, 2.62),
                                           santaclara.full.cMR = seq(from = -1.38, to = 2.62, by = 1)), 
                              se=TRUE,confidence.level=.95)

#Saving the effects as a data frame. 
mctaxes.SCAtPO.Eff<-as.data.frame(mctaxes.SCAtPO.fitted)

#Recoding the moderator variable (PO) as a factor with the names of the groups. 
mctaxes.SCAtPO.Eff$POmod<-factor(mctaxes.SCAtPO.Eff$po.fullMR,
                                 levels=c(-2.62,0,2.62),
                                 labels=c("Liberals","Moderates","Conservatives"))

mctaxes.SCAtPO.Plot <-ggplot(data = mctaxes.SCAtPO.Eff, aes(x = santaclara.full.cMR, y =fit, group=POmod))+
  coord_cartesian(xlim=c(-1.38, 2.62),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -1.38, to = 2.62, by = 1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=POmod, linetype = POmod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=POmod),alpha=.2)+
  xlab("Religiosity")+
  ylab("Taxing Wealthy Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.65, .77))
mctaxes.SCAtPO.Plot


####################################################################################################################
##### For transgender bathroom issue: Do you support/oppose transgender people using bathroom of their choice? #####
####################################################################################################################
RCMCData.trans <- subset(RCMCData, imcpass == 1)

describe(RCMCData.trans$trans.mcfull)
describe(RCMCData.trans$trans.rcfull)
describe(RCMCData.trans$po.full)
describe(RCMCData.trans$santaclara.full)

RCMCData.trans$trans.rcfull.c <- scale(RCMCData.trans$trans.rcfull, scale = FALSE)[,]
describe(RCMCData.trans$trans.rcfull.c)

RCMCData.trans$santaclara.full.c <- scale(RCMCData.trans$santaclara.full, scale = FALSE)[,]
describe(RCMCData.trans$santaclara.full.c)

### Creating mean replacement variables to take care of missingness.
#If else statement: if value of the variable is missing, replace with the mean of the variable, else use the original value.

#Mean centered religious conviction for trans. Replace missing values with mean (0 since it's mean centered). 
RCMCData.trans$trans.rcfullMR <- ifelse(is.na(RCMCData.trans$trans.rcfull),
                                                     mean(RCMCData.trans$trans.rcfull,na.rm=TRUE), RCMCData.trans$trans.rcfull)

describe(RCMCData.trans$trans.rcfull)
describe(RCMCData.trans$trans.rcfullMR)

RCMCData.trans$trans.rcfull.cMR <- ifelse(is.na(RCMCData.trans$trans.rcfull.c),
                                                       mean(RCMCData.trans$trans.rcfull.c,na.rm=TRUE), RCMCData.trans$trans.rcfull.c)

describe(RCMCData.trans$trans.rcfull.c)
describe(RCMCData.trans$trans.rcfull.cMR)


#Midpoint centered political orientation. Replace missing values with mean. 
RCMCData.trans$po.fullMR <- ifelse(is.na(RCMCData.trans$po.full),
                                                mean(RCMCData.trans$po.full,na.rm=TRUE), RCMCData.trans$po.full)

describe(RCMCData.trans$po.full)
describe(RCMCData.trans$po.fullMR)


#Mean centered religiosity for trans. Replace missing values with mean (0 since it's mean centered). 
RCMCData.trans$santaclara.fullMR <- ifelse(is.na(RCMCData.trans$santaclara.full),
                                                        mean(RCMCData.trans$santaclara.full,na.rm=TRUE), RCMCData.trans$santaclara.full)

describe(RCMCData.trans$santaclara.full)
describe(RCMCData.trans$santaclara.fullMR)

RCMCData.trans$santaclara.full.cMR <- ifelse(is.na(RCMCData.trans$santaclara.full.c),
                                                          mean(RCMCData.trans$santaclara.full.c,na.rm=TRUE), RCMCData.trans$santaclara.full.c)

describe(RCMCData.trans$santaclara.full.c)
describe(RCMCData.trans$santaclara.full.cMR)


#Moral conviction for trans. Replace missing values with mean. 
RCMCData.trans$trans.mcfullMR <- ifelse(is.na(RCMCData.trans$trans.mcfull),
                                                     mean(RCMCData.trans$trans.mcfull,na.rm=TRUE), RCMCData.trans$trans.mcfull)

describe(RCMCData.trans$trans.mcfull)
describe(RCMCData.trans$trans.mcfullMR)


###############################################
#### Moral conviction about trans bathroom ####

#Main effects political orientation, trans religious conviction, religiosity
mctrans.main <- lm(trans.mcfullMR ~ po.fullMR
                   + santaclara.full.cMR
                   + trans.rcfull.cMR,
                   data = RCMCData.trans) 
summary(mctrans.main)

#Mmain effects & 2-way Interactions
mctrans.2way <- lm(trans.mcfullMR ~ po.fullMR
                   + santaclara.full.cMR
                   + trans.rcfull.cMR
                   + santaclara.full.cMR*trans.rcfull.cMR
                   + po.fullMR*santaclara.full.cMR
                   + po.fullMR*trans.rcfull.cMR,
                   data = RCMCData.trans) 
summary(mctrans.2way)

anova(mctrans.main,mctrans.2way)

#Mmain effects, 2-way Interactions, and 3-way interaction
mctrans.3way <- lm(trans.mcfullMR ~ po.fullMR
                   + santaclara.full.cMR
                   + trans.rcfull.cMR
                   + santaclara.full.cMR*trans.rcfull.cMR
                   + po.fullMR*santaclara.full.cMR
                   + po.fullMR*trans.rcfull.cMR
                   + santaclara.full.cMR*trans.rcfull.cMR*po.fullMR,
                   data = RCMCData.trans) 
summary(mctrans.3way)

anova(mctrans.main,mctrans.2way,mctrans.3way)

##Nice table of all the steps
stargazer(mctrans.main,mctrans.2way,mctrans.3way,type="text",
          column.labels = c("Main Effects", "2-way Interactions", "3-way Interaction"),
          intercept.bottom = FALSE, star.cutoffs = c(.05,.01,.001),
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

# Tables for Linda
transcordata<-RCMCData.trans[,c("po.fullMR","santaclara.fullMR","trans.rcfull.cMR","trans.mcfullMR")]
apa.cor.table(transcordata, show.conf.interval = FALSE, landscape = FALSE)
transcordatamatrix<-as.matrix(transcordata)
rcorr(transcordatamatrix, type = "pearson")

#Plotting
describe(RCMCData.trans$po.fullMR)
describe(RCMCData.trans$trans.rcfull.cMR)

mctrans.RCAtPO <- plotSlopes(mctrans.2way, plotx="trans.rcfull.cMR", modx="po.fullMR", 
                             xlab = "Religious Conviction Transgender Bathroom Choice", xlim = c(-.99,3.01),ylab = "Transgender Bathroom Choice Moral Conviction", 
                             modxVals = c(-2.62,0,2.62), plotPoints = FALSE,
                             legendTitle = "Political Orientation")

mctrans.RCAtPO.test <- testSlopes(mctrans.RCAtPO)
round(mctrans.RCAtPO.test$hypotests,3)

#Plotting pretty with ggplot

#Plotting the Political orientation by religious conviction interaction predicting moral conviction.
#The effect of religious conviction at PO moderates and one standard deviation above and below moderate (2.62).
summary(mctrans.2way)
describe(RCMCData.trans$trans.rcfull.cMR)

#Getting the effects for the PO by Religious conviction interaction
# at 1 SD below moderate, moderate, and 1 SD above moderate (-2.62, 0, 2.62).
# Specifying the full range of religious conviction (min = -0.99 max = 3.01, every one unit) 
# The variable is mean centered, so this translates to the original points on the 1-5 scale.
mctrans.RCAtPO.fitted<-effect('po.fullMR:trans.rcfull.cMR', mctrans.2way,
                              xlevels=list(po.fullMR=c(-2.62, 0, 2.62),
                                           trans.rcfull.cMR = seq(from = -.99, to = 3.01, by = 1)), 
                              se=TRUE,confidence.level=.95)

#Saving the effects as a data frame. 
mctrans.RCAtPO.Eff<-as.data.frame(mctrans.RCAtPO.fitted)

#Recoding the moderator variable (PO) as a factor with the names of the groups. 
mctrans.RCAtPO.Eff$POmod<-factor(mctrans.RCAtPO.Eff$po.fullMR,
                                 levels=c(-2.62,0,2.62),
                                 labels=c("Liberals","Moderates","Conservatives"))

mctrans.RCAtPO.Plot <-ggplot(data = mctrans.RCAtPO.Eff, aes(x = trans.rcfull.cMR, y =fit, group=POmod))+
  coord_cartesian(xlim=c(-.99, 3.01),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -.99, to = 3.01, by = 1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=POmod, linetype = POmod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=POmod),alpha=.2)+
  xlab("Transgender Bathroom Religious Conviction")+
  ylab("Transgender Bathroom Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.55, .27))
mctrans.RCAtPO.Plot


####################
### Descriptives ###
####################

describe(RCMCData.climate$age)

str(RCMCData.climate$gender)
RCMCData.climate$gender.f<-factor(RCMCData.climate$gender, levels = seq(1:7),
                                               labels = c("female","male","other","rather not say","transgender female",
                                                          "transgender male","gender queer"))
prop.table(table(RCMCData.climate$gender.f))*100

str(RCMCData.climate$edu)
RCMCData.climate$edu.f<-factor(RCMCData.climate$edu, levels = c(7,6,5,4,3,2,1),
                                       labels = c("Doctoral / professional degree","Master's degree",
                                                  "4-year college degree","2-year college degree",
                                                  "Some college","High school / GED",
                                                  "Less than high school"))
prop.table(table(RCMCData.climate$edu.f))*100


climatemc.alpha <- alpha(RCMCData.climate[,c("climate.mc1","climate.mc2","climate.mc3","climate.mc4")])
climatemc.alpha

taxesmc.alpha <- alpha(RCMCData.climate[,c("taxes.mc1","taxes.mc2","taxes.mc3","taxes.mc4")])
taxesmc.alpha

transmc.alpha <- alpha(RCMCData.climate[,c("trans.mc1","trans.mc2","trans.mc3","trans.mc4")])
transmc.alpha

climaterc.alpha <- alpha(RCMCData.climate[,c("climate.rc1","climate.rc2")])
climaterc.alpha

taxesrc.alpha <- alpha(RCMCData.climate[,c("taxes.rc1","taxes.rc2")])
taxesrc.alpha

transrc.alpha <- alpha(RCMCData.climate[,c("trans.rc1","trans.rc2")])
transrc.alpha

santaclara.alpha <- alpha(RCMCData.climate[,c("santaclara1","santaclara2","santaclara3")])
santaclara.alpha

