###################################
########### Interaction follow-ups 
###### RC and MC distinct

library(rockchalk) #Graphing simple slopes; moderation
library(stargazer) #Handy regression tables
library(foreign)  # Read in SPSS
library(gvlma)   #helper on diagnostics
library(effects) #helper on visualizing interactions - Uses lattice
library(sjPlot)  #helper on visualizing interactions - uses ggplot
library(ggplot2) #All the graphs
library(psych) #handy for descriptives, etc
library(dplyr) 
library(apaTables)
library(texreg)
library(Hmisc)
describe <- psych::describe

#set working directory
setwd("")

ConsensusData<-read.spss("MCRC_Study1_Data.sav", use.value.labels = FALSE, to.data.frame = TRUE,
                 max.value.labels = Inf, trim.factor.names = FALSE,
                 trim_values = TRUE, reencode = NA, use.missings = to.data.frame)
str(ConsensusData)
head(ConsensusData)

describe(ConsensusData$sodamcfull)
describe(ConsensusData$sodarc)
describe(ConsensusData$pofull)

ConsensusData$sodarc.c <- scale(ConsensusData$sodarc, scale = FALSE)[,]
describe(ConsensusData$sodarc.c)

### Creating mean replacement variables to take care of missingness.
#If else statement: if value of the variable is missing, replace with the mean of the variable, else use the original value.

#Mean centered time religious conviction for soda taxes. Replace missing values with mean (0 since it's mean centered). 
ConsensusData$sodarcMR <- ifelse(is.na(ConsensusData$sodarc),
                                          mean(ConsensusData$sodarc,na.rm=TRUE), ConsensusData$sodarc)

describe(ConsensusData$sodarc)
describe(ConsensusData$sodarcMR)

ConsensusData$sodarc.cMR <- ifelse(is.na(ConsensusData$sodarc.c),
                                     mean(ConsensusData$sodarc.c,na.rm=TRUE), ConsensusData$sodarc.c)

describe(ConsensusData$sodarc.c)
describe(ConsensusData$sodarc.cMR)


#Midpoint centered political orientation. Replace missing values with mean. 
ConsensusData$pofullMR <- ifelse(is.na(ConsensusData$pofull),
                                          mean(ConsensusData$pofull,na.rm=TRUE), ConsensusData$pofull)

describe(ConsensusData$pofull)
describe(ConsensusData$pofullMR)


#Moral conviction for soda taxes. Replace missing values with mean. 
ConsensusData$sodamcfullMR <- ifelse(is.na(ConsensusData$sodamcfull),
                                          mean(ConsensusData$sodamcfull,na.rm=TRUE), ConsensusData$sodamcfull)

describe(ConsensusData$sodamcfull)
describe(ConsensusData$sodamcfullMR)


############################################
#### Moral conviction about soda taxes ####

#Main effects political orientation, soda tax religious conviction 
mcSoda.main <- lm(sodamcfullMR ~ pofullMR
                  + sodarc.cMR,
                  data = ConsensusData) 
summary(mcSoda.main)

#Mmain effects & 2-way Interactions
mcSoda.2way <- lm(sodamcfullMR ~ pofullMR*sodarc.cMR,
                  data = ConsensusData) 
summary(mcSoda.2way)

anova(mcSoda.main,mcSoda.2way)

##Nice table of all the steps
stargazer(mcSoda.main,mcSoda.2way,type="text",
          column.labels = c("Main Effects", "Two-Way Interaction"), dep.var.caption = "",
          dep.var.labels = "Soda Tax Moral Conviction",
          intercept.bottom = FALSE, keep.stat = c("f","n","rsq","adj.rsq","max.rsq"),
          add.lines = list(c("\U0394 R2","","")),
          single.row=FALSE, omit.table.layout = "#",
          star.char = c("*", "**", "***"), 
          notes= c("*p < .05 **p < .01 ***p < .001"),
          notes.append = FALSE, digits = 2, notes.align = "l", star.cutoffs = c(.05,.01,.001),
          header=FALSE)

# Tables for Linda
sodacordata<-subset(ConsensusData[,c("pofullMR","sodarcMR","sodamcfullMR")])
apa.cor.table(sodacordata, show.conf.interval = FALSE, landscape = FALSE)
sodacordatamatrix<-as.matrix(sodacordata)
rcorr(sodacordatamatrix, type = "pearson")

#Plotting
## No significant interactions

### Descriptives ###
describe(ConsensusData$age)

str(ConsensusData$gender)
attr(ConsensusData$gender, "value.labels")
ConsensusData$gender.f<-factor(ConsensusData$gender, levels = c(3,2,1), labels = c("other","female","male"))
prop.table(table(ConsensusData$gender.f))*100

str(ConsensusData$edulevel)
ConsensusData$edulevel.f<-factor(ConsensusData$edulevel, levels = c(7,6,5,4,3,2,1),
                                            labels = c("Doctoral degree","Master's / professional degree",
                                                       "Bachelor's degree","Associate's degree",
                                                       "Some college, no degree","High school / GED",
                                                       "Less than high school"))

str(ConsensusData$edulevel.f)
table(ConsensusData$edulevel.f)
prop.table(table(ConsensusData$edulevel.f))*100

ConsensusDataAlpha <- subset(ConsensusData, select = c("sodamc1","sodamc2"))
alpha(ConsensusDataAlpha)
cor(ConsensusDataAlpha)
