###################################
########### Interaction follow-ups 
###### RC and MC distinct

library(rockchalk) #Graphing simple slopes; moderation
library(stargazer) #Handy regression tables
library(foreign)  # Read in SPSS
library(gvlma)   #helper on diagnostics
library(effects) #helper on visualizing interactions - Uses lattice
library(sjPlot)  #helper on visualizing interactions - uses ggplot
library(ggplot2) #All the graphs
library(psych) #handy for descriptives, etc
library(dplyr)
library(apaTables)
library(texreg)
library(Hmisc)
describe <- psych::describe

#set working directory
setwd("")

MCRCStudy2Data<-read.spss("MCRC_Study2_Data.sav", use.value.labels = FALSE, to.data.frame = TRUE,
                 max.value.labels = Inf, trim.factor.names = FALSE,
                 trim_values = TRUE, reencode = NA, use.missings = to.data.frame)
str(MCRCStudy2Data)
head(MCRCStudy2Data)


#########################################################################################################
##### For CONTROL issue: Do you support/oppose medical researchers treating rashes with skin cream? #####
#########################################################################################################

MCRCStudy2Data.Control <- subset(MCRCStudy2Data, issuecond == 1)
describe(MCRCStudy2Data.Control$compmcfull)
describe(MCRCStudy2Data.Control$comprc)
describe(MCRCStudy2Data.Control$pofull)

MCRCStudy2Data.Control$comprc.c <- scale(MCRCStudy2Data.Control$comprc, scale = FALSE)[,]
describe(MCRCStudy2Data.Control$comprc.c)

### Creating mean replacement variables to take care of missingness.
#If else statement: if value of the variable is missing, replace with the mean of the variable, else use the original value.

#Mean centered time religious conviction for skin cream. Replace missing values with mean (0 since it's mean centered). 
MCRCStudy2Data.Control$comprcMR <- ifelse(is.na(MCRCStudy2Data.Control$comprc),
                                                 mean(MCRCStudy2Data.Control$comprc,na.rm=TRUE), MCRCStudy2Data.Control$comprc)

describe(MCRCStudy2Data.Control$comprc)
describe(MCRCStudy2Data.Control$comprcMR)

MCRCStudy2Data.Control$comprc.cMR <- ifelse(is.na(MCRCStudy2Data.Control$comprc.c),
                                     mean(MCRCStudy2Data.Control$comprc.c,na.rm=TRUE), MCRCStudy2Data.Control$comprc.c)

describe(MCRCStudy2Data.Control$comprc.c)
describe(MCRCStudy2Data.Control$comprc.cMR)


#Midpoint centered political orientation. Replace missing values with mean. 
MCRCStudy2Data.Control$pofullMR <- ifelse(is.na(MCRCStudy2Data.Control$pofull),
                                          mean(MCRCStudy2Data.Control$pofull,na.rm=TRUE), MCRCStudy2Data.Control$pofull)

describe(MCRCStudy2Data.Control$pofull)
describe(MCRCStudy2Data.Control$pofullMR)


#Moral conviction for skin cream. Replace missing values with mean. 
MCRCStudy2Data.Control$compmcfullMR <- ifelse(is.na(MCRCStudy2Data.Control$compmcfull),
                                          mean(MCRCStudy2Data.Control$compmcfull,na.rm=TRUE), MCRCStudy2Data.Control$compmcfull)

describe(MCRCStudy2Data.Control$compmcfull)
describe(MCRCStudy2Data.Control$compmcfullMR)

############################################
#### Moral conviction about skin cream ####

#Main effects political orientation, skin cream religious conviction 
mcControl.main <- lm(compmcfullMR ~ pofullMR
                  + comprc.cMR,
                  data = MCRCStudy2Data.Control) 
summary(mcControl.main)

#Mmain effects & 2-way Interactions
mcControl.2way <- lm(compmcfullMR ~ pofullMR*comprc.cMR,
                  data = MCRCStudy2Data.Control) 
summary(mcControl.2way)

anova(mcControl.main,mcControl.2way)


##Nice table of all the steps
stargazer(mcControl.main,mcControl.2way,type="text",
          column.labels = c("Main Effects", "2-way Interaction"),
          intercept.bottom = FALSE, star.cutoffs = c(.05,.01,.001),
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

# Tables for Linda
controlcordata<-subset(MCRCStudy2Data.Control[,c("pofullMR","comprcMR","compmcfullMR")])
apa.cor.table(controlcordata, show.conf.interval = FALSE, landscape = FALSE)
controlcordatamatrix<-as.matrix(controlcordata)
rcorr(controlcordatamatrix, type = "pearson")

#Plotting
#No significant interaction


#########################################################################################################
##### For GUN CONTROL issue: Do you support/oppose additional gun control laws? #####
#########################################################################################################

MCRCStudy2Data.Gun <- subset(MCRCStudy2Data, issuecond == 2)
describe(MCRCStudy2Data.Gun$compmcfull)
describe(MCRCStudy2Data.Gun$comprc)
describe(MCRCStudy2Data.Gun$pofull)

MCRCStudy2Data.Gun$comprc.c <- scale(MCRCStudy2Data.Gun$comprc, scale = FALSE)[,]
describe(MCRCStudy2Data.Gun$comprc.c)

### Creating mean replacement variables to take care of missingness.
#If else statement: if value of the variable is missing, replace with the mean of the variable, else use the original value.

#Mean centered time religious conviction for gun control. Replace missing values with mean (0 since it's mean centered). 
MCRCStudy2Data.Gun$comprcMR <- ifelse(is.na(MCRCStudy2Data.Gun$comprc),
                                             mean(MCRCStudy2Data.Gun$comprc,na.rm=TRUE), MCRCStudy2Data.Gun$comprc)

describe(MCRCStudy2Data.Gun$comprc)
describe(MCRCStudy2Data.Gun$comprcMR)

MCRCStudy2Data.Gun$comprc.cMR <- ifelse(is.na(MCRCStudy2Data.Gun$comprc.c),
                                                 mean(MCRCStudy2Data.Gun$comprc.c,na.rm=TRUE), MCRCStudy2Data.Gun$comprc.c)

describe(MCRCStudy2Data.Gun$comprc.c)
describe(MCRCStudy2Data.Gun$comprc.cMR)


#Midpoint centered political orientation. Replace missing values with mean. 
MCRCStudy2Data.Gun$pofullMR <- ifelse(is.na(MCRCStudy2Data.Gun$pofull),
                                               mean(MCRCStudy2Data.Gun$pofull,na.rm=TRUE), MCRCStudy2Data.Gun$pofull)

describe(MCRCStudy2Data.Gun$pofull)
describe(MCRCStudy2Data.Gun$pofullMR)


#Moral conviction for gun control. Replace missing values with mean. 
MCRCStudy2Data.Gun$compmcfullMR <- ifelse(is.na(MCRCStudy2Data.Gun$compmcfull),
                                                   mean(MCRCStudy2Data.Gun$compmcfull,na.rm=TRUE), MCRCStudy2Data.Gun$compmcfull)

describe(MCRCStudy2Data.Gun$compmcfull)
describe(MCRCStudy2Data.Gun$compmcfullMR)

############################################
#### Moral conviction about gun control ####

#Main effects political orientation, gun control religious conviction 
mcGun.main <- lm(compmcfullMR ~ pofullMR
                     + comprc.cMR,
                     data = MCRCStudy2Data.Gun) 
summary(mcGun.main)

#Mmain effects & 2-way Interactions
mcGun.2way <- lm(compmcfullMR ~ pofullMR*comprc.cMR,
                     data = MCRCStudy2Data.Gun) 
summary(mcGun.2way)

anova(mcGun.main,mcGun.2way)


##Nice table of all the steps
stargazer(mcGun.main,mcGun.2way,type="text",
          column.labels = c("Main Effects", "2-way Interaction"),
          intercept.bottom = FALSE, star.cutoffs = c(.05,.01,.001),
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

# Tables for Linda
guncordata<-subset(MCRCStudy2Data.Gun[,c("pofullMR","comprcMR","compmcfullMR")])
apa.cor.table(guncordata, show.conf.interval = FALSE, landscape = FALSE)
guncordatamatrix<-as.matrix(guncordata)
rcorr(guncordatamatrix, type = "pearson")

#Plotting
# No significant interaction

#########################################################################################################
##### For CARBON EMISSIONS issue: Do you support/oppose additional laws restricting carbon emissions? #####
#########################################################################################################

MCRCStudy2Data.Carbon <- subset(MCRCStudy2Data, issuecond == 3)
describe(MCRCStudy2Data.Carbon$compmcfull)
describe(MCRCStudy2Data.Carbon$comprc)
describe(MCRCStudy2Data.Carbon$pofull)

MCRCStudy2Data.Carbon$comprc.c <- scale(MCRCStudy2Data.Carbon$comprc, scale = FALSE)[,]
describe(MCRCStudy2Data.Carbon$comprc.c)

### Creating mean replacement variables to take care of missingness.
#If else statement: if value of the variable is missing, replace with the mean of the variable, else use the original value.

#Mean centered time religious conviction for Carbon emissions. Replace missing values with mean (0 since it's mean centered). 
MCRCStudy2Data.Carbon$comprcMR <- ifelse(is.na(MCRCStudy2Data.Carbon$comprc),
                                                mean(MCRCStudy2Data.Carbon$comprc,na.rm=TRUE), MCRCStudy2Data.Carbon$comprc)

describe(MCRCStudy2Data.Carbon$comprc)
describe(MCRCStudy2Data.Carbon$comprcMR)

MCRCStudy2Data.Carbon$comprc.cMR <- ifelse(is.na(MCRCStudy2Data.Carbon$comprc.c),
                                             mean(MCRCStudy2Data.Carbon$comprc.c,na.rm=TRUE), MCRCStudy2Data.Carbon$comprc.c)

describe(MCRCStudy2Data.Carbon$comprc.c)
describe(MCRCStudy2Data.Carbon$comprc.cMR)


#Midpoint centered political orientation. Replace missing values with mean. 
MCRCStudy2Data.Carbon$pofullMR <- ifelse(is.na(MCRCStudy2Data.Carbon$pofull),
                                           mean(MCRCStudy2Data.Carbon$pofull,na.rm=TRUE), MCRCStudy2Data.Carbon$pofull)

describe(MCRCStudy2Data.Carbon$pofull)
describe(MCRCStudy2Data.Carbon$pofullMR)


#Moral conviction for Carbon emissions. Replace missing values with mean. 
MCRCStudy2Data.Carbon$compmcfullMR <- ifelse(is.na(MCRCStudy2Data.Carbon$compmcfull),
                                               mean(MCRCStudy2Data.Carbon$compmcfull,na.rm=TRUE), MCRCStudy2Data.Carbon$compmcfull)

describe(MCRCStudy2Data.Carbon$compmcfull)
describe(MCRCStudy2Data.Carbon$compmcfullMR)

############################################
#### Moral conviction about Carbon emissions ####

#Main effects political orientation, carbon emissions religious conviction 
mcCarbon.main <- lm(compmcfullMR ~ pofullMR
                 + comprc.cMR,
                 data = MCRCStudy2Data.Carbon) 
summary(mcCarbon.main)

#Mmain effects & 2-way Interactions
mcCarbon.2way <- lm(compmcfullMR ~ pofullMR*comprc.cMR,
                 data = MCRCStudy2Data.Carbon) 
summary(mcCarbon.2way)

anova(mcCarbon.main,mcCarbon.2way)


##Nice table of all the steps
stargazer(mcCarbon.main,mcCarbon.2way,type="text",
          column.labels = c("Main Effects", "2-way Interaction"),
          intercept.bottom = FALSE, star.cutoffs = c(.05,.01,.001),
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

# Tables for Linda
carboncordata<-subset(MCRCStudy2Data.Carbon[,c("pofullMR","comprcMR","compmcfullMR")])
apa.cor.table(carboncordata, show.conf.interval = FALSE, landscape = FALSE)
carboncordatamatrix<-as.matrix(carboncordata)
rcorr(carboncordatamatrix, type = "pearson")

#Plotting
# No significant interaction


#########################################################################################################
##### For NUCLEAR POWER issue: Do you support/oppose government investment in nuclear energy? #####
#########################################################################################################

MCRCStudy2Data.Nuclear <- subset(MCRCStudy2Data, issuecond == 4)
describe(MCRCStudy2Data.Nuclear$compmcfull)
describe(MCRCStudy2Data.Nuclear$comprc)
describe(MCRCStudy2Data.Nuclear$pofull)

MCRCStudy2Data.Nuclear$comprc.c <- scale(MCRCStudy2Data.Nuclear$comprc, scale = FALSE)[,]
describe(MCRCStudy2Data.Nuclear$comprc.c)

### Creating mean replacement variables to take care of missingness.
#If else statement: if value of the variable is missing, replace with the mean of the variable, else use the original value.

#Mean centered time religious conviction for Nuclear power. Replace missing values with mean (0 since it's mean centered). 
MCRCStudy2Data.Nuclear$comprcMR <- ifelse(is.na(MCRCStudy2Data.Nuclear$comprc),
                                                 mean(MCRCStudy2Data.Nuclear$comprc,na.rm=TRUE), MCRCStudy2Data.Nuclear$comprc)

describe(MCRCStudy2Data.Nuclear$comprc)
describe(MCRCStudy2Data.Nuclear$comprcMR)

MCRCStudy2Data.Nuclear$comprc.cMR <- ifelse(is.na(MCRCStudy2Data.Nuclear$comprc.c),
                                                mean(MCRCStudy2Data.Nuclear$comprc.c,na.rm=TRUE), MCRCStudy2Data.Nuclear$comprc.c)

describe(MCRCStudy2Data.Nuclear$comprc.c)
describe(MCRCStudy2Data.Nuclear$comprc.cMR)


#Midpoint centered political orientation. Replace missing values with mean. 
MCRCStudy2Data.Nuclear$pofullMR <- ifelse(is.na(MCRCStudy2Data.Nuclear$pofull),
                                              mean(MCRCStudy2Data.Nuclear$pofull,na.rm=TRUE), MCRCStudy2Data.Nuclear$pofull)

describe(MCRCStudy2Data.Nuclear$pofull)
describe(MCRCStudy2Data.Nuclear$pofullMR)


#Moral conviction for Nuclear power. Replace missing values with mean. 
MCRCStudy2Data.Nuclear$compmcfullMR <- ifelse(is.na(MCRCStudy2Data.Nuclear$compmcfull),
                                                  mean(MCRCStudy2Data.Nuclear$compmcfull,na.rm=TRUE), MCRCStudy2Data.Nuclear$compmcfull)

describe(MCRCStudy2Data.Nuclear$compmcfull)
describe(MCRCStudy2Data.Nuclear$compmcfullMR)

############################################
#### Moral conviction about Nuclear power ####

#Main effects political orientation, Nuclear power religious conviction 
mcNuclear.main <- lm(compmcfullMR ~ pofullMR
                    + comprc.cMR,
                    data = MCRCStudy2Data.Nuclear) 
summary(mcNuclear.main)

#Mmain effects & 2-way Interactions
mcNuclear.2way <- lm(compmcfullMR ~ pofullMR*comprc.cMR,
                    data = MCRCStudy2Data.Nuclear) 
summary(mcNuclear.2way)

anova(mcNuclear.main,mcNuclear.2way)


##Nice table of all the steps
stargazer(mcNuclear.main,mcNuclear.2way,type="text",
          column.labels = c("Main Effects", "2-way Interaction"),
          intercept.bottom = FALSE, star.cutoffs = c(.05,.01,.001),
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

# Tables for Linda
nuclearcordata<-subset(MCRCStudy2Data.Nuclear[,c("pofullMR","comprcMR","compmcfullMR")])
apa.cor.table(nuclearcordata, show.conf.interval = FALSE, landscape = FALSE)
nuclearcordatamatrix<-as.matrix(nuclearcordata)
rcorr(nuclearcordatamatrix, type = "pearson")

#Plotting
# No significant interaction


#########################################################################################################
##### For Same-Sex Marriage issue: Do you support/oppose allowing same-sex marriage? #####
#########################################################################################################

MCRCStudy2Data.SSM <- subset(MCRCStudy2Data, issuecond == 5)
describe(MCRCStudy2Data.SSM$compmcfull)
describe(MCRCStudy2Data.SSM$comprc)
describe(MCRCStudy2Data.SSM$pofull)

MCRCStudy2Data.SSM$comprc.c <- scale(MCRCStudy2Data.SSM$comprc, scale = FALSE)[,]
describe(MCRCStudy2Data.SSM$comprc.c)

### Creating mean replacement variables to take care of missingness.
#If else statement: if value of the variable is missing, replace with the mean of the variable, else use the original value.

#Mean centered time religious conviction for SSM . Replace missing values with mean (0 since it's mean centered). 
MCRCStudy2Data.SSM$comprcMR <- ifelse(is.na(MCRCStudy2Data.SSM$comprc),
                                             mean(MCRCStudy2Data.SSM$comprc,na.rm=TRUE), MCRCStudy2Data.SSM$comprc)

describe(MCRCStudy2Data.SSM$comprc)
describe(MCRCStudy2Data.SSM$comprcMR)

MCRCStudy2Data.SSM$comprc.cMR <- ifelse(is.na(MCRCStudy2Data.SSM$comprc.c),
                                                 mean(MCRCStudy2Data.SSM$comprc.c,na.rm=TRUE), MCRCStudy2Data.SSM$comprc.c)

describe(MCRCStudy2Data.SSM$comprc.c)
describe(MCRCStudy2Data.SSM$comprc.cMR)


#Midpoint centered political orientation. Replace missing values with mean. 
MCRCStudy2Data.SSM$pofullMR <- ifelse(is.na(MCRCStudy2Data.SSM$pofull),
                                               mean(MCRCStudy2Data.SSM$pofull,na.rm=TRUE), MCRCStudy2Data.SSM$pofull)

describe(MCRCStudy2Data.SSM$pofull)
describe(MCRCStudy2Data.SSM$pofullMR)


#Moral conviction for SSM. Replace missing values with mean. 
MCRCStudy2Data.SSM$compmcfullMR <- ifelse(is.na(MCRCStudy2Data.SSM$compmcfull),
                                                   mean(MCRCStudy2Data.SSM$compmcfull,na.rm=TRUE), MCRCStudy2Data.SSM$compmcfull)

describe(MCRCStudy2Data.SSM$compmcfull)
describe(MCRCStudy2Data.SSM$compmcfullMR)

############################################
#### Moral conviction about SSM  ####

#Main effects political orientation, SSM religious conviction 
mcSSM.main <- lm(compmcfullMR ~ pofullMR
                     + comprc.cMR,
                     data = MCRCStudy2Data.SSM) 
summary(mcSSM.main)

#Mmain effects & 2-way Interactions
mcSSM.2way <- lm(compmcfullMR ~ pofullMR*comprc.cMR,
                     data = MCRCStudy2Data.SSM) 
summary(mcSSM.2way)

anova(mcSSM.main,mcSSM.2way)


##Nice table of all the steps
stargazer(mcSSM.main,mcSSM.2way,type="text",
          column.labels = c("Main Effects", "2-way Interaction"),
          intercept.bottom = FALSE, star.cutoffs = c(.05,.01,.001),
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

# Tables for Linda
ssmcordata<-subset(MCRCStudy2Data.SSM[,c("pofullMR","comprcMR","compmcfullMR")])
apa.cor.table(ssmcordata, show.conf.interval = FALSE, landscape = FALSE)
ssmcordatamatrix<-as.matrix(ssmcordata)
rcorr(ssmcordatamatrix, type = "pearson")

#Plotting
describe(MCRCStudy2Data.SSM$pofullMR)
describe(MCRCStudy2Data.SSM$comprc.cMR)


mcSSM.RCAtPO <- plotSlopes(mcSSM.2way, plotx="comprc.cMR", modx="pofullMR", 
                               xlab = "Same-Sex Marriage Religious Conviction", xlim = c(-1.53,2.47),ylab = "Same-Sex Marriage Moral Conviction", 
                               modxVals = c(-2.53,0,2.53), plotPoints = FALSE,
                               legendTitle = "Political Orientation")

mcSSM.RCAtPO.test <- testSlopes(mcSSM.RCAtPO)
round(mcSSM.RCAtPO.test$hypotests,3)


#Plotting pretty with ggplot
#Plotting the Political orientation by religious conviction interaction predicting moral conviction.
#The effect of religious conviction at PO moderates and one standard deviation above and below moderate (2.53).
summary(mcSSM.2way)
describe(MCRCStudy2Data.SSM$comprc.cMR)

#Getting the effects for the PO by Religious conviction interaction
# at 1 SD below moderate, moderate, and 1 SD above moderate (-2.53, 0, 2.53).
# Specifying the full range of religious conviction (min = -1.53 max = 2.47, every one unit) 
# The variable is mean centered, so this translates to the original points on the 1-5 scale.
mcSSM.RCAtPO.fitted<-effect('pofullMR:comprc.cMR', mcSSM.2way,
                                 xlevels=list(pofullMR=c(-2.53, 0, 2.53),
                                              comprc.cMR = seq(from = -1.53, to = 2.47, by =1)), 
                                 se=TRUE,confidence.level=.95)

#Saving the effects as a data frame. 
mcSSM.RCAtPO.Eff<-as.data.frame(mcSSM.RCAtPO.fitted)

#Recoding the moderator variable (PO) as a factor with the names of the groups. 
mcSSM.RCAtPO.Eff$POmod<-factor(mcSSM.RCAtPO.Eff$pofullMR,
                                    levels=c(-2.53,0,2.53),
                                    labels=c("Liberals","Moderates","Conservatives"))

mcSSM.RCAtPO.Plot <-ggplot(data = mcSSM.RCAtPO.Eff, aes(x = comprc.cMR, y =fit, group=POmod))+
  coord_cartesian(xlim=c(-1.53, 2.47),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -1.53, to = 2.47, by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=POmod, linetype = POmod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=POmod),alpha=.2)+
  xlab("Same-Sex Marriage Religious Conviction")+
  ylab("Same-Sex Marriage Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .87))
mcSSM.RCAtPO.Plot


#########################################################################################################
##### For Health Care issue: Do you support/oppose universal health care? #####
#########################################################################################################

MCRCStudy2Data.Health <- subset(MCRCStudy2Data, issuecond == 6)
describe(MCRCStudy2Data.Health$compmcfull)
describe(MCRCStudy2Data.Health$comprc)
describe(MCRCStudy2Data.Health$pofull)

MCRCStudy2Data.Health$comprc.c <- scale(MCRCStudy2Data.Health$comprc, scale = FALSE)[,]
describe(MCRCStudy2Data.Health$comprc.c)

### Creating mean replacement variables to take care of missingness.
#If else statement: if value of the variable is missing, replace with the mean of the variable, else use the original value.

#Mean centered time religious conviction for Health care. Replace missing values with mean (0 since it's mean centered). 
MCRCStudy2Data.Health$comprcMR <- ifelse(is.na(MCRCStudy2Data.Health$comprc),
                                                mean(MCRCStudy2Data.Health$comprc,na.rm=TRUE), MCRCStudy2Data.Health$comprc)

describe(MCRCStudy2Data.Health$comprc)
describe(MCRCStudy2Data.Health$comprcMR)

MCRCStudy2Data.Health$comprc.cMR <- ifelse(is.na(MCRCStudy2Data.Health$comprc.c),
                                             mean(MCRCStudy2Data.Health$comprc.c,na.rm=TRUE), MCRCStudy2Data.Health$comprc.c)

describe(MCRCStudy2Data.Health$comprc.c)
describe(MCRCStudy2Data.Health$comprc.cMR)


#Midpoint centered political orientation. Replace missing values with mean. 
MCRCStudy2Data.Health$pofullMR <- ifelse(is.na(MCRCStudy2Data.Health$pofull),
                                           mean(MCRCStudy2Data.Health$pofull,na.rm=TRUE), MCRCStudy2Data.Health$pofull)

describe(MCRCStudy2Data.Health$pofull)
describe(MCRCStudy2Data.Health$pofullMR)


#Moral conviction for Health care. Replace missing values with mean. 
MCRCStudy2Data.Health$compmcfullMR <- ifelse(is.na(MCRCStudy2Data.Health$compmcfull),
                                               mean(MCRCStudy2Data.Health$compmcfull,na.rm=TRUE), MCRCStudy2Data.Health$compmcfull)

describe(MCRCStudy2Data.Health$compmcfull)
describe(MCRCStudy2Data.Health$compmcfullMR)

############################################
#### Moral conviction about Health care ####

#Main effects political orientation, Health care religious conviction 
mcHealth.main <- lm(compmcfullMR ~ pofullMR
                 + comprc.cMR,
                 data = MCRCStudy2Data.Health) 
summary(mcHealth.main)

#Mmain effects & 2-way Interactions
mcHealth.2way <- lm(compmcfullMR ~ pofullMR*comprc.cMR,
                 data = MCRCStudy2Data.Health) 
summary(mcHealth.2way)

anova(mcHealth.main,mcHealth.2way)


##Nice table of all the steps
stargazer(mcHealth.main,mcHealth.2way,type="text",
          column.labels = c("Main Effects", "2-way Interaction"),
          intercept.bottom = FALSE, star.cutoffs = c(.05,.01,.001),
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

# Tables for Linda
healthcordata<-subset(MCRCStudy2Data.Health[,c("pofullMR","comprcMR","compmcfullMR")])
apa.cor.table(healthcordata, show.conf.interval = FALSE, landscape = FALSE)
healthcordatamatrix<-as.matrix(healthcordata)
rcorr(healthcordatamatrix, type = "pearson")

#Plotting
# No significant interaction


#########################################################################################################
##### For Immigration issue: Do you support/oppose lenient immigration? #####
#########################################################################################################

MCRCStudy2Data.Immig <- subset(MCRCStudy2Data, issuecond == 7)
describe(MCRCStudy2Data.Immig$compmcfull)
describe(MCRCStudy2Data.Immig$comprc)
describe(MCRCStudy2Data.Immig$pofull)

MCRCStudy2Data.Immig$comprc.c <- scale(MCRCStudy2Data.Immig$comprc, scale = FALSE)[,]
describe(MCRCStudy2Data.Immig$comprc.c)

### Creating mean replacement variables to take care of missingness.
#If else statement: if value of the variable is missing, replace with the mean of the variable, else use the original value.

#Mean centered time religious conviction for Immig. Replace missing values with mean (0 since it's mean centered). 
MCRCStudy2Data.Immig$comprcMR <- ifelse(is.na(MCRCStudy2Data.Immig$comprc),
                                               mean(MCRCStudy2Data.Immig$comprc,na.rm=TRUE), MCRCStudy2Data.Immig$comprc)

describe(MCRCStudy2Data.Immig$comprc)
describe(MCRCStudy2Data.Immig$comprcMR)

MCRCStudy2Data.Immig$comprc.cMR <- ifelse(is.na(MCRCStudy2Data.Immig$comprc.c),
                                                mean(MCRCStudy2Data.Immig$comprc.c,na.rm=TRUE), MCRCStudy2Data.Immig$comprc.c)

describe(MCRCStudy2Data.Immig$comprc.c)
describe(MCRCStudy2Data.Immig$comprc.cMR)


#Midpoint centered political orientation. Replace missing values with mean. 
MCRCStudy2Data.Immig$pofullMR <- ifelse(is.na(MCRCStudy2Data.Immig$pofull),
                                              mean(MCRCStudy2Data.Immig$pofull,na.rm=TRUE), MCRCStudy2Data.Immig$pofull)

describe(MCRCStudy2Data.Immig$pofull)
describe(MCRCStudy2Data.Immig$pofullMR)


#Moral conviction for Immig. Replace missing values with mean. 
MCRCStudy2Data.Immig$compmcfullMR <- ifelse(is.na(MCRCStudy2Data.Immig$compmcfull),
                                                  mean(MCRCStudy2Data.Immig$compmcfull,na.rm=TRUE), MCRCStudy2Data.Immig$compmcfull)

describe(MCRCStudy2Data.Immig$compmcfull)
describe(MCRCStudy2Data.Immig$compmcfullMR)

############################################
#### Moral conviction about Immig ####

#Main effects political orientation, Immig religious conviction 
mcImmig.main <- lm(compmcfullMR ~ pofullMR
                    + comprc.cMR,
                    data = MCRCStudy2Data.Immig) 
summary(mcImmig.main)

#Mmain effects & 2-way Interactions
mcImmig.2way <- lm(compmcfullMR ~ pofullMR*comprc.cMR,
                    data = MCRCStudy2Data.Immig) 
summary(mcImmig.2way)

anova(mcImmig.main,mcImmig.2way)


##Nice table of all the steps
stargazer(mcImmig.main,mcImmig.2way,type="text",
          column.labels = c("Main Effects", "2-way Interaction"),
          intercept.bottom = FALSE, star.cutoffs = c(.05,.01,.001),
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

# Tables for Linda
immigcordata<-subset(MCRCStudy2Data.Immig[,c("pofullMR","comprcMR","compmcfullMR")])
apa.cor.table(immigcordata, show.conf.interval = FALSE, landscape = FALSE)
immigcordatamatrix<-as.matrix(immigcordata)
rcorr(immigcordatamatrix, type = "pearson")

#Plotting
# No significant interaction


### Descriptives ###
describe(MCRCStudy2Data$age)

str(MCRCStudy2Data$gender)
MCRCStudy2Data$gender.f<-factor(MCRCStudy2Data$gender, labels = c("female","male"))
prop.table(table(MCRCStudy2Data$gender.f))*100

str(MCRCStudy2Data$edulevel)
MCRCStudy2Data$edulevel.f<-factor(MCRCStudy2Data$edulevel, levels = c(7,6,5,4,3,2,1),
                                       labels = c("Doctoral degree","Master's / professional degree",
                                                  "Bachelor's degree","Associate's degree",
                                                  "Some college, no degree","High school / GED",
                                                  "Less than high school"))

str(MCRCStudy2Data$edulevel.f)
table(MCRCStudy2Data$edulevel.f)
prop.table(table(MCRCStudy2Data$edulevel.f))*100

MCRCStudy2Data.CarbonAlpha <- subset(MCRCStudy2Data.Carbon, select = c("compmc1","compmc2"))
alpha(MCRCStudy2Data.CarbonAlpha)

MCRCStudy2Data.ControlAlpha <- subset(MCRCStudy2Data.Control, select = c("compmc1","compmc2"))
alpha(MCRCStudy2Data.ControlAlpha)

MCRCStudy2Data.GunAlpha <- subset(MCRCStudy2Data.Gun, select = c("compmc1","compmc2"))
alpha(MCRCStudy2Data.GunAlpha)

MCRCStudy2Data.NuclearAlpha <- subset(MCRCStudy2Data.Nuclear, select = c("compmc1","compmc2"))
alpha(MCRCStudy2Data.NuclearAlpha)

MCRCStudy2Data.SSMAlpha <- subset(MCRCStudy2Data.SSM, select = c("compmc1","compmc2"))
alpha(MCRCStudy2Data.SSMAlpha)

MCRCStudy2Data.HealthAlpha <- subset(MCRCStudy2Data.Health, select = c("compmc1","compmc2"))
alpha(MCRCStudy2Data.HealthAlpha)

MCRCStudy2Data.ImmigAlpha <- subset(MCRCStudy2Data.Immig, select = c("compmc1","compmc2"))
alpha(MCRCStudy2Data.ImmigAlpha)
