###################################
########### Interaction follow-ups 
###### RC and MC distinct

library(rockchalk) #Graphing simple slopes; moderation
library(stargazer) #Handy regression tables
library(foreign)  # Read in SPSS
library(gvlma)   #helper on diagnostics
library(effects) #helper on visualizing interactions - Uses lattice
library(sjPlot)  #helper on visualizing interactions - uses ggplot
library(ggplot2) #All the graphs
library(psych) #handy for descriptives, etc
library(dplyr)
library(apaTables)
library(texreg)
library(Hmisc)
describe <- psych::describe

#set working directory
setwd("")

MCRCStudy3Data<-read.spss("MCRC_Study3_Data.sav", use.value.labels = FALSE, to.data.frame = TRUE,
                 max.value.labels = Inf, trim.factor.names = FALSE,
                 trim_values = TRUE, reencode = NA, use.missings = to.data.frame)
str(MCRCStudy3Data)
head(MCRCStudy3Data)


#########################################################################################################
##### For GUN CONTROL issue: Do you support/oppose additional gun control laws? #####
#########################################################################################################

describe(MCRCStudy3Data$mcfull)
describe(MCRCStudy3Data$rc)
describe(MCRCStudy3Data$pofull)

MCRCStudy3Data$rc.c <- scale(MCRCStudy3Data$rc, scale = FALSE)[,]
describe(MCRCStudy3Data$rc.c)

### Creating mean replacement variables to take care of missingness.
#If else statement: if value of the variable is missing, replace with the mean of the variable, else use the original value.

#Mean centered time religious conviction for gun control. Replace missing values with mean (0 since it's mean centered). 
MCRCStudy3Data$rcMR <- ifelse(is.na(MCRCStudy3Data$rc),
                                          mean(MCRCStudy3Data$rc,na.rm=TRUE), MCRCStudy3Data$rc)

describe(MCRCStudy3Data$rc)
describe(MCRCStudy3Data$rcMR)

MCRCStudy3Data$rc.cMR <- ifelse(is.na(MCRCStudy3Data$rc.c),
                                                 mean(MCRCStudy3Data$rc.c,na.rm=TRUE), MCRCStudy3Data$rc.c)

describe(MCRCStudy3Data$rc.c)
describe(MCRCStudy3Data$rc.cMR)


#Midpoint centered political orientation. Replace missing values with mean. 
MCRCStudy3Data$pofullMR <- ifelse(is.na(MCRCStudy3Data$pofull),
                                               mean(MCRCStudy3Data$pofull,na.rm=TRUE), MCRCStudy3Data$pofull)

describe(MCRCStudy3Data$pofull)
describe(MCRCStudy3Data$pofullMR)


#Moral conviction for gun control. Replace missing values with mean. 
MCRCStudy3Data$mcfullMR <- ifelse(is.na(MCRCStudy3Data$mcfull),
                                                   mean(MCRCStudy3Data$mcfull,na.rm=TRUE), MCRCStudy3Data$mcfull)

describe(MCRCStudy3Data$mcfull)
describe(MCRCStudy3Data$mcfullMR)

############################################
#### Moral conviction about gun control ####

#Main effects political orientation, gun control religious conviction 
mcGun.main <- lm(mcfullMR ~ pofullMR
                     + rc.cMR,
                     data = MCRCStudy3Data) 
summary(mcGun.main)

#Mmain effects & 2-way Interactions
mcGun.2way <- lm(mcfullMR ~ pofullMR*rc.cMR,
                     data = MCRCStudy3Data) 
summary(mcGun.2way)

anova(mcGun.main,mcGun.2way)


##Nice table of all the steps
stargazer(mcGun.main,mcGun.2way,type="text",
          column.labels = c("Main Effects", "2-way Interaction"),
          intercept.bottom = FALSE, star.cutoffs = c(.05,.01,.001),
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

# Tables for Linda
guncordata<-subset(MCRCStudy3Data[,c("pofullMR","rcMR","mcfullMR")])
apa.cor.table(guncordata, show.conf.interval = FALSE, landscape = FALSE)
guncordatamatrix<-as.matrix(guncordata)
rcorr(guncordatamatrix, type = "pearson")

#Plotting
# No significant interaction

### Descriptives ###
describe(MCRCStudy3Data$age)

str(MCRCStudy3Data$gender)
MCRCStudy3Data$gender.f<-factor(MCRCStudy3Data$gender, labels = c("female","male"))
prop.table(table(MCRCStudy3Data$gender.f))*100

str(MCRCStudy3Data$edulevel)
MCRCStudy3Data$edulevel.f<-factor(MCRCStudy3Data$edulevel, levels = c(7,6,5,4,3,2,1),
                                       labels = c("Doctoral degree","Master's / professional degree",
                                                  "Bachelor's degree","Associate's degree",
                                                  "Some college, no degree","High school / GED",
                                                  "Less than high school"))

str(MCRCStudy3Data$edulevel.f)
table(MCRCStudy3Data$edulevel.f)
prop.table(table(MCRCStudy3Data$edulevel.f))*100

MCRCStudy3DataAlpha <- subset(MCRCStudy3Data, select = c("mc1","mc2"))
alpha(MCRCStudy3DataAlpha)
