###################################
########### Interaction follow-ups 
###### RC and MC distinct

library(rockchalk) #Graphing simple slopes; moderation
library(stargazer) #Handy regression tables
library(foreign)  # Read in SPSS
library(gvlma)   #helper on diagnostics
library(effects) #helper on visualizing interactions - Uses lattice
library(sjPlot)  #helper on visualizing interactions - uses ggplot
library(ggplot2) #All the graphs
library(psych) #handy for descriptives, etc
library(dplyr)
library(apaTables)
library(texreg)
library(Hmisc)
describe <- psych::describe

#set working directory
setwd("")

MCRCStudy4Data<-read.spss("MCRC_Study4_Data.sav", use.value.labels = FALSE, to.data.frame = TRUE,
                 max.value.labels = Inf, trim.factor.names = FALSE,
                 trim_values = TRUE, reencode = NA, use.missings = to.data.frame)
str(MCRCStudy4Data)
head(MCRCStudy4Data)

#########################################################################################################
##### For War on Xmas issue: Do you agree/disagree with idea that there is a war on xmas? #####
#########################################################################################################

MCRCStudy4Data.Xmas <- subset(MCRCStudy4Data, topic == 1)
describe(MCRCStudy4Data.Xmas$att.mc)
describe(MCRCStudy4Data.Xmas$att.rc)
describe(MCRCStudy4Data.Xmas$po.full)
describe(MCRCStudy4Data.Xmas$santaclara.full)

MCRCStudy4Data.Xmas$att.rc.c <- scale(MCRCStudy4Data.Xmas$att.rc, scale = FALSE)[,]
describe(MCRCStudy4Data.Xmas$att.rc.c)

MCRCStudy4Data.Xmas$santaclara.full.c <- scale(MCRCStudy4Data.Xmas$santaclara.full, scale = FALSE)[,]
describe(MCRCStudy4Data.Xmas$santaclara.full.c)

### Creating mean replacement variables to take care of missingness.
#If else statement: if value of the variable is missing, replace with the mean of the variable, else use the original value.

#Mean centered time religious conviction for war on xmas. Replace missing values with mean (0 since it's mean centered). 
MCRCStudy4Data.Xmas$att.rcMR <- ifelse(is.na(MCRCStudy4Data.Xmas$att.rc),
                                                     mean(MCRCStudy4Data.Xmas$att.rc,na.rm=TRUE), MCRCStudy4Data.Xmas$att.rc)

describe(MCRCStudy4Data.Xmas$att.rc)
describe(MCRCStudy4Data.Xmas$att.rcMR)

MCRCStudy4Data.Xmas$att.rc.cMR <- ifelse(is.na(MCRCStudy4Data.Xmas$att.rc.c),
                                     mean(MCRCStudy4Data.Xmas$att.rc.c,na.rm=TRUE), MCRCStudy4Data.Xmas$att.rc.c)

describe(MCRCStudy4Data.Xmas$att.rc.c)
describe(MCRCStudy4Data.Xmas$att.rc.cMR)


#Midpoint centered political orientation. Replace missing values with mean. 
MCRCStudy4Data.Xmas$po.fullMR <- ifelse(is.na(MCRCStudy4Data.Xmas$po.full),
                                          mean(MCRCStudy4Data.Xmas$po.full,na.rm=TRUE), MCRCStudy4Data.Xmas$po.full)

describe(MCRCStudy4Data.Xmas$po.full)
describe(MCRCStudy4Data.Xmas$po.fullMR)


#Mean centered time religiosity for war on xmas. Replace missing values with mean (0 since it's mean centered). 
MCRCStudy4Data.Xmas$santaclara.fullMR <- ifelse(is.na(MCRCStudy4Data.Xmas$santaclara.full),
                                                              mean(MCRCStudy4Data.Xmas$santaclara.full,na.rm=TRUE), MCRCStudy4Data.Xmas$santaclara.full)

describe(MCRCStudy4Data.Xmas$santaclara.full)
describe(MCRCStudy4Data.Xmas$santaclara.fullMR)

MCRCStudy4Data.Xmas$santaclara.full.cMR <- ifelse(is.na(MCRCStudy4Data.Xmas$santaclara.full.c),
                                                     mean(MCRCStudy4Data.Xmas$santaclara.full.c,na.rm=TRUE), MCRCStudy4Data.Xmas$santaclara.full.c)

describe(MCRCStudy4Data.Xmas$santaclara.full.c)
describe(MCRCStudy4Data.Xmas$santaclara.full.cMR)


#Moral conviction for war on xmas. Replace missing values with mean. 
MCRCStudy4Data.Xmas$att.mcMR <- ifelse(is.na(MCRCStudy4Data.Xmas$att.mc),
                                          mean(MCRCStudy4Data.Xmas$att.mc,na.rm=TRUE), MCRCStudy4Data.Xmas$att.mc)

describe(MCRCStudy4Data.Xmas$att.mc)
describe(MCRCStudy4Data.Xmas$att.mcMR)

############################################
#### Moral conviction about war on xmas ####

#Main effects political orientation, war on xmas religious conviction, religiosity
mcXmas.main <- lm(att.mcMR ~ po.fullMR
                  + santaclara.full.cMR
                  + att.rc.cMR,
                  data = MCRCStudy4Data.Xmas) 
summary(mcXmas.main)

#Mmain effects & 2-way Interactions
mcXmas.2way <- lm(att.mcMR ~ po.fullMR
                  + santaclara.full.cMR
                  + att.rc.cMR
                  + I(santaclara.full.cMR*att.rc.cMR)
                  + I(po.fullMR*santaclara.full.cMR)
                  + I(po.fullMR*att.rc.cMR),
                  data = MCRCStudy4Data.Xmas) 
summary(mcXmas.2way)

anova(mcXmas.main,mcXmas.2way)

#Mmain effects, 2-way Interactions, and 3-way interaction
mcXmas.3way <- lm(att.mcMR ~ po.fullMR
                  + santaclara.full.cMR
                  + att.rc.cMR
                  + I(santaclara.full.cMR*att.rc.cMR)
                  + I(po.fullMR*santaclara.full.cMR)
                  + I(po.fullMR*att.rc.cMR)
                  + I(santaclara.full.cMR*att.rc.cMR*po.fullMR),
                  data = MCRCStudy4Data.Xmas) 
summary(mcXmas.3way)

anova(mcXmas.main,mcXmas.2way,mcXmas.3way)

##Nice table of all the steps
stargazer(mcXmas.main,mcXmas.2way,mcXmas.3way,type="text",
          column.labels = c("Main Effects", "2-way Interactions", "3-way Interaction"),
          intercept.bottom = FALSE, star.cutoffs = c(.05,.01,.001),
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

# Tables for Linda
xmascordata<-subset(MCRCStudy4Data.Xmas[,c("po.fullMR","santaclara.fullMR","att.rcMR","att.mcMR")])
apa.cor.table(xmascordata, show.conf.interval = FALSE, landscape = FALSE)
xmascordatamatrix<-as.matrix(xmascordata)
rcorr(xmascordatamatrix, type = "pearson")

#Plotting
# No significant interactions


#########################################################################################################
##### For War on Women issue: Do you agree/disagree with idea that there is a war on women? #####
#########################################################################################################

MCRCStudy4Data.Women <- subset(MCRCStudy4Data, topic == 2)
describe(MCRCStudy4Data.Women$att.mc)
describe(MCRCStudy4Data.Women$att.rc)
describe(MCRCStudy4Data.Women$po.full)
describe(MCRCStudy4Data.Women$santaclara.full)

MCRCStudy4Data.Women$att.rc.c <- scale(MCRCStudy4Data.Women$att.rc, scale = FALSE)[,]
describe(MCRCStudy4Data.Women$att.rc.c)

MCRCStudy4Data.Women$santaclara.full.c <- scale(MCRCStudy4Data.Women$santaclara.full, scale = FALSE)[,]
describe(MCRCStudy4Data.Women$santaclara.full.c)

### Creating mean replacement variables to take care of missingness.
#If else statement: if value of the variable is missing, replace with the mean of the variable, else use the original value.

#Mean centered time religious conviction for war on women. Replace missing values with mean (0 since it's mean centered). 
MCRCStudy4Data.Women$att.rcMR <- ifelse(is.na(MCRCStudy4Data.Women$att.rc),
                                                      mean(MCRCStudy4Data.Women$att.rc,na.rm=TRUE), MCRCStudy4Data.Women$att.rc)

describe(MCRCStudy4Data.Women$att.rc)
describe(MCRCStudy4Data.Women$att.rcMR)

MCRCStudy4Data.Women$att.rc.cMR <- ifelse(is.na(MCRCStudy4Data.Women$att.rc.c),
                                                     mean(MCRCStudy4Data.Women$att.rc.c,na.rm=TRUE), MCRCStudy4Data.Women$att.rc.c)

describe(MCRCStudy4Data.Women$att.rc.c)
describe(MCRCStudy4Data.Women$att.rc.cMR)


#Midpoint centered political orientation. Replace missing values with mean. 
MCRCStudy4Data.Women$po.fullMR <- ifelse(is.na(MCRCStudy4Data.Women$po.full),
                                                    mean(MCRCStudy4Data.Women$po.full,na.rm=TRUE), MCRCStudy4Data.Women$po.full)

describe(MCRCStudy4Data.Women$po.full)
describe(MCRCStudy4Data.Women$po.fullMR)


#Mean centered time religiosity for war on women. Replace missing values with mean (0 since it's mean centered). 
MCRCStudy4Data.Women$santaclara.fullMR <- ifelse(is.na(MCRCStudy4Data.Women$santaclara.full),
                                                               mean(MCRCStudy4Data.Women$santaclara.full,na.rm=TRUE), MCRCStudy4Data.Women$santaclara.full)

describe(MCRCStudy4Data.Women$santaclara.full)
describe(MCRCStudy4Data.Women$santaclara.fullMR)

MCRCStudy4Data.Women$santaclara.full.cMR <- ifelse(is.na(MCRCStudy4Data.Women$santaclara.full.c),
                                                              mean(MCRCStudy4Data.Women$santaclara.full.c,na.rm=TRUE), MCRCStudy4Data.Women$santaclara.full.c)

describe(MCRCStudy4Data.Women$santaclara.full.c)
describe(MCRCStudy4Data.Women$santaclara.full.cMR)


#Moral conviction for war on women. Replace missing values with mean. 
MCRCStudy4Data.Women$att.mcMR <- ifelse(is.na(MCRCStudy4Data.Women$att.mc),
                                                   mean(MCRCStudy4Data.Women$att.mc,na.rm=TRUE), MCRCStudy4Data.Women$att.mc)

describe(MCRCStudy4Data.Women$att.mc)
describe(MCRCStudy4Data.Women$att.mcMR)

############################################
#### Moral conviction about war on women ####

#Main effects political orientation, war on women religious conviction, religiosity
mcWomen.main <- lm(att.mcMR ~ po.fullMR
                   + santaclara.full.cMR
                   + att.rc.cMR,
                  data = MCRCStudy4Data.Women) 
summary(mcWomen.main)

#Mmain effects & 2-way Interactions
mcWomen.2way <- lm(att.mcMR ~ po.fullMR
                   + santaclara.full.cMR
                   + att.rc.cMR
                   + I(santaclara.full.cMR*att.rc.cMR)
                   + I(po.fullMR*santaclara.full.cMR)
                   + I(po.fullMR*att.rc.cMR),
                  data = MCRCStudy4Data.Women) 
summary(mcWomen.2way)

anova(mcWomen.main,mcWomen.2way)

#Mmain effects, 2-way Interactions, and 3-way interaction
mcWomen.3way <- lm(att.mcMR ~ po.fullMR
                   + santaclara.full.cMR
                   + att.rc.cMR
                   + I(santaclara.full.cMR*att.rc.cMR)
                   + I(po.fullMR*santaclara.full.cMR)
                   + I(po.fullMR*att.rc.cMR)
                   + I(santaclara.full.cMR*att.rc.cMR*po.fullMR),
                  data = MCRCStudy4Data.Women) 
summary(mcWomen.3way)

anova(mcWomen.main,mcWomen.2way,mcWomen.3way)

##Nice table of all the steps
stargazer(mcWomen.main,mcWomen.2way,mcWomen.3way,type="text",
          column.labels = c("Main Effects", "2-way Interactions", "3-way Interaction"),
          intercept.bottom = FALSE, star.cutoffs = c(.05,.01,.001),
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

# Tables for Linda
womencordata<-subset(MCRCStudy4Data.Women[,c("po.fullMR","santaclara.fullMR","att.rcMR","att.mcMR")])
apa.cor.table(womencordata, show.conf.interval = FALSE, landscape = FALSE)
womencordatamatrix<-as.matrix(womencordata)
rcorr(womencordatamatrix, type = "pearson")

#Plotting
describe(MCRCStudy4Data.Women$po.fullMR)
describe(MCRCStudy4Data.Women$att.rc.cMR)
describe(MCRCStudy4Data.Women$santaclara.full.cMR)
describe(MCRCStudy4Data.Women$santaclara.fullMR)

mcWomen.RCAtPO <- plotSlopes(mcWomen.2wayplot, plotx="att.rc.cMR", modx="po.fullMR", 
                            xlab = "Religious Conviction War on Women", xlim = c(-.93,3.07),ylab = "War on Women Moral Conviction", 
                            modxVals = c(-2.52,0,2.52), plotPoints = FALSE,
                            legendTitle = "Political Orientation")

mcWomen.RCAtPO.test <- testSlopes(mcWomen.RCAtPO)
round(mcWomen.RCAtPO.test$hypotests,3)


mcWomen.SCAtPO <- plotSlopes(mcWomen.2wayplot, plotx="santaclara.full.cMR", modx="po.fullMR", 
                            xlab = "Religiosity", xlim = c(-3.43,3.57),ylab = "War on Women Moral Conviction", 
                            modxVals = c(-2.52,0,2.52), plotPoints = FALSE,
                            legendTitle = "Political Orientation")

mcWomen.SCAtPO.test <- testSlopes(mcWomen.SCAtPO)
round(mcWomen.SCAtPO.test$hypotests,3)


#Plotting pretty with ggplot
mcWomen.2wayplot <- lm(att.mcMR ~ po.fullMR
                   + santaclara.full.cMR
                   + att.rc.cMR
                   + (po.fullMR*santaclara.full.cMR)
                   + (po.fullMR*att.rc.cMR),
                   data = MCRCStudy4Data.Women) 

#Plotting the Political orientation by religious conviction interaction predicting moral conviction.
#The effect of religious conviction at PO moderates and one standard deviation above and below moderate (2.52).
summary(mcWomen.2wayplot)
describe(MCRCStudy4Data.Women$att.rc.cMR)

#Getting the effects for the PO by Religious conviction interaction
# at 1 SD below moderate, moderate, and 1 SD above moderate (-2.52, 0, 2.52).
# Specifying the full range of religious conviction (min = -0.93 max = 3.07, every one unit) 
# The variable is mean centered, so this translates to the original points on the 1-5 scale.
mcWomen.RCAtPO.fitted<-effect('po.fullMR:att.rc.cMR', mcWomen.2wayplot,
                            xlevels=list(po.fullMR=c(-2.52, 0, 2.52),
                                         att.rc.cMR = seq(from = -.93, to = 3.07, by =1)), 
                            se=TRUE,confidence.level=.95)

#Saving the effects as a data frame. 
mcWomen.RCAtPO.Eff<-as.data.frame(mcWomen.RCAtPO.fitted)

#Recoding the moderator variable (PO) as a factor with the names of the groups. 
mcWomen.RCAtPO.Eff$POmod<-factor(mcWomen.RCAtPO.Eff$po.fullMR,
                               levels=c(-2.52,0,2.52),
                               labels=c("Liberals","Moderates","Conservatives"))

mcWomen.RCAtPO.Plot <-ggplot(data = mcWomen.RCAtPO.Eff, aes(x = att.rc.cMR, y =fit, group=POmod))+
  coord_cartesian(xlim=c(-.93, 3.07),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -.93, to = 3.07, by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=POmod, linetype = POmod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=POmod),alpha=.2)+
  xlab("War on Women Religious Conviction")+
  ylab("War on Women Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .87))
mcWomen.RCAtPO.Plot


#Plotting the Political orientation by religiosity interaction predicting moral conviction.
#The effect of religiosity at PO moderates and one standard deviation above and below moderate (2.52).
summary(mcWomen.2wayplot)
describe(MCRCStudy4Data.Women$santaclara.full.cMR)

#Getting the effects for the PO by Religious conviction interaction
# at 1 SD below moderate, moderate, and 1 SD above moderate (-2.52, 0, 2.52).
# Specifying the full range of religiosity (min = -2.79 max = 3.21, every one unit) 
# The variable is mean centered, so this translates to the original points on the 1-7 scale.
mcWomen.SCAtPO.fitted<-effect('po.fullMR:santaclara.full.cMR', mcWomen.2wayplot,
                              xlevels=list(po.fullMR=c(-2.52, 0, 2.52),
                                           santaclara.full.cMR = seq(from = -2.79, to = 3.21, by =1)), 
                              se=TRUE,confidence.level=.95)

#Saving the effects as a data frame. 
mcWomen.SCAtPO.Eff<-as.data.frame(mcWomen.SCAtPO.fitted)

#Recoding the moderator variable (PO) as a factor with the names of the groups. 
mcWomen.SCAtPO.Eff$POmod<-factor(mcWomen.SCAtPO.Eff$po.fullMR,
                                 levels=c(-2.52,0,2.52),
                                 labels=c("Liberals","Moderates","Conservatives"))

mcWomen.SCAtPO.Plot <-ggplot(data = mcWomen.SCAtPO.Eff, aes(x = santaclara.full.cMR, y =fit, group=POmod))+
  coord_cartesian(xlim=c(-2.79, 3.21),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -2.79, to = 3.21, by =1),labels = c(1,2,3,4,5,6,7))+
  geom_line(aes(color=POmod, linetype = POmod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=POmod),alpha=.2)+
  xlab("Religiosity")+
  ylab("War on Women Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .87))
mcWomen.SCAtPO.Plot


#########################################################################################################
##### For Workplace issue: Do you agree/disagree with idea that there is lack of professionalism in workplace? #####
#########################################################################################################

MCRCStudy4Data.Work <- subset(MCRCStudy4Data, topic == 3)
describe(MCRCStudy4Data.Work$att.mc)
describe(MCRCStudy4Data.Work$att.rc)
describe(MCRCStudy4Data.Work$po.full)
describe(MCRCStudy4Data.Work$santaclara.full)

MCRCStudy4Data.Work$att.rc.c <- scale(MCRCStudy4Data.Work$att.rc, scale = FALSE)[,]
describe(MCRCStudy4Data.Work$att.rc.c)

MCRCStudy4Data.Work$santaclara.full.c <- scale(MCRCStudy4Data.Work$santaclara.full, scale = FALSE)[,]
describe(MCRCStudy4Data.Work$santaclara.full.c)

### Creating mean replacement variables to take care of missingness.
#If else statement: if value of the variable is missing, replace with the mean of the variable, else use the original value.

#Mean centered time religious conviction for workplace professionalism. Replace missing values with mean (0 since it's mean centered). 
MCRCStudy4Data.Work$att.rcMR <- ifelse(is.na(MCRCStudy4Data.Work$att.rc),
                                                     mean(MCRCStudy4Data.Work$att.rc,na.rm=TRUE), MCRCStudy4Data.Work$att.rc)

describe(MCRCStudy4Data.Work$att.rc)
describe(MCRCStudy4Data.Work$att.rcMR)

MCRCStudy4Data.Work$att.rc.cMR <- ifelse(is.na(MCRCStudy4Data.Work$att.rc.c),
                                                      mean(MCRCStudy4Data.Work$att.rc.c,na.rm=TRUE), MCRCStudy4Data.Work$att.rc.c)

describe(MCRCStudy4Data.Work$att.rc.c)
describe(MCRCStudy4Data.Work$att.rc.cMR)


#Midpoint centered political orientation. Replace missing values with mean. 
MCRCStudy4Data.Work$po.fullMR <- ifelse(is.na(MCRCStudy4Data.Work$po.full),
                                                     mean(MCRCStudy4Data.Work$po.full,na.rm=TRUE), MCRCStudy4Data.Work$po.full)

describe(MCRCStudy4Data.Work$po.full)
describe(MCRCStudy4Data.Work$po.fullMR)


#Mean centered time religiosity for workplace professionalism. Replace missing values with mean (0 since it's mean centered). 
MCRCStudy4Data.Work$santaclara.fullMR <- ifelse(is.na(MCRCStudy4Data.Work$santaclara.full),
                                                              mean(MCRCStudy4Data.Work$santaclara.full,na.rm=TRUE), MCRCStudy4Data.Work$santaclara.full)

describe(MCRCStudy4Data.Work$santaclara.full)
describe(MCRCStudy4Data.Work$santaclara.fullMR)

MCRCStudy4Data.Work$santaclara.full.cMR <- ifelse(is.na(MCRCStudy4Data.Work$santaclara.full.c),
                                                               mean(MCRCStudy4Data.Work$santaclara.full.c,na.rm=TRUE), MCRCStudy4Data.Work$santaclara.full.c)

describe(MCRCStudy4Data.Work$santaclara.full.c)
describe(MCRCStudy4Data.Work$santaclara.full.cMR)


#Moral conviction for workplace professionalism. Replace missing values with mean. 
MCRCStudy4Data.Work$att.mcMR <- ifelse(is.na(MCRCStudy4Data.Work$att.mc),
                                                    mean(MCRCStudy4Data.Work$att.mc,na.rm=TRUE), MCRCStudy4Data.Work$att.mc)

describe(MCRCStudy4Data.Work$att.mc)
describe(MCRCStudy4Data.Work$att.mcMR)

############################################
#### Moral conviction about workplace professionalism ####

#Main effects political orientation, workplace religious conviction, religiosity
mcWork.main <- lm(att.mcMR ~ po.fullMR
                  + santaclara.full.cMR
                  + att.rc.cMR,
                   data = MCRCStudy4Data.Work) 
summary(mcWork.main)

#Mmain effects & 2-way Interactions
mcWork.2way <- lm(att.mcMR ~ po.fullMR
                  + santaclara.full.cMR
                  + att.rc.cMR
                  + I(santaclara.full.cMR*att.rc.cMR)
                  + I(po.fullMR*santaclara.full.cMR)
                  + I(po.fullMR*att.rc.cMR),
                   data = MCRCStudy4Data.Work) 
summary(mcWork.2way)

anova(mcWork.main,mcWork.2way)

#Mmain effects, 2-way Interactions, and 3-way interaction
mcWork.3way <- lm(att.mcMR ~ po.fullMR
                  + santaclara.full.cMR
                  + att.rc.cMR
                  + I(santaclara.full.cMR*att.rc.cMR)
                  + I(po.fullMR*santaclara.full.cMR)
                  + I(po.fullMR*att.rc.cMR)
                  + I(santaclara.full.cMR*att.rc.cMR*po.fullMR),
                   data = MCRCStudy4Data.Work) 
summary(mcWork.3way)

anova(mcWork.main,mcWork.2way,mcWork.3way)

##Nice table of all the steps
stargazer(mcWork.main,mcWork.2way,mcWork.3way,type="text",
          column.labels = c("Main Effects", "2-way Interactions", "3-way Interaction"),
          intercept.bottom = FALSE, star.cutoffs = c(.05,.01,.001),
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

# Tables for Linda
workcordata<-subset(MCRCStudy4Data.Work[,c("po.fullMR","santaclara.fullMR","att.rcMR","att.mcMR")])
apa.cor.table(workcordata, show.conf.interval = FALSE, landscape = FALSE)
workcordatamatrix<-as.matrix(workcordata)
rcorr(workcordatamatrix, type = "pearson")

#Plotting
# No significant interactions


### Descriptives ###
describe(MCRCStudy4Data$age)

str(MCRCStudy4Data$gender)
attr(AnthonyConsensusData$gender, "value.labels")
MCRCStudy4Data$gender.f<-factor(MCRCStudy4Data$gender, levels = c(3,2,1), labels = c("other","female","male"))
prop.table(table(MCRCStudy4Data$gender.f))*100

str(MCRCStudy4Data$edu)
MCRCStudy4Data$edu.f<-factor(MCRCStudy4Data$edu, levels = c(7,6,5,4,3,2,1),
                                       labels = c("Doctoral degree","Master's / professional degree",
                                                  "Bachelor's degree","Associate's degree",
                                                  "Some college, no degree","High school / GED",
                                                  "Less than high school"))

str(MCRCStudy4Data$edu.f)
table(MCRCStudy4Data$edu.f)
prop.table(table(MCRCStudy4Data$edu.f))*100

MCRCStudy4Data.XmasAlpha <- subset(MCRCStudy4Data, select = c("xmas.att.mc1","xmas.att.mc2"))
alpha(MCRCStudy4Data.XmasAlpha)

MCRCStudy4Data.WomenAlpha <- subset(MCRCStudy4Data, select = c("women.att.mc1","women.att.mc2"))
alpha(MCRCStudy4Data.WomenAlpha)

MCRCStudy4Data.WorkAlpha <- subset(MCRCStudy4Data, select = c("work.att.mc1","work.att.mc2"))
alpha(MCRCStudy4Data.WorkAlpha)

MCRCStudy4Data.SantaClara <- subset(MCRCStudy4Data, select = c("santaclara1","santaclara2","santaclara3"))
alpha(MCRCStudy4Data.SantaClara)

