###################################
########### Interaction follow-ups 
###### RC and MC distinct

library(rockchalk) #Graphing simple slopes; moderation
library(stargazer) #Handy regression tables
library(foreign)  # Read in SPSS
library(gvlma)   #helper on diagnostics
library(effects) #helper on visualizing interactions - Uses lattice
library(sjPlot)  #helper on visualizing interactions - uses ggplot
library(ggplot2) #All the graphs
library(psych) #handy for descriptives, etc
library(dplyr)
library(apaTables)
library(texreg)
library(Hmisc)
describe <- psych::describe

#set working directory
setwd("")

MCRCStudy5Data<-read.spss("MCRC_Study5_Data.sav", use.value.labels = FALSE, to.data.frame = TRUE,
                 max.value.labels = Inf, trim.factor.names = FALSE,
                 trim_values = TRUE, reencode = NA, use.missings = to.data.frame)
str(MCRCStudy5Data)
head(MCRCStudy5Data)

##################################################################################################################################
##### For Conservative bias issue: Do you agree/disagree with idea that there is conservative bias taking over universities? #####
##################################################################################################################################
MCRCStudy5Data.ConBias <- subset(MCRCStudy5Data, topic == 1 & !is.na(attitude))
describe(MCRCStudy5Data.ConBias$att.mc)
describe(MCRCStudy5Data.ConBias$att.rc)
describe(MCRCStudy5Data.ConBias$po.full)
describe(MCRCStudy5Data.ConBias$santaclara.full)

MCRCStudy5Data.ConBias$att.rc.c <- scale(MCRCStudy5Data.ConBias$att.rc, scale = FALSE)[,]
describe(MCRCStudy5Data.ConBias$att.rc.c)

MCRCStudy5Data.ConBias$santaclara.full.c <- scale(MCRCStudy5Data.ConBias$santaclara.full, scale = FALSE)[,]
describe(MCRCStudy5Data.ConBias$santaclara.full.c)

### Creating mean replacement variables to take care of missingness.
#If else statement: if value of the variable is missing, replace with the mean of the variable, else use the original value.

#Mean centered time religious conviction for war on xmas. Replace missing values with mean (0 since it's mean centered). 
MCRCStudy5Data.ConBias$att.rcMR <- ifelse(is.na(MCRCStudy5Data.ConBias$att.rc),
                                                     mean(MCRCStudy5Data.ConBias$att.rc,na.rm=TRUE), MCRCStudy5Data.ConBias$att.rc)

describe(MCRCStudy5Data.ConBias$att.rc)
describe(MCRCStudy5Data.ConBias$att.rcMR)

MCRCStudy5Data.ConBias$att.rc.cMR <- ifelse(is.na(MCRCStudy5Data.ConBias$att.rc.c),
                                     mean(MCRCStudy5Data.ConBias$att.rc.c,na.rm=TRUE), MCRCStudy5Data.ConBias$att.rc.c)

describe(MCRCStudy5Data.ConBias$att.rc.c)
describe(MCRCStudy5Data.ConBias$att.rc.cMR)


#Midpoint centered political orientation. Replace missing values with mean. 
MCRCStudy5Data.ConBias$po.fullMR <- ifelse(is.na(MCRCStudy5Data.ConBias$po.full),
                                          mean(MCRCStudy5Data.ConBias$po.full,na.rm=TRUE), MCRCStudy5Data.ConBias$po.full)

describe(MCRCStudy5Data.ConBias$po.full)
describe(MCRCStudy5Data.ConBias$po.fullMR)


#Mean centered time religiosity for war on xmas. Replace missing values with mean (0 since it's mean centered). 
MCRCStudy5Data.ConBias$santaclara.fullMR <- ifelse(is.na(MCRCStudy5Data.ConBias$santaclara.full),
                                                              mean(MCRCStudy5Data.ConBias$santaclara.full,na.rm=TRUE), MCRCStudy5Data.ConBias$santaclara.full)

describe(MCRCStudy5Data.ConBias$santaclara.full)
describe(MCRCStudy5Data.ConBias$santaclara.fullMR)

MCRCStudy5Data.ConBias$santaclara.full.cMR <- ifelse(is.na(MCRCStudy5Data.ConBias$santaclara.full.c),
                                                     mean(MCRCStudy5Data.ConBias$santaclara.full.c,na.rm=TRUE), MCRCStudy5Data.ConBias$santaclara.full.c)

describe(MCRCStudy5Data.ConBias$santaclara.full.c)
describe(MCRCStudy5Data.ConBias$santaclara.full.cMR)


#Moral conviction for war on xmas. Replace missing values with mean. 
MCRCStudy5Data.ConBias$att.mcMR <- ifelse(is.na(MCRCStudy5Data.ConBias$att.mc),
                                          mean(MCRCStudy5Data.ConBias$att.mc,na.rm=TRUE), MCRCStudy5Data.ConBias$att.mc)

describe(MCRCStudy5Data.ConBias$att.mc)
describe(MCRCStudy5Data.ConBias$att.mcMR)

##################################################
#### Moral conviction about conservative bias ####

#Main effects political orientation, religious conviction, religiosity
mcConBias.main <- lm(att.mcMR ~ po.fullMR
                  + santaclara.full.cMR
                  + att.rc.cMR,
                  data = MCRCStudy5Data.ConBias) 
summary(mcConBias.main)

#Mmain effects & 2-way Interactions
mcConBias.2way <- lm(att.mcMR ~ po.fullMR
                  + santaclara.full.cMR
                  + att.rc.cMR
                  + I(santaclara.full.cMR*att.rc.cMR)
                  + I(po.fullMR*santaclara.full.cMR)
                  + I(po.fullMR*att.rc.cMR),
                  data = MCRCStudy5Data.ConBias) 
summary(mcConBias.2way)

anova(mcConBias.main,mcConBias.2way)

#Mmain effects, 2-way Interactions, and 3-way interaction
mcConBias.3way <- lm(att.mcMR ~ po.fullMR
                  + santaclara.full.cMR
                  + att.rc.cMR
                  + I(santaclara.full.cMR*att.rc.cMR)
                  + I(po.fullMR*santaclara.full.cMR)
                  + I(po.fullMR*att.rc.cMR)
                  + I(santaclara.full.cMR*att.rc.cMR*po.fullMR),
                  data = MCRCStudy5Data.ConBias) 
summary(mcConBias.3way)

anova(mcConBias.main,mcConBias.2way,mcConBias.3way)

##Nice table of all the steps
stargazer(mcConBias.main,mcConBias.2way,mcConBias.3way,type="text",
          column.labels = c("Main Effects", "2-way Interactions", "3-way Interaction"),
          intercept.bottom = FALSE, star.cutoffs = c(.05,.01,.001),
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

# Tables for Linda
concordata<-subset(MCRCStudy5Data.ConBias[,c("po.fullMR","santaclara.fullMR","att.rcMR","att.mcMR")])
apa.cor.table(concordata, show.conf.interval = FALSE, landscape = FALSE)
concordatamatrix<-as.matrix(concordata)
rcorr(concordatamatrix, type = "pearson")

#Plotting
# No significant interactions


###############################################################################################################
##### For liberal bias issue: Do you agree/disagree with idea that there is liberal bias at universities? #####
###############################################################################################################

MCRCStudy5Data.LibBias <- subset(MCRCStudy5Data, topic == 2 & !is.na(attitude))
describe(MCRCStudy5Data.LibBias$att.mc)
describe(MCRCStudy5Data.LibBias$att.rc)
describe(MCRCStudy5Data.LibBias$po.full)
describe(MCRCStudy5Data.LibBias$santaclara.full)

MCRCStudy5Data.LibBias$att.rc.c <- scale(MCRCStudy5Data.LibBias$att.rc, scale = FALSE)[,]
describe(MCRCStudy5Data.LibBias$att.rc.c)

MCRCStudy5Data.LibBias$santaclara.full.c <- scale(MCRCStudy5Data.LibBias$santaclara.full, scale = FALSE)[,]
describe(MCRCStudy5Data.LibBias$santaclara.full.c)

### Creating mean replacement variables to take care of missingness.
#If else statement: if value of the variable is missing, replace with the mean of the variable, else use the original value.

#Mean centered time religious conviction for war on women. Replace missing values with mean (0 since it's mean centered). 
MCRCStudy5Data.LibBias$att.rcMR <- ifelse(is.na(MCRCStudy5Data.LibBias$att.rc),
                                                      mean(MCRCStudy5Data.LibBias$att.rc,na.rm=TRUE), MCRCStudy5Data.LibBias$att.rc)

describe(MCRCStudy5Data.LibBias$att.rc)
describe(MCRCStudy5Data.LibBias$att.rcMR)

MCRCStudy5Data.LibBias$att.rc.cMR <- ifelse(is.na(MCRCStudy5Data.LibBias$att.rc.c),
                                                     mean(MCRCStudy5Data.LibBias$att.rc.c,na.rm=TRUE), MCRCStudy5Data.LibBias$att.rc.c)

describe(MCRCStudy5Data.LibBias$att.rc.c)
describe(MCRCStudy5Data.LibBias$att.rc.cMR)


#Midpoint centered political orientation. Replace missing values with mean. 
MCRCStudy5Data.LibBias$po.fullMR <- ifelse(is.na(MCRCStudy5Data.LibBias$po.full),
                                                    mean(MCRCStudy5Data.LibBias$po.full,na.rm=TRUE), MCRCStudy5Data.LibBias$po.full)

describe(MCRCStudy5Data.LibBias$po.full)
describe(MCRCStudy5Data.LibBias$po.fullMR)


#Mean centered time religiosity for war on women. Replace missing values with mean (0 since it's mean centered). 
MCRCStudy5Data.LibBias$santaclara.fullMR <- ifelse(is.na(MCRCStudy5Data.LibBias$santaclara.full),
                                                               mean(MCRCStudy5Data.LibBias$santaclara.full,na.rm=TRUE), MCRCStudy5Data.LibBias$santaclara.full)

describe(MCRCStudy5Data.LibBias$santaclara.full)
describe(MCRCStudy5Data.LibBias$santaclara.fullMR)

MCRCStudy5Data.LibBias$santaclara.full.cMR <- ifelse(is.na(MCRCStudy5Data.LibBias$santaclara.full.c),
                                                              mean(MCRCStudy5Data.LibBias$santaclara.full.c,na.rm=TRUE), MCRCStudy5Data.LibBias$santaclara.full.c)

describe(MCRCStudy5Data.LibBias$santaclara.full.c)
describe(MCRCStudy5Data.LibBias$santaclara.full.cMR)


#Moral conviction for war on women. Replace missing values with mean. 
MCRCStudy5Data.LibBias$att.mcMR <- ifelse(is.na(MCRCStudy5Data.LibBias$att.mc),
                                                   mean(MCRCStudy5Data.LibBias$att.mc,na.rm=TRUE), MCRCStudy5Data.LibBias$att.mc)

describe(MCRCStudy5Data.LibBias$att.mc)
describe(MCRCStudy5Data.LibBias$att.mcMR)


############################################
#### Moral conviction about war on women ####

#Main effects political orientation, war on women religious conviction, religiosity
mcLibBias.main <- lm(att.mcMR ~ po.fullMR
                   + santaclara.full.cMR
                   + att.rc.cMR,
                  data = MCRCStudy5Data.LibBias) 
summary(mcLibBias.main)

#Mmain effects & 2-way Interactions
mcLibBias.2way <- lm(att.mcMR ~ po.fullMR
                   + santaclara.full.cMR
                   + att.rc.cMR
                   + I(santaclara.full.cMR*att.rc.cMR)
                   + I(po.fullMR*santaclara.full.cMR)
                   + I(po.fullMR*att.rc.cMR),
                  data = MCRCStudy5Data.LibBias) 
summary(mcLibBias.2way)

anova(mcLibBias.main,mcLibBias.2way)

#Mmain effects, 2-way Interactions, and 3-way interaction
mcLibBias.3way <- lm(att.mcMR ~ po.fullMR
                   + santaclara.full.cMR
                   + att.rc.cMR
                   + I(santaclara.full.cMR*att.rc.cMR)
                   + I(po.fullMR*santaclara.full.cMR)
                   + I(po.fullMR*att.rc.cMR)
                   + I(santaclara.full.cMR*att.rc.cMR*po.fullMR),
                  data = MCRCStudy5Data.LibBias) 
summary(mcLibBias.3way)

anova(mcLibBias.main,mcLibBias.2way,mcLibBias.3way)

##Nice table of all the steps
stargazer(mcLibBias.main,mcLibBias.2way,mcLibBias.3way,type="text",
          column.labels = c("Main Effects", "2-way Interactions", "3-way Interaction"),
          intercept.bottom = FALSE, star.cutoffs = c(.05,.01,.001),
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

# Tables for Linda
libcordata<-subset(MCRCStudy5Data.LibBias[,c("po.fullMR","santaclara.fullMR","att.rcMR","att.mcMR")])
apa.cor.table(libcordata, show.conf.interval = FALSE, landscape = FALSE)
libcordatamatrix<-as.matrix(libcordata)
rcorr(libcordatamatrix, type = "pearson")

#Plotting
# No significant interactions


####################################################################################################################
##### For Workplace issue: Do you agree/disagree with idea that there is lack of professionalism in workplace? #####
####################################################################################################################

MCRCStudy5Data.Work <- subset(MCRCStudy5Data, topic == 3 & !is.na(attitude))
describe(MCRCStudy5Data.Work$att.mc)
describe(MCRCStudy5Data.Work$att.rc)
describe(MCRCStudy5Data.Work$po.full)
describe(MCRCStudy5Data.Work$santaclara.full)

MCRCStudy5Data.Work$att.rc.c <- scale(MCRCStudy5Data.Work$att.rc, scale = FALSE)[,]
describe(MCRCStudy5Data.Work$att.rc.c)

MCRCStudy5Data.Work$santaclara.full.c <- scale(MCRCStudy5Data.Work$santaclara.full, scale = FALSE)[,]
describe(MCRCStudy5Data.Work$santaclara.full.c)

### Creating mean replacement variables to take care of missingness.
#If else statement: if value of the variable is missing, replace with the mean of the variable, else use the original value.

#Mean centered time religious conviction for workplace professionalism. Replace missing values with mean (0 since it's mean centered). 
MCRCStudy5Data.Work$att.rcMR <- ifelse(is.na(MCRCStudy5Data.Work$att.rc),
                                                     mean(MCRCStudy5Data.Work$att.rc,na.rm=TRUE), MCRCStudy5Data.Work$att.rc)

describe(MCRCStudy5Data.Work$att.rc)
describe(MCRCStudy5Data.Work$att.rcMR)

MCRCStudy5Data.Work$att.rc.cMR <- ifelse(is.na(MCRCStudy5Data.Work$att.rc.c),
                                                      mean(MCRCStudy5Data.Work$att.rc.c,na.rm=TRUE), MCRCStudy5Data.Work$att.rc.c)

describe(MCRCStudy5Data.Work$att.rc.c)
describe(MCRCStudy5Data.Work$att.rc.cMR)


#Midpoint centered political orientation. Replace missing values with mean. 
MCRCStudy5Data.Work$po.fullMR <- ifelse(is.na(MCRCStudy5Data.Work$po.full),
                                                     mean(MCRCStudy5Data.Work$po.full,na.rm=TRUE), MCRCStudy5Data.Work$po.full)

describe(MCRCStudy5Data.Work$po.full)
describe(MCRCStudy5Data.Work$po.fullMR)


#Mean centered time religiosity for workplace professionalism. Replace missing values with mean (0 since it's mean centered). 
MCRCStudy5Data.Work$santaclara.fullMR <- ifelse(is.na(MCRCStudy5Data.Work$santaclara.full),
                                                              mean(MCRCStudy5Data.Work$santaclara.full,na.rm=TRUE), MCRCStudy5Data.Work$santaclara.full)

describe(MCRCStudy5Data.Work$santaclara.full)
describe(MCRCStudy5Data.Work$santaclara.fullMR)

MCRCStudy5Data.Work$santaclara.full.cMR <- ifelse(is.na(MCRCStudy5Data.Work$santaclara.full.c),
                                                               mean(MCRCStudy5Data.Work$santaclara.full.c,na.rm=TRUE), MCRCStudy5Data.Work$santaclara.full.c)

describe(MCRCStudy5Data.Work$santaclara.full.c)
describe(MCRCStudy5Data.Work$santaclara.full.cMR)


#Moral conviction for workplace professionalism. Replace missing values with mean. 
MCRCStudy5Data.Work$att.mcMR <- ifelse(is.na(MCRCStudy5Data.Work$att.mc),
                                                    mean(MCRCStudy5Data.Work$att.mc,na.rm=TRUE), MCRCStudy5Data.Work$att.mc)

describe(MCRCStudy5Data.Work$att.mc)
describe(MCRCStudy5Data.Work$att.mcMR)


############################################
#### Moral conviction about workplace professionalism ####

#Main effects political orientation, workplace religious conviction, religiosity
mcWork.main <- lm(att.mcMR ~ po.fullMR
                  + santaclara.full.cMR
                  + att.rc.cMR,
                   data = MCRCStudy5Data.Work) 
summary(mcWork.main)

#Mmain effects & 2-way Interactions
mcWork.2way <- lm(att.mcMR ~ po.fullMR
                  + santaclara.full.cMR
                  + att.rc.cMR
                  + I(santaclara.full.cMR*att.rc.cMR)
                  + I(po.fullMR*santaclara.full.cMR)
                  + I(po.fullMR*att.rc.cMR),
                   data = MCRCStudy5Data.Work) 
summary(mcWork.2way)

anova(mcWork.main,mcWork.2way)

#Mmain effects, 2-way Interactions, and 3-way interaction
mcWork.3way <- lm(att.mcMR ~ po.fullMR
                  + santaclara.full.cMR
                  + att.rc.cMR
                  + I(santaclara.full.cMR*att.rc.cMR)
                  + I(po.fullMR*santaclara.full.cMR)
                  + I(po.fullMR*att.rc.cMR)
                  + I(santaclara.full.cMR*att.rc.cMR*po.fullMR),
                   data = MCRCStudy5Data.Work) 
summary(mcWork.3way)

anova(mcWork.main,mcWork.2way,mcWork.3way)

##Nice table of all the steps
stargazer(mcWork.main,mcWork.2way,mcWork.3way,type="text",
          column.labels = c("Main Effects", "2-way Interactions", "3-way Interaction"),
          intercept.bottom = FALSE, star.cutoffs = c(.05,.01,.001),
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

# Tables for Linda
workcordata<-subset(MCRCStudy5Data.Work[,c("po.fullMR","santaclara.fullMR","att.rcMR","att.mcMR")])
apa.cor.table(workcordata, show.conf.interval = FALSE, landscape = FALSE)
workcordatamatrix<-as.matrix(workcordata)
rcorr(workcordatamatrix, type = "pearson")

#Plotting
# No significant interactions


### Descriptives ###
describe(MCRCStudy5Data$age)

str(MCRCStudy5Data$gender)
attr(MCRCStudy5Data$gender, "value.labels")
MCRCStudy5Data$gender.f<-factor(MCRCStudy5Data$gender, levels = c(3,2,1), labels = c("other","female","male"))
prop.table(table(MCRCStudy5Data$gender.f))*100

str(MCRCStudy5Data$edu)
MCRCStudy5Data$edu.f<-factor(MCRCStudy5Data$edu, levels = c(7,6,5,4,3,2,1),
                                       labels = c("Doctoral degree","Master's / professional degree",
                                                  "Bachelor's degree","Associate's degree",
                                                  "Some college, no degree","High school / GED",
                                                  "Less than high school"))

str(MCRCStudy5Data$edu.f)
table(MCRCStudy5Data$edu.f)
prop.table(table(MCRCStudy5Data$edu.f))*100

MCRCStudy5Data.ChristianAlpha <- subset(MCRCStudy5Data, select = c("christian.att.mc1","christian.att.mc2"))
alpha(MCRCStudy5Data.ChristianAlpha)

MCRCStudy5Data.IslamAlpha <- subset(MCRCStudy5Data, select = c("islam.att.mc1","islam.att.mc2"))
alpha(MCRCStudy5Data.IslamAlpha)

MCRCStudy5Data.WorkAlpha <- subset(MCRCStudy5Data, select = c("work.att.mc1","work.att.mc2"))
alpha(MCRCStudy5Data.WorkAlpha)

MCRCStudy5Data.SantaClara <- subset(MCRCStudy5Data, select = c("santaclara1","santaclara2","santaclara3"))
alpha(MCRCStudy5Data.SantaClara)

