###################################
########### Interaction follow-ups 
###### RC and MC distint



library(rockchalk) #Graphing simple slopes; moderation
library(stargazer) #Handy regression tables
library(foreign)  # Read in SPSS
library(gvlma)   #helper on diagnostics
library(effects) #helper on visualizing interactions - Uses lattice
library(sjPlot)  #helper on visualizing interactions - uses ggplot
library(ggplot2) #All the graphs
library(psych) #handy for descriptives, etc
library(dplyr) 

#set working directory
setwd("")

PerspectiveTaking<-read.spss("MCRC_Study6_Data.sav", use.value.labels = FALSE, to.data.frame = TRUE,
                 max.value.labels = Inf, trim.factor.names = FALSE,
                 trim_values = TRUE, reencode = NA, use.missings = to.data.frame)



length(PerspectiveTaking$PO)

describe(PerspectiveTaking$PO)
describe(PerspectiveTaking$AvgMCbaseline)
describe(PerspectiveTaking$AvgRCbaseline)

head(PerspectiveTaking)

PerspectiveTaking$AvgRCbaselineC <- scale(PerspectiveTaking$AvgRCbaseline, scale=FALSE)
describe(PerspectiveTaking$AvgRCbaselineC, na.rm = TRUE)


### Creating mean replacement variables to take care of missingness.
#If else statement: if value of the variable is missing, replace with the mean of the variable, else use the original value.

#Mean centered time 1 religious conviction. Replace missing values with mean (0 since it's mean centered). 
PerspectiveTaking$AvgRCbaselineCMR <- ifelse(is.na(PerspectiveTaking$AvgRCbaselineC),
                                     mean(PerspectiveTaking$AvgRCbaselineC,na.rm=TRUE), PerspectiveTaking$AvgRCbaselineC)

describe(PerspectiveTaking$AvgRCbaselineC)
round(PerspectiveTaking$AvgRCbaselineC, 3)

#time 1 Moral conviction. Replace missing values with mean (0 since it's mean centered). 
PerspectiveTaking$AvgMCbaselineMR <- ifelse(is.na(PerspectiveTaking$AvgMCbaseline),
                                             mean(PerspectiveTaking$AvgMCbaseline,na.rm=TRUE), PerspectiveTaking$AvgMCbaseline)

describe(PerspectiveTaking$AvgMCbaselineMR)
round(PerspectiveTaking$AvgMCbaselineMR, 3)


#Midpoint centered time 2 political orientation. Replace missing values with mean. 
PerspectiveTaking$POMR <- ifelse(is.na(PerspectiveTaking$PO),
                           mean(PerspectiveTaking$PO,na.rm=TRUE), PerspectiveTaking$PO)

describe(PerspectiveTaking$POMR)
round(PerspectiveTaking$POMR, 3)





##################################################
####T1 Moral conviction for legalized abortion 

#first, make sure that RC is read as a vector not a matrix
PerspectiveTaking$AvgRCbaselineCMRV <- as.vector(PerspectiveTaking$AvgRCbaselineCMR)

#Main effects T2 political orientation, T1 religious conviction for legalized abortion 

mcAbort.main <- lm(AvgMCbaselineMR ~ POMR
                  + AvgRCbaselineCMRV,
                  data = PerspectiveTaking) 
summary(mcAbort.main)

cor(PerspectiveTaking$AvgRCbaselineCMRV,PerspectiveTaking$AvgMCbaselineMR)
cor(PerspectiveTaking$AvgRCbaseline,PerspectiveTaking$AvgMCbaseline)
cor(PerspectiveTaking$AvgRCbaselineCMRV,PerspectiveTaking$POMR)
cor(PerspectiveTaking$AvgMCbaselineMR,PerspectiveTaking$POMR)

#Mmain effects & 2-way Interactions

mcAbort.2way <- lm(AvgMCbaselineMR ~ POMR
                  + AvgRCbaselineCMRV
                  + AvgRCbaselineCMRV*POMR,
                  data = PerspectiveTaking) 
summary(mcAbort.2way)
anova(mcAbort.main,mcAbort.2way)


stargazer(mcAbort.2way,type="text", title = "2 ways", out="mcAbort.2way.txt")

##Nice table of all the steps
stargazer(mcAbort.main,mcAbort.2way,type="text",
          column.labels = c("Main Effects", "2-way Interaction"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE,
          out="mcAbort.2wayfull.txt")

#Plotting
library(rockchalk)
?plotSlopes

describe(PerspectiveTaking$AvgRCbaselineCMRV)
describe(PerspectiveTaking$POMR)


mcAbort.RCAtPO <- plotSlopes(mcAbort.2way, plotx="AvgRCbaselineCMRV", modx="POMR", 
                  xlab = "Religious Conviction for Legalized Abortion", ylab = "Moral Conviction for Legalized Abortion", 
                  modxVals = c(-1.53, 0, 1.53), xlim = c (-1.27, 2.73), plotPoints = F, 
                  legendTitle = "Political Orientation")



mcAbort.RCAtPO.test <- testSlopes(mcAbort.RCAtPO)

mcAbort.RCAtPO.test$hypotests



