###################################
########### Interaction follow-ups 
###### RC and MC distint



library(rockchalk) #Graphing simple slopes; moderation
library(stargazer) #Handy regression tables
library(foreign)  # Read in SPSS
library(gvlma)   #helper on diagnostics
library(effects) #helper on visualizing interactions - Uses lattice
library(sjPlot)  #helper on visualizing interactions - uses ggplot
library(ggplot2) #All the graphs
library(psych) #handy for descriptives, etc
library(dplyr) 

#set working directory
setwd("")

PASData2<-read.spss("MCRC_Study7_Data.sav", use.value.labels = FALSE, to.data.frame = TRUE,
                             max.value.labels = Inf, trim.factor.names = FALSE,
                             trim_values = TRUE, reencode = NA, use.missings = to.data.frame)

head(PASData2)
str(PASData2)

length(PASData2$RELIGION)
length(PASData2$PASREL)

describe(PASData2$RELIGION)
describe(PASData2$PASREL)
describe(PASData2$PASMC)
describe(PASData2$PO)

#center continuous predictors 

PASData2$PASRELC <- scale(PASData2$PASREL, scale=FALSE)
describe(PASData2$PASRELC, na.rm = TRUE)

PASData2$RELIGIONC <- scale(PASData2$RELIGION, scale=FALSE)
describe(PASData2$RELIGIONC, na.rm = TRUE)



### Creating mean replacement variables to take care of missingness.
#If else statement: if value of the variable is missing, replace with the mean of the variable, else use the original value.

#Mean centered time 1 religious conviction. Replace missing values with mean (0 since it's mean centered). 
PASData2$PASRELCMR <- ifelse(is.na(PASData2$PASRELC),
                                             mean(PASData2$PASRELC,na.rm=TRUE), PASData2$PASRELC)

describe(PASData2$PASRELC)
describe(PASData2$PASRELCMR)
round(PASData2$PASRELCMR, 3)

#time 1 Moral conviction. Replace missing values with mean
PASData2$PASMCMR <- ifelse(is.na(PASData2$PASMC),
                                            mean(PASData2$PASMC,na.rm=TRUE), PASData2$PASMC)

describe(PASData2$PASMCMR)
describe(PASData2$PASMC)
round(PASData2$PASMCMR, 3)

#time 1 religiosity. Replace missing values with mean (0 since it's mean centered). 
PASData2$RELIGIONCMR <- ifelse(is.na(PASData2$RELIGIONC),
                            mean(PASData2$RELIGIONC,na.rm=TRUE), PASData2$RELIGIONC)

describe(PASData2$RELIGIONCMR)
describe(PASData2$RELIGIONC)
round(PASData2$RELIGIONCMR, 3)


#time 1 PO. Replace missing values with mean (0 since it's mean centered). 
PASData2$POMR <- ifelse(is.na(PASData2$PO),
                               mean(PASData2$PO,na.rm=TRUE), PASData2$PO)

describe(PASData2$POMR)
describe(PASData2$PO)
round(PASData2$POMR, 3)


##################################################
####T1 Moral conviction for PAS

PASData2$PASRELCMRV <- as.vector(PASData2$PASRELCMR)
PASData2$RELIGIONCMRV <- as.vector(PASData2$RELIGIONCMR)
PASData2$PASMCMRV <- as.vector(PASData2$PASMCMR)
PASData2$POMRV <- as.vector(PASData2$POMR)



#Main effects T1 political orientation, T1 religious conviction for PAS, T1 religiosity 

mcPAS.mainV <- lm(PASMCMRV ~ PASRELCMRV
                   + RELIGIONCMRV
                  + POMRV,
                   data = PASData2) 
summary(mcPAS.mainV)

cor(PASData2$PASRELCMRV,PASData2$PASMCMRV)


#Mmain effects & 2-way Interactions

mcPAS.2wayV <- lm(PASMCMRV ~ PASRELCMRV
                 + RELIGIONCMRV
                 + POMRV
                   + PASRELCMRV*RELIGIONCMRV
                  + POMRV*PASRELCMRV
                 + RELIGIONCMRV*POMRV,
                   data = PASData2) 
summary(mcPAS.2wayV)
anova(mcPAS.mainV,mcPAS.2wayV)

#main effects, 2 way, and 3 way interaction
mcPAS.3wayV <- lm(PASMCMRV ~ PASRELCMRV
                  + RELIGIONCMRV
                  + POMRV
                  + PASRELCMRV*RELIGIONCMRV
                  + POMRV*PASRELCMRV
                  + RELIGIONCMRV*POMRV
                  + PASRELCMRV*RELIGIONCMRV*POMRV,
                  data = PASData2) 
summary(mcPAS.3wayV)
anova(mcPAS.2wayV,mcPAS.3wayV)

stargazer(mcPAS.3wayV,type="text", title = "3 way", out="mcPAS.3way.txt")

##Nice table of all the steps
stargazer(mcPAS.mainV,mcPAS.2wayV,mcPAS.3wayV, type="text",
          column.labels = c("Main Effects", "2-way Interactions", "3-way Interaction"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE,
          out="mcPAS.3wayfull.txt")

#Le sigh 3 way :/

#Create High and Low PO, (Liberal, Conservative, Moderate)
describe(PASData2$POMRV)

PASData2$POMRVHi <- (PASData2$POMRV - sd(PASData2$POMRV))
PASData2$POMRVLo <- (PASData2$POMRV + sd(PASData2$POMRV))

describe(PASData2$POMRVHi)
describe(PASData2$POMRVLo)

#Simple Interaction of Religiosity and Religious Conviction for Hi PO (Conservatives).
mcPAS.3way.HiPO <- lm(PASMCMRV ~ POMRVHi
                       + RELIGIONCMRV
                       + PASRELCMRV
                       + RELIGIONCMRV*PASRELCMRV
                       + POMRVHi*RELIGIONCMRV
                       + POMRVHi*PASRELCMRV
                       + POMRVHi*PASRELCMRV*RELIGIONCMRV,
                       data = PASData2) 
summary(mcPAS.3way.HiPO)

#Simple Interaction of Religiosity and Religious Conviction for Lo PO (Liberals).
mcPAS.3way.LoPO <- lm(PASMCMRV ~ POMRVLo
                       + RELIGIONCMRV
                       + PASRELCMRV
                       + RELIGIONCMRV*PASRELCMRV
                       + POMRVLo*RELIGIONCMRV
                       + POMRVLo*PASRELCMRV
                       + POMRVLo*PASRELCMRV*RELIGIONCMRV,
                       data = PASData2) 
summary(mcPAS.3way.LoPO)

#Three simple interactions for Liberals, Moderates, and Conservatives. 
stargazer(mcPAS.3way.LoPO,mcPAS.3wayV,mcPAS.3way.HiPO,type="text",
          column.labels = c("Liberals", "Moderates", "Conservatives"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)


#Plotting the Religious Conviction by Religiosity by Political Orientation interaction predicting moral conviction
#The effect of Religious Convicition at mean religiousity and one standard deviation above and below 
#FOR Liberals (- 1SD), Moderates (Midpoint), and Conservatives (+1SD)
summary(mcPAS.3wayV)
describe(PASData2$POMRV)
describe(PASData2$RELIGIONCMRV)
describe(PASData2$PASRELCMRV)

PAS.RCatReligatPO.fitted<-effect('PASRELCMRV:RELIGIONCMRV:POMRV', mcPAS.3wayV,
                                    xlevels=list(POMRV=c(-1.39, 0 , 1.39),
                                                 RELIGIONCMRV=c(-1.93, 0 , 1.93),
                                                 PASRELCMRV = seq(from = -3.18, to = 2.82, by =1)), 
                                    se=TRUE,confidence.level=.95)

PAS.RCatReligatPO.Eff<-as.data.frame(PAS.RCatReligatPO.fitted)

PAS.RCatReligatPO.Eff$ReligMod<-factor(PAS.RCatReligatPO.Eff$RELIGIONCMRV,
                                          levels=c(-1.93,0,1.93),
                                          labels=c("Low Religiosity","Mean Religiosity","Hi Religiosity"))

PAS.RCatReligatPO.Eff$POMod<-factor(PAS.RCatReligatPO.Eff$POMRV,
                                       levels=c(-1.39,0,1.39),
                                       labels=c("Liberals","Moderates","Conservatives"))


PAS.RCatReligatPO.Plot <-ggplot(data = PAS.RCatReligatPO.Eff, aes(x = PASRELCMRV, y =fit, group=ReligMod))+
  facet_grid(~POMod)+
  coord_cartesian(xlim=c(-3.18, 2.82),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = -3.18, to = 2.82, by =1),labels = c(1,2,3,4,5,6,7))+
  geom_line(aes(color=ReligMod, linetype = ReligMod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=ReligMod),alpha=.2)+
  xlab("PAS Religious Conviction")+
  ylab("PAS Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .18))
PAS.RCatReligatPO.Plot

#Testing the Simple Slopes of the Simple Interaction Religious Conviction by Religiosity For Liberals. 
summary(SC_SSM.3way.LoPO)
describe(SCSSM$SSM_RCcmr)
describe(SCSSM$Religcmr)

PAS.RCAtRelig.Lib <- plotSlopes(mcPAS.3way.LoPO, plotx="PASRELCMRV", modx="RELIGIONCMRV", 
                                   xlab = "Religious Conviction", ylab = "Moral Conviction", 
                                   modxVals = c(-1.93,0,1.93), xlim = c (-3.18, 2.82), plotPoints = FALSE, 
                                   legendTitle = "Religiosity")

PAS.RCAtRelig.Lib.test <- testSlopes(PAS.RCAtRelig.Lib)
PAS.RCAtRelig.Lib.test$hypotests

PAS.RCAtRelig.Mod <- plotSlopes(mcPAS.3wayV, plotx="PASRELCMRV", modx="RELIGIONCMRV", 
                                   xlab = "Religious Conviction", ylab = "Moral Conviction", 
                                   modxVals = c(-1.93,0,1.93), xlim = c (-3.18, 2.82), plotPoints = FALSE, 
                                   legendTitle = "Religiosity")

PAS.RCAtRelig.Mod.test <- testSlopes(PAS.RCAtRelig.Mod)
PAS.RCAtRelig.Mod.test$hypotests

PAS.RCAtRelig.Con <- plotSlopes(mcPAS.3way.HiPO, plotx="PASRELCMRV", modx="RELIGIONCMRV", 
                                   xlab = "Religious Conviction", ylab = "Moral Conviction", 
                                   modxVals = c(-1.93,0,1.93), xlim = c (-3.18, 2.82), plotPoints = FALSE, 
                                   legendTitle = "Religiosity")

PAS.RCAtRelig.Con.test <- testSlopes(PAS.RCAtRelig.Con)
PAS.RCAtRelig.Con.test$hypotests


#Plotting
library(rockchalk)
?plotSlopes

describe(PASData1$RELIGIONCMR)
describe(PASData1$PASRELCMR)

mcPAS.RCAtRel <- plotSlopes(mcPAS.2wayV, plotx="PASRELCMRV", modx="RELIGIONCMRV", 
                            xlab = "Religious Conviction for PAS", ylab = "Moral Conviction for PAS", 
                            modxVals = c(-2.03, 2.03), xlim = c(-3.08, 2.92), plotPoints = F, 
                            legendTitle = "Religiosity")

mcPAS.RCAtRel.test <- testSlopes(mcPAS.RCAtRel)

mcPAS.RCAtRel.test$hypotests


describe(PASData1$POMR)
describe(PASData1$PASRELCMR)

mcPAS.RCAtPO <- plotSlopes(mcPAS.2wayV, plotx="PASRELCMRV", modx="POMRV", 
                             xlab = "Religious Conviction for PAS", ylab = "Moral Conviction for PAS", 
                             modxVals = c(-2.12, 0, 2.12), xlim = c(-3.08, 2.92), plotPoints = F, 
                             legendTitle = "PO")

mcPAS.RCAtPO.test <- testSlopes(mcPAS.RCAtPO)

mcPAS.RCAtPO.test$hypotests


