####################################################################
####################################################################
#######  Religious Conviction Predicting Moral Conviction   #########

library(rockchalk) #Graphing simple slopes; moderation
library(stargazer) #Handy regression tables
library(foreign)  # Read in SPSS
library(gvlma)   #helper on diagnostics
library(effects) #helper on visualizing interactions - Uses lattice
library(sjPlot)  #helper on visualizing interactions - uses ggplot
library(ggplot2) #All the graphs
library(psych) #handy for descriptives, etc
library(dplyr) 

#Set working directory
setwd("C:/Users/Brittany/Box Sync/RC Project/Data sets/Study 8 (2012 Election BH)")

##########################################################################################
##########################################################################################
#### 2012 Election Paper

#Data for preferred  candidate analysis. 
Elect2012pref<-read.spss("MCRC_Study8_PreferredCandidate_Data.sav", use.value.labels = FALSE, to.data.frame = TRUE,
                         max.value.labels = Inf, trim.factor.names = FALSE,
                         trim_values = TRUE, reencode = NA, use.missings = to.data.frame)

#Data for non-preferred  candidate analysis. 
Elect2012Npref<-read.spss("MCRC_Study8_NonPreferredCandidate_Data.sav", use.value.labels = FALSE, to.data.frame = TRUE,
                          max.value.labels = Inf, trim.factor.names = FALSE,
                          trim_values = TRUE, reencode = NA, use.missings = to.data.frame)


describe(Elect2012pref$PO1)
describe(Elect2012pref$ReligiosityT1c)
describe(Elect2012pref$RCpreferredT1c)
describe(Elect2012pref$MCpreferredT1)

describe(Elect2012Npref$PO1)
describe(Elect2012Npref$ReligiosityT1c)
describe(Elect2012Npref$RCnonpreferredT1c)
describe(Elect2012Npref$MCnonpreferredT1)

### Creating mean replacement variables to take care of missingness.
#If else statement: if value of the variable is missing, replace with the mean of the variable, else use the original value.

#Mean centered time 1 religious conviction for preferred candidate. Replace missing values with mean (0 since it's mean centered). 
Elect2012pref$RCpreferredT1cMR <- ifelse(is.na(Elect2012pref$RCpreferredT1c),
                                         mean(Elect2012pref$RCpreferredT1c,na.rm=TRUE), 
                                         Elect2012pref$RCpreferredT1c)

describe(Elect2012pref$RCpreferredT1c)
round(Elect2012pref$RCpreferredT1cMR, 3)

#Time 1 religious conviction for preferred candidate. Replace missing values with mean. 
Elect2012pref$RCpreferredT1MR <- ifelse(is.na(Elect2012pref$RCpreferredT1),
                                        mean(Elect2012pref$RCpreferredT1,na.rm=TRUE), 
                                        Elect2012pref$RCpreferredT1)

describe(Elect2012pref$RCpreferredT1)
round(Elect2012pref$RCpreferredT1MR, 3)

#Mean centered time 1 religious conviction for non-preferred candidate. Replace missing values with mean (0 since it's mean centered). 
Elect2012Npref$RCnonpreferredT1cMR <- ifelse(is.na(Elect2012Npref$RCnonpreferredT1c),
                                             mean(Elect2012Npref$RCnonpreferredT1c,na.rm=TRUE), 
                                             Elect2012Npref$RCnonpreferredT1c)

describe(Elect2012Npref$RCnonpreferredT1c)
round(Elect2012Npref$RCnonpreferredT1cMR, 3)

#Time 1 religious conviction for non-preferred candidate. Replace missing values with mean. 
Elect2012Npref$RCnonpreferredT1MR <- ifelse(is.na(Elect2012Npref$RCnonpreferredT1),
                                            mean(Elect2012Npref$RCnonpreferredT1,na.rm=TRUE), 
                                            Elect2012Npref$RCnonpreferredT1)

describe(Elect2012Npref$RCnonpreferredT1)
round(Elect2012Npref$RCnonpreferredT1MR, 3)

#Midpoint (moderate) centered time 1 political orientation. Replace missing values with mean. For Preferred Data. 
Elect2012pref$PO1MR <- ifelse(is.na(Elect2012pref$PO1),
                              mean(Elect2012pref$PO1,na.rm=TRUE), 
                              Elect2012pref$PO1)

describe(Elect2012pref$PO1MR)
round(Elect2012pref$PO1MR, 3)

#Midpoint (moderate) centered time 1 political orientation. Replace missing values with mean. For Non-Preferred Data. 
Elect2012Npref$PO1MR <- ifelse(is.na(Elect2012Npref$PO1),
                               mean(Elect2012Npref$PO1,na.rm=TRUE), 
                               Elect2012Npref$PO1)

describe(Elect2012Npref$PO1MR)
round(Elect2012Npref$PO1MR, 3)

#Mean centered time 1 religiosity. Replace missing values with mean (0 since it's mean centered). For Preferred Data.
Elect2012pref$ReligiosityT1cMR <- ifelse(is.na(Elect2012pref$ReligiosityT1c),
                                         mean(Elect2012pref$ReligiosityT1c,na.rm=TRUE), 
                                         Elect2012pref$ReligiosityT1c)

describe(Elect2012pref$ReligiosityT1c)
round(Elect2012pref$ReligiosityT1cMR, 3)

#Time 1 religiosity. Replace missing values with mean. For Preferred Data.
Elect2012pref$ReligiosityT1MR <- ifelse(is.na(Elect2012pref$ReligiosityT1),
                                        mean(Elect2012pref$ReligiosityT1,na.rm=TRUE), Elect2012pref$ReligiosityT1)

describe(Elect2012pref$ReligiosityT1)
round(Elect2012pref$ReligiosityT1MR, 3)

#Mean centered time 1 religiosity. Replace missing values with mean (0 since it's mean centered). For Non-Preferred Data.
Elect2012Npref$ReligiosityT1cMR <- ifelse(is.na(Elect2012Npref$ReligiosityT1c),
                                          mean(Elect2012Npref$ReligiosityT1c,na.rm=TRUE), Elect2012Npref$ReligiosityT1c)

describe(Elect2012Npref$ReligiosityT1c)
round(Elect2012Npref$ReligiosityT1cMR, 3)

#Mean centered time 1 religiosity. Replace missing values with mean (0 since it's mean centered). For Non-Preferred Data.
Elect2012Npref$ReligiosityT1MR <- ifelse(is.na(Elect2012Npref$ReligiosityT1),
                                         mean(Elect2012Npref$ReligiosityT1,na.rm=TRUE), 
                                         Elect2012Npref$ReligiosityT1)

describe(Elect2012Npref$ReligiosityT1)
round(Elect2012Npref$ReligiosityT1, 3)
round(Elect2012Npref$ReligiosityT1MR, 3)

#Time 1 moral conviction for preferred candidate. Replace missing values with mean. 
Elect2012pref$MCpreferredT1MR <- ifelse(is.na(Elect2012pref$MCpreferredT1),
                                        mean(Elect2012pref$MCpreferredT1,na.rm=TRUE), Elect2012pref$MCpreferredT1)

describe(Elect2012pref$MCpreferredT1)
round(Elect2012pref$MCpreferredT1MR, 3)

#Time 1 moral conviction for non-preferred candidate. Replace missing values with mean. 
Elect2012Npref$MCnonpreferredT1MR <- ifelse(is.na(Elect2012Npref$MCnonpreferredT1),
                                            mean(Elect2012Npref$MCnonpreferredT1,na.rm=TRUE), Elect2012Npref$MCnonpreferredT1)

describe(Elect2012Npref$MCnonpreferredT1)
round(Elect2012Npref$MCnonpreferredT1MR, 3)

##################################################
####Preferred Candidate Moral conviction

##Descriptives and Bi-variate correlations.
describe(Elect2012pref$PO1MR)
describe(Elect2012pref$ReligiosityT1MR)
describe(Elect2012pref$RCpreferredT1MR)
describe(Elect2012pref$MCpreferredT1MR)

cor.test(Elect2012pref$PO1,Elect2012pref$ReligiosityT1)
cor.test(Elect2012pref$PO1,Elect2012pref$RCpreferredT1)
cor.test(Elect2012pref$PO1,Elect2012pref$MCpreferredT1)
cor.test(Elect2012pref$ReligiosityT1, Elect2012pref$RCpreferredT1)
cor.test(Elect2012pref$ReligiosityT1, Elect2012pref$MCpreferredT1)
cor.test(Elect2012pref$RCpreferredT1, Elect2012pref$MCpreferredT1)

#Main effects political orientation, religiosity, preferred candidate religious conviction. 
mcPref.main <- lm(MCpreferredT1MR ~ PO1MR
                  + ReligiosityT1cMR
                  + RCpreferredT1cMR,
                  data = Elect2012pref) 
summary(mcPref.main)

#Main effects & 2-way Interactions
mcPref.2way <- lm(MCpreferredT1MR ~ PO1MR
                  + ReligiosityT1cMR
                  + RCpreferredT1cMR
                  + ReligiosityT1cMR*RCpreferredT1cMR
                  + PO1MR*ReligiosityT1cMR
                  + PO1MR*RCpreferredT1cMR,
                  data = Elect2012pref) 
summary(mcPref.2way)
anova(mcPref.main,mcPref.2way)

#Main effects & 2-way Interactions & 3-way interaction
mcPref.3way <- lm(MCpreferredT1MR ~ PO1MR
                  + ReligiosityT1cMR
                  + RCpreferredT1cMR
                  + ReligiosityT1cMR*RCpreferredT1cMR
                  + PO1MR*ReligiosityT1cMR
                  + PO1MR*RCpreferredT1cMR
                  + PO1MR*RCpreferredT1cMR*ReligiosityT1cMR,
                  data = Elect2012pref) 
summary(mcPref.3way)
anova(mcPref.2way,mcPref.3way)

#Nice table of all the steps
stargazer(mcPref.main,mcPref.2way,mcPref.3way,type="text",
          column.labels = c("Main Effects", "2-way Interactions", "3-way Interaction"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

#Main effects & Significant 2-way Interactions
mcPref.2way.sig <- lm(MCpreferredT1MR ~ PO1MR
                      + ReligiosityT1cMR
                      + RCpreferredT1cMR
                      + PO1MR*ReligiosityT1cMR
                      + PO1MR*RCpreferredT1cMR,
                      data = Elect2012pref) 
summary(mcPref.2way.sig)
anova(mcPref.main,mcPref.2way.sig)

##Table for main effects and significant 2-ways. 
stargazer(mcPref.main,mcPref.2way.sig, type="text",
          column.labels = c("Main Effects", "Significant 2-way Interactions"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

##Plotting quick and dirty with rockchalk and getting simple slopes. 
describe(Elect2012pref$ReligiosityT1cMR)
describe(Elect2012pref$RCpreferredT1cMR)
describe(Elect2012pref$PO1MR)

#Religiosity by Political Orientation Interaction predicting Moral Conviction, 
# The effect of Religiosity at midpoint of PO (moderates) and +/- 1 SD. 
mcPref.RelgAtPO <- plotSlopes(mcPref.2way.sig, plotx="ReligiosityT1cMR", modx="PO1MR", 
                              xlab = "Religiosity", ylab = "Preferred Candidate Moral Conviction", 
                              modxVals = c(-sd(Elect2012pref$PO1MR), 0, sd(Elect2012pref$PO1MR)), 
                              xlim = c (min(Elect2012pref$ReligiosityT1cMR), max(Elect2012pref$ReligiosityT1cMR)), plotPoints = F, 
                              legendTitle = "Political Orientation")
mcPref.RelgAtPO.test <- testSlopes(mcPref.RelgAtPO)
mcPref.RelgAtPO.test$hypotests

#Religious Conviction by Political Orientation Interaction predicting Moral Conviction, 
# The effect of Religiosity at midpoint of PO (moderates) and +/- 1 SD. 
mcPref.RCAtPO <- plotSlopes(mcPref.2way.sig, plotx="RCpreferredT1cMR", modx="PO1MR", 
                            xlab = "Preferred Candidate Religious Conviction", ylab = "Preferred Candidate Moral Conviction", 
                            modxVals = c(-sd(Elect2012pref$PO1MR), 0, sd(Elect2012pref$PO1MR)), 
                            xlim = c (min(Elect2012pref$RCpreferredT1cMR), max(Elect2012pref$RCpreferredT1cMR)), 
                            plotPoints = FALSE, 
                            legendTitle = "Political Orientation")
mcPref.RCAtPO.test <- testSlopes(mcPref.RCAtPO)
mcPref.RCAtPO.test$hypotests

#Plotting pretty with ggplot. 

#Plotting the Political orientation by religiosity interaction predicting moral conviction.
# The effect of religiosity at PO moderates and one standard deviation above and below moderate (1.71).
summary(mcPref.2way.sig)
describe(Elect2012pref$ReligiosityT1cMR)

#Getting the effects for the PO by Religiosity interaction
# at 1 SD below moderate, moderate, and 1 SD above moderate (-1.71, 0, 1.71).
# Specifying the full range of Religiosity (min = -1.39 max = 2.61, every one unit) 
# The variable is mean centered, so this translates to the original points on the 1-5 scale.
Pref2012.RelgAtPO.fitted<-effect('PO1MR:ReligiosityT1cMR', mcPref.2way.sig,
                                 xlevels=list(PO1MR=c(-sd(Elect2012pref$PO1MR), 0 , sd(Elect2012pref$PO1MR)),
                                              ReligiosityT1cMR = seq(from = min(Elect2012pref$ReligiosityT1cMR), to = max(Elect2012pref$ReligiosityT1cMR), by =1)), 
                                 se=TRUE,confidence.level=.95)

#Saving the effects as a data frame. 
Pref2012.RelgAtPO.Eff<-as.data.frame(Pref2012.RelgAtPO.fitted)

#Recoding the moderator variable (PO) as a factor with the names of the levels. 
Pref2012.RelgAtPO.Eff$POmod<-factor(Pref2012.RelgAtPO.Eff$PO1MR,
                                    levels=c(-sd(Elect2012pref$PO1MR),0,sd(Elect2012pref$PO1MR)),
                                    labels=c("Liberal","Moderate","Conservative"))

#Create plot.
Pref2012.RelgAtPO.Plot <-ggplot(data = Pref2012.RelgAtPO.Eff, aes(x = ReligiosityT1cMR, y =fit, group=POmod))+
  coord_cartesian(xlim=c(min(Elect2012pref$ReligiosityT1cMR), max(Elect2012pref$ReligiosityT1cMR)),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = min(Elect2012pref$ReligiosityT1cMR), to = max(Elect2012pref$ReligiosityT1cMR), by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=POmod, linetype = POmod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=POmod),alpha=.2)+
  xlab("Religiosity")+
  ylab("Preferred Candidate Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .18))
Pref2012.RelgAtPO.Plot

#Plotting the Political orientation by religious conviction interaction predicting moral conviction.
#The effect of RC at moderates and one standard deviation above and below moderate (1.71).
summary(mcPref.2way.sig)
describe(Elect2012pref$RCpreferredT1cMR)
describe(Elect2012pref$PO1MR)

Pref2012.RCatPO.fitted<-effect('PO1MR:RCpreferredT1cMR', mcPref.2way.sig,
                               xlevels=list(PO1MR=c(-sd(Elect2012pref$PO1MR), 0 , sd(Elect2012pref$PO1MR)), 
                                            RCpreferredT1cMR = seq(from = min(Elect2012pref$RCpreferredT1cMR), to = max(Elect2012pref$RCpreferredT1cMR), by =1)), 
                               se=TRUE,confidence.level=.95)

Pref2012.RCatPO.Eff<-as.data.frame(Pref2012.RCatPO.fitted)

Pref2012.RCatPO.Eff$POmod<-factor(Pref2012.RCatPO.Eff$PO1MR,
                                  levels=c(-sd(Elect2012pref$PO1MR),0,sd(Elect2012pref$PO1MR)),
                                  labels=c("Liberal","Moderate","Conservative"))

Perf2012.RCatPO.Plot <-ggplot(data = Pref2012.RCatPO.Eff, aes(x = RCpreferredT1cMR, y =fit, group=POmod))+
  coord_cartesian(xlim=c(min(Elect2012pref$RCpreferredT1cMR), max(Elect2012pref$RCpreferredT1cMR)),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = min(Elect2012pref$RCpreferredT1cMR), to = max(Elect2012pref$RCpreferredT1cMR), by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=POmod, linetype = POmod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=POmod),alpha=.2)+
  xlab("Preferred Candidate Religious Conviction")+
  ylab("Preferred Candidate Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .18))
Perf2012.RCatPO.Plot


##################################################
####Non-preferred Candidate Moral Conviction

##Descriptives and Bi-variate correlations.
describe(Elect2012Npref$PO1)
describe(Elect2012Npref$ReligiosityT1)
describe(Elect2012Npref$RCnonpreferredT1)
describe(Elect2012Npref$MCnonpreferredT1)

cor.test(Elect2012Npref$PO1,Elect2012Npref$ReligiosityT1)
cor.test(Elect2012Npref$PO1,Elect2012Npref$RCnonpreferredT1)
cor.test(Elect2012Npref$PO1,Elect2012Npref$MCnonpreferredT1)
cor.test(Elect2012Npref$ReligiosityT1, Elect2012Npref$RCnonpreferredT1)
cor.test(Elect2012Npref$ReligiosityT1, Elect2012Npref$MCnonpreferredT1)
cor.test(Elect2012Npref$RCnonpreferredT1, Elect2012Npref$MCnonpreferredT1)


#Main effects political orientation, religiosity, preferred candidate religious conviction 
mcNpref.main <- lm(MCnonpreferredT1MR ~ PO1MR
                   + ReligiosityT1cMR
                   + RCnonpreferredT1cMR,
                   data = Elect2012Npref) 
summary(mcNpref.main)

#Main effects & 2-way Interactions
mcNpref.2way <- lm(MCnonpreferredT1MR ~ PO1MR
                   + ReligiosityT1cMR
                   + RCnonpreferredT1cMR
                   + ReligiosityT1cMR*RCnonpreferredT1cMR
                   + PO1MR*ReligiosityT1cMR
                   + PO1MR*RCnonpreferredT1cMR,
                   data = Elect2012Npref) 
summary(mcNpref.2way)
anova(mcNpref.main,mcNpref.2way)

#Main effects & 2-way Interactions & 3-way interaction
mcNpref.3way <- lm(MCnonpreferredT1MR ~ PO1MR
                   + ReligiosityT1cMR
                   + RCnonpreferredT1cMR
                   + ReligiosityT1cMR*RCnonpreferredT1cMR
                   + PO1MR*ReligiosityT1cMR
                   + PO1MR*RCnonpreferredT1cMR
                   + PO1MR*RCnonpreferredT1cMR*ReligiosityT1cMR,
                   data = Elect2012Npref) 
summary(mcNpref.3way)
anova(mcNpref.2way,mcNpref.3way)

stargazer(mcNpref.2way,type="text", title = "2 ways")

##Nice table of all the steps
stargazer(mcNpref.main,mcNpref.2way,mcNpref.3way,type="text",
          column.labels = c("Main Effects", "2-way Interactions", "3-way Interaction"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

#Main effects & Significant 2-way Interactions
mcNpref.2way.sig <- lm(MCnonpreferredT1MR ~ PO1MR
                       + ReligiosityT1cMR
                       + RCnonpreferredT1cMR
                       + ReligiosityT1cMR*RCnonpreferredT1cMR
                       + PO1MR*ReligiosityT1cMR,
                       data = Elect2012Npref) 
summary(mcNpref.2way.sig)

##Table of main effects and significant 2-way interactions. 
stargazer(mcNpref.main,mcNpref.2way.sig,type="text",
          column.labels = c("Main Effects", "2-way Interactions"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)

#Plotting the Political orientation by Religiosity interaction predicting moral conviction.
#The effect of Religiosity at moderates and one standard deviation above and below moderate (1.72).
summary(mcNpref.2way.sig)
describe(Elect2012Npref$ReligiosityT1cMR)
describe(Elect2012Npref$PO1MR)

Npref2012.RelgAtPO.fitted<-effect('PO1MR:ReligiosityT1cMR', mcNpref.2way.sig,
                                  xlevels=list(PO1MR=c(-sd(Elect2012Npref$PO1MR), 0 , sd(Elect2012Npref$PO1MR)), 
                                               ReligiosityT1cMR = seq(from = min(Elect2012Npref$ReligiosityT1cMR), to = max(Elect2012Npref$ReligiosityT1cMR), by =1)), 
                                  se=TRUE,confidence.level=.95)

Npref2012.RelgAtPO.Eff<-as.data.frame(Npref2012.RelgAtPO.fitted)

Npref2012.RelgAtPO.Eff$POmod<-factor(Npref2012.RelgAtPO.Eff$PO1MR,
                                     levels=c(-sd(Elect2012Npref$PO1MR),0,sd(Elect2012Npref$PO1MR)),
                                     labels=c("Liberal","Moderate","Conservative"))

Npref2012.RelgAtPO.Plot <-ggplot(data = Npref2012.RelgAtPO.Eff, aes(x = ReligiosityT1cMR, y =fit, group=POmod))+
  coord_cartesian(xlim=c(min(Elect2012Npref$ReligiosityT1cMR), max(Elect2012Npref$ReligiosityT1cMR)),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = min(Elect2012Npref$ReligiosityT1cMR), to = max(Elect2012Npref$ReligiosityT1cMR), by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=POmod, linetype = POmod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=POmod),alpha=.2)+
  xlab("Religiosity")+
  ylab("Non-Preferred Candidate Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .18))
Npref2012.RelgAtPO.Plot


#Test simple slopes.
mcNpref.RelgAtPO <- plotSlopes(mcNpref.2way.sig, plotx="ReligiosityT1cMR", modx="PO1MR", 
                               xlab = "Religiosity", ylab = "Non-Preferred Candidate Moral Conviction", 
                               modxVals = c(-sd(Elect2012Npref$PO1MR), 0, sd(Elect2012Npref$PO1MR)), xlim = c (min(Elect2012Npref$ReligiosityT1cMR), max(Elect2012Npref$ReligiosityT1cMR)), plotPoints = FALSE, 
                               legendTitle = "Political Orientation")

mcNpref.RelgAtPO.test <- testSlopes(mcNpref.RelgAtPO)
mcNpref.RelgAtPO.test$hypotests


#Plotting the Religious Conviction by Religiosity interaction predicting moral conviction.
#The effect of Religious Conviction at mean religiosity and one standard deviation above and below.
summary(mcNpref.2way.sig)
describe(Elect2012Npref$ReligiosityT1cMR)
describe(Elect2012Npref$RCnonpreferredT1cMR)

Npref2012.RCatRelig.fitted<-effect('ReligiosityT1cMR:RCnonpreferredT1cMR', mcNpref.2way.sig,
                                   xlevels=list(ReligiosityT1cMR=c(-sd(Elect2012Npref$ReligiosityT1cMR), 0 , sd(Elect2012Npref$ReligiosityT1cMR)), 
                                                RCnonpreferredT1cMR = seq(from = min(Elect2012Npref$RCnonpreferredT1cMR), to = max(Elect2012Npref$RCnonpreferredT1cMR), by =1)), 
                                   se=TRUE,confidence.level=.95)

Npref2012.RCatRelig.Eff<-as.data.frame(Npref2012.RCatRelig.fitted)

Npref2012.RCatRelig.Eff$ReligMod<-factor(Npref2012.RCatRelig.Eff$ReligiosityT1cMR,
                                         levels=c(-sd(Elect2012Npref$ReligiosityT1cMR),0,sd(Elect2012Npref$ReligiosityT1cMR)),
                                         labels=c("Low Religiosity","Mean Religiosity","Hi Religiosity"))

Npref2012.RCatRelig.Plot <-ggplot(data = Npref2012.RCatRelig.Eff, aes(x = RCnonpreferredT1cMR, y =fit, group=ReligMod))+
  coord_cartesian(xlim=c(min(Elect2012Npref$RCnonpreferredT1cMR), max(Elect2012Npref$RCnonpreferredT1cMR)),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = min(Elect2012Npref$RCnonpreferredT1cMR), to = max(Elect2012Npref$RCnonpreferredT1cMR), by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=ReligMod, linetype = ReligMod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=ReligMod),alpha=.2)+
  xlab("Non-Preferred Candidate Religious Conviction")+
  ylab("Non-Preferred Candidate Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .18))
Npref2012.RCatRelig.Plot

#Test simple slopes
Npref2012.RCatRelig <- plotSlopes(mcNpref.2way.sig, plotx="RCnonpreferredT1cMR", modx="ReligiosityT1cMR", 
                                  xlab = "Religious Conviction", ylab = "Non-Preferred Candidate Moral Conviction", 
                                  modxVals = c(-sd(Elect2012Npref$ReligiosityT1cMR), 0, sd(Elect2012Npref$ReligiosityT1cMR)), xlim = c (min(Elect2012Npref$RCnonpreferredT1cMR), max(Elect2012Npref$RCnonpreferredT1cMR)), plotPoints = FALSE, 
                                  legendTitle = "Religiosity")

Npref2012.RCatRelig.test <- testSlopes(Npref2012.RCatRelig)
Npref2012.RCatRelig.test$hypotests


