####################################################################
####################################################################
#######  Religious Conviction Predicting Moral Conviction  #########

library(rockchalk) #Graphing simple slopes; moderation
library(stargazer) #Handy regression tables
library(foreign)  # Read in SPSS
library(gvlma)   #helper on diagnostics
library(effects) #helper on visualizing interactions - Uses lattice
library(sjPlot)  #helper on visualizing interactions - uses ggplot
library(ggplot2) #All the graphs
library(psych) #handy for descriptives, etc
library(dplyr) 

#set working directory
setwd("C:/Users/Brittany/Box Sync/RC Project/Data sets/Study 9 (Zaal S4 BH)")

##########################################################################################
##########################################################################################
#### Study 9. 

MCmanipRegFit <- read.spss("MCRC_Study9_Data.sav", use.value.labels = FALSE, to.data.frame = TRUE,
                           max.value.labels = Inf, trim.factor.names = FALSE,
                           trim_values = TRUE, reencode = NA, use.missings = to.data.frame)

#Center Religious Conviction.
MCmanipRegFit$RCc <- scale(MCmanipRegFit$RC, center = T, scale = F)

#Mean replace centered Religious Conviction.
MCmanipRegFit$RCcmr <- ifelse(is.na(MCmanipRegFit$RCc),
                              mean(MCmanipRegFit$RCc,na.rm=TRUE), MCmanipRegFit$RCc)

MCmanipRegFit$RCcmr <- as.vector(MCmanipRegFit$RCcmr)

#Mean replace midpoint Centered Political Orientation.
MCmanipRegFit$POmr <- ifelse(is.na(MCmanipRegFit$PO),
                             mean(MCmanipRegFit$PO,na.rm=TRUE), MCmanipRegFit$PO)

#Mean replace Moral Conviction. 
MCmanipRegFit$MCmr <- ifelse(is.na(MCmanipRegFit$MC),
                             mean(MCmanipRegFit$MC,na.rm=TRUE), MCmanipRegFit$MC)

describe(MCmanipRegFit$RCc)
describe(MCmanipRegFit$RCcmr)
describe(MCmanipRegFit$PO)
describe(MCmanipRegFit$POmr)
describe(MCmanipRegFit$MC)
describe(MCmanipRegFit$MCmr)

##################################################
####Participant generated issue Moral Conviction

##Descriptives and Bi-variate correlations

describe(MCmanipRegFit$PO)
describe(MCmanipRegFit$RC)
describe(MCmanipRegFit$MC)

cor.test(MCmanipRegFit$PO, MCmanipRegFit$RC)
cor.test(MCmanipRegFit$PO, MCmanipRegFit$MC)
cor.test(MCmanipRegFit$RC, MCmanipRegFit$MC)

#Main effects political orientation (mean replaced, midpoint centered), candidate religious conviction (mean replaced, mean centered)
MCmanipRF.main <- lm(MCmr ~ POmr
                     + RCcmr,
                     data = MCmanipRegFit) 
summary(MCmanipRF.main)

#Main effects & 2-way Interactions
MCmanipRF.2way <- lm(MCmr ~ POmr*RCcmr,
                     data = MCmanipRegFit) 

summary(MCmanipRF.2way)
anova(MCmanipRF.main,MCmanipRF.2way)

##Paper table of main effects and significant 2-way interactions. 
stargazer(MCmanipRF.main,MCmanipRF.2way,type="text",
          column.labels = c("Main Effects", "2-way Interaction"),
          intercept.bottom = FALSE,
          single.row=FALSE, 
          notes.append = FALSE,
          header=FALSE)
anova(MCmanipRF.main,MCmanipRF.2way)

#Testing Simple Slopes. 
describe(MCmanipRegFit$RCcmr)
describe(MCmanipRegFit$POmr)

MCmanipRegFit.RCAtPO <- plotSlopes(MCmanipRF.2way, plotx="RCcmr", modx="POmr", 
                                   xlab = "Religious Conviction", ylab = "Moral Conviction", 
                                   modxVals = c(-sd(MCmanipRegFit$POmr), 0 , sd(MCmanipRegFit$POmr)), xlim = c (min(MCmanipRegFit$RCcmr), max(MCmanipRegFit$RCcmr)), plotPoints = FALSE, 
                                   legendTitle = "Political Orientation")

MCmanipRegFit.RCAtPO.test <- testSlopes(MCmanipRegFit.RCAtPO)
MCmanipRegFit.RCAtPO.test$hypotests

#Plotting the Political orientation by religious conviction interaction predicting moral conviction.
#The effect of RC at moderates and one standard deviation above and below moderate (1.75).

MCmanipRF.2way.fitted<-effect('POmr:RCcmr', MCmanipRF.2way,
                              xlevels=list(POmr=c(-sd(MCmanipRegFit$POmr), 0 , sd(MCmanipRegFit$POmr)), RCcmr = seq(from = min(MCmanipRegFit$RCcmr), to = max(MCmanipRegFit$RCcmr), by =1)), se=TRUE,confidence.level=.95)

MCmanipRF.2way.Eff<-as.data.frame(MCmanipRF.2way.fitted)

MCmanipRF.2way.Eff$POmod<-factor(MCmanipRF.2way.Eff$POmr,
                                 levels=c(-sd(MCmanipRegFit$POmr),0,sd(MCmanipRegFit$POmr)),
                                 labels=c("Liberal","Moderate","Conservative"))

MCmanipRF.2way.Plot.RCAtPO <-ggplot(data = MCmanipRF.2way.Eff, aes(x = RCcmr, y =fit, group=POmod))+
  coord_cartesian(xlim=c(min(MCmanipRegFit$RCcmr), max(MCmanipRegFit$RCcmr)),ylim = c(1,5))+ 
  scale_x_continuous(breaks = seq(from = min(MCmanipRegFit$RCcmr), to = max(MCmanipRegFit$RCcmr), by =1),labels = c(1,2,3,4,5))+
  geom_line(aes(color=POmod, linetype = POmod))+
  geom_ribbon(aes(ymin=fit-se, ymax=fit+se,fill=POmod),alpha=.2)+
  xlab("Religious Conviction")+
  ylab("Moral Conviction")+
  scale_color_manual(values=c("gray0", "gray0", "gray0"))+
  scale_fill_manual(values=c("gray40", "gray40", "gray40"))+
  theme_bw()+
  theme(text=element_text(family="", face="bold", size=12),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        axis.line = element_line(size = 1, colour = "grey0"),
        legend.title=element_blank(),
        legend.position = c(.15, .18))
MCmanipRF.2way.Plot.RCAtPO